@@ -6,6 +6,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Couldn&apos;t initialize QSql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open mySQL connection!</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAddCart</name>
     <message>
@@ -80,6 +91,14 @@
         <source>This cart already exists.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Duplicate Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The cart title must be unique!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -111,6 +130,10 @@
         <source>&amp;Service:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The service is invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAudioSettingsDialog</name>
@@ -320,6 +343,19 @@ Color</source>
         <source>GROUP</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Send to
+&amp;Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please Wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -384,6 +420,14 @@ Cart</source>
         <source>GROUP</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Please Wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -620,6 +664,29 @@ Marker</source>
         <source>R</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No Fade on Segue Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDEditPanelName</name>
+    <message>
+        <source>Edit Panel Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Panel &amp;Name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDExceptionDialog</name>
@@ -800,6 +867,22 @@ Overwrite?</source>
         <source>40 kbps</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>8 kbps</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16 kbps</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>24 kbps</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>144 kbps</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDGetAth</name>
@@ -862,17 +945,6 @@ figure for the report period.
 </context>
 <context>
     <name>RDImportAudio</name>
-    <message>
-        <source>Sound Files (*.mp* *.MP* *.wav *.WAV *.ogg *.OGG *.flac *.FLAC *.atx *.ATX *.tmc *.TMC)
-WAV Files (*.wav *.WAV)
-MPEG Files (*.mp* *.MP*)
-OggVorbis Files (*.ogg *.OGG)
-FLAC Files (*.flac *.FLAC)
-ATX Files (*.atx *.ATX)
-TM Century GoldDrive Files (*.tmc *.TMC)
-All Files (*.*)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import/Export Audio File</source>
         <translation type="unfinished"></translation>
@@ -1063,6 +1135,36 @@ Do you still want to proceed?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDIntegerDialog</name>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Value</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDIntegerEdit</name>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Value</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDLicense</name>
     <message>
@@ -1074,6 +1176,60 @@ Do you still want to proceed?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDListGroups</name>
+    <message>
+        <source>Select Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NAME</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DESCRIPTION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDListLogs</name>
+    <message>
+        <source>Select Log - User: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NAME</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DESCRIPTION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SERVICE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDListSelector</name>
     <message>
@@ -1183,10 +1339,6 @@ Do you still want to proceed?</source>
         <source>Tracker</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>OVERLAP</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>RDPasswd</name>
@@ -1301,6 +1453,10 @@ please try again!</source>
         <source>Report canceled!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RadioTraffic.com Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDSoundPanel</name>
@@ -1333,6 +1489,17 @@ please try again!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDSqlDatabaseStatus</name>
+    <message>
+        <source>Database connection restored.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database connection failed : </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDStereoMeter</name>
     <message>
@@ -1360,7 +1527,7 @@ please try again!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Autofill Errors
+        <source>Event Fill Errors
 </source>
         <translation type="unfinished"></translation>
     </message>
