@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.188.2.2 2009/05/21 17:32:17 cvs Exp $
+//      $Id: rd.h,v 1.188.2.4 2009/08/04 17:48:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,6 +29,11 @@
 #define RD_CONF_FILE "/etc/rd.conf"
 #define RD_WIN_CONF_FILE "rd.ini"
 
+/*
+ * Default ALSA asoundrc file
+ */
+#define RD_ASOUNDRC_FILE "/etc/asound.conf"
+
 /*
  * PID File Locations
  */
@@ -306,6 +311,16 @@ struct RDMeterBlock {
  */
 #define RD_FADE_TYPE RDHPISoundCard::Log
 
+/*
+ * This defines the maximum frequency (in Hz) of the broadcast audio
+ * channel being fed by Rivendell.  It is used for things like calculating
+ * how expensive an algorithm is needed for sample rate conversion.
+ *
+ * For modern FM facilities running MPX stereo, 15000 Hz is a reasonable
+ * value.
+ */
+#define RD_MAX_BANDPASS 15000
+
 /*
  * The limits on timescaling
  */
