@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.cpp,v 1.61.2.2 2008-11-30 16:33:57 fredg Exp $
+//      $Id: rdcart.cpp,v 1.61.2.3 2009/03/24 12:11:18 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,7 +33,7 @@
 #include <rdcut.h>
 #include <rdtextvalidator.h>
 #include <rdescape_string.h>
-
+#include <rdsystem.h>
 
 RDCart::RDCart(unsigned number)
 {
@@ -162,7 +162,7 @@ QString RDCart::title() const
 
 void RDCart::setTitle(const QString &title) const
 {
-  SetRow("TITLE",title);
+  SetRow("TITLE",VerifyTitle(title));
 }
 
 
@@ -649,42 +649,42 @@ void RDCart::setMetadata(RDWaveData *data)
   QString sql="update CART set ";
   if(!data->title().isEmpty()) {
     sql+=QString().sprintf("TITLE=\"%s\",",(const char *)
-		    RDEscapeString(data->title()).utf8());
+			   RDEscapeString(VerifyTitle(data->title())).utf8());
   }
   if(!data->artist().isEmpty()) {
     sql+=QString().sprintf("ARTIST=\"%s\",",(const char *)
-		    RDEscapeString(data->artist()).utf8());
+			   RDEscapeString(data->artist()).utf8());
   }
   if(!data->album().isEmpty()) {
     sql+=QString().sprintf("ALBUM=\"%s\",",(const char *)
-		    RDEscapeString(data->album()).utf8());
+			   RDEscapeString(data->album()).utf8());
   }
   if(data->releaseYear()>0) {
     sql+=QString().sprintf("YEAR=\"%04d-01-01\",",data->releaseYear());
   }
   if(!data->label().isEmpty()) {
     sql+=QString().sprintf("LABEL=\"%s\",",(const char *)
-		    RDEscapeString(data->label()).utf8());
+			   RDEscapeString(data->label()).utf8());
   }
   if(!data->client().isEmpty()) {
     sql+=QString().sprintf("CLIENT=\"%s\",",(const char *)
-		    RDEscapeString(data->client()).utf8());
+			   RDEscapeString(data->client()).utf8());
   }
   if(!data->agency().isEmpty()) {
     sql+=QString().sprintf("AGENCY=\"%s\",",(const char *)
-		    RDEscapeString(data->agency()).utf8());
+			   RDEscapeString(data->agency()).utf8());
   }
   if(!data->publisher().isEmpty()) {
     sql+=QString().sprintf("PUBLISHER=\"%s\",",(const char *)
 			   RDEscapeString(data->publisher()).utf8());
   }
   if(!data->composer().isEmpty()) {
-    sql+=QString().sprintf("COMPOSER=\"%s\",",
-    (const char *)RDEscapeString(data->composer()).utf8());
+    sql+=QString().sprintf("COMPOSER=\"%s\",",(const char *)
+			   RDEscapeString(data->composer()).utf8());
   }
   if(!data->userDefined().isEmpty()) {
-    sql+=QString().sprintf("USER_DEFINED=\"%s\",",
-    (const char *)RDEscapeString(data->userDefined()).utf8());
+    sql+=QString().sprintf("USER_DEFINED=\"%s\",",(const char *)
+			   RDEscapeString(data->userDefined()).utf8());
   }
   if(sql.right(1)==",") {
     sql=sql.left(sql.length()-1);
@@ -1120,6 +1120,33 @@ RDCut::Validity RDCart::ValidateCut(RDSqlQuery *q,bool enforce_length,
 }
 
 
+QString RDCart::VerifyTitle(const QString &title) const
+{
+  QString ret=title;
+  QString sql;
+  RDSqlQuery *q;
+  RDSystem *system=new RDSystem();
+
+  if(!system->allowDuplicateCartTitles()) {
+    int n=1;
+    while(1==1) {
+      sql=QString().sprintf("select NUMBER from CART \
+                             where (TITLE=\"%s\")&&(NUMBER!=%u)",
+			    (const char *)RDEscapeString(ret),cart_number);
+      q=new RDSqlQuery(sql);
+      if(!q->first()) {
+	delete q;
+	return ret;
+      }
+      delete q;
+      ret=title+QString().sprintf(" [%d]",n++);
+    }
+  }
+  delete system;
+  return ret;
+}
+
+
 void RDCart::SetRow(const QString &param,const QString &value) const
 {
   RDSqlQuery *q;
