@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdcddblookup.cpp,v 1.1 2007/09/14 14:06:24 fredg Exp $
+//    $Id: rdcddblookup.cpp,v 1.3 2008/01/18 20:08:52 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -322,12 +322,13 @@ int RDCddbLookup::GetIndex(QString *tag)
 bool RDCddbLookup::GetCddaData(QString &cdda_dir,QString &cdda_dev)
 {
   int err=0;
-  RDProfile *profile=new RDProfile();
+  RDProfile *title_profile=new RDProfile();
+  RDProfile *isrc_profile=new RDProfile();
   bool cdtext_found=false;
   QString str;
 
   //
-  // Write the CDDA Data to a Temp File
+  // Write the Track Title Data to a Temp File
   //
   QString cmd=QString().sprintf("CURDIR=`pwd`;cd %s;cdda2wav -D %s --info-only -v titles 2> /dev/null;cd $CURDIR",
 				(const char *)cdda_dir,
@@ -338,47 +339,66 @@ bool RDCddbLookup::GetCddaData(QString &cdda_dir,QString &cdda_dev)
   }
 
   //
-  // Read the Temp File
+  // Read the Track Title Data File
   //
   for(int i=0;i<lookup_record->tracks();i++) {
-    profile->setSource(QString().sprintf("%s/audio_%02d.inf",
+    title_profile->setSource(QString().sprintf("%s/audio_%02d.inf",
 					 (const char *)cdda_dir,i+1));
-    str=profile->stringValue("","Albumtitle","");
+    str=title_profile->stringValue("","Albumtitle","");
     str.remove("'");
     if((!str.isEmpty())&&(str!="''")) {
       lookup_record->setDiscTitle(str);
       cdtext_found=true;
     }
 
-    str=profile->stringValue("","Albumperformer","");
+    str=title_profile->stringValue("","Albumperformer","");
     str.remove("'");
     if((!str.isEmpty())&&(str!="''")) {
       lookup_record->setDiscArtist(str);
       cdtext_found=true;
     }
 
-    str=profile->stringValue("","Tracktitle","");
+    str=title_profile->stringValue("","Tracktitle","");
     str.remove("'");
     if((!str.isEmpty())&&(str!="''")) {
       lookup_record->setTrackTitle(i,str);
       cdtext_found=true;
     }
 
-    str=profile->stringValue("","Performer","");
+    str=title_profile->stringValue("","Performer","");
     str.remove("'");
     if((!str.isEmpty())&&(str!="''")) {
       lookup_record->setTrackArtist(i,str);
       cdtext_found=true;
     }
+  }
 
-    str=profile->stringValue("","ISRC","");
+  //
+  // Write the ISRC Data to a Temp File
+  //
+  cmd=QString().sprintf("CURDIR=`pwd`;cd %s;cdda2wav -D %s --info-only -v trackid 2> /dev/null;cd $CURDIR",
+				(const char *)cdda_dir,
+				(const char *)cdda_dev);
+  if((err=system(cmd))!=0) {
+    printf("cdda2wav error: %d\n",err);
+    return false;
+  }
+
+  //
+  // Read the ISRC Data File
+  //
+  for(int i=0;i<lookup_record->tracks();i++) {
+    isrc_profile->setSource(QString().sprintf("%s/audio_%02d.inf",
+					      (const char *)cdda_dir,i+1));
+    str=isrc_profile->stringValue("","ISRC","");
     str.remove("'");
+    str.remove("-");
     if((!str.isEmpty())&&(str!="''")) {
       lookup_record->setIsrc(i,str);
-      cdtext_found=true;
     }
   }
-  delete profile;
+  delete title_profile;
+  delete isrc_profile;
 
   return cdtext_found;
 }
