@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcmd_switch.cpp,v 1.7 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdcmd_switch.cpp,v 1.10 2008/07/26 00:01:37 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,11 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#ifndef WIN32
+#include <syslog.h>
+#endif  // WIN32
+
+#include <stdlib.h>
 #include <rdcmd_switch.h>
 #include <qmessagebox.h>
 
@@ -27,6 +32,7 @@ RDCmdSwitch::RDCmdSwitch(int argc,char *argv[],char *modname,char *usage)
 {
   unsigned l=0;
   bool handled=false;
+  bool debug=false;
 
   for(int i=1;i<argc;i++) {
 #ifndef WIN32
@@ -39,6 +45,9 @@ RDCmdSwitch::RDCmdSwitch(int argc,char *argv[],char *modname,char *usage)
       printf("\n%s %s\n",modname,usage);
       exit(0);
     }
+    if(!strcmp(argv[i],"-d")) {
+      debug=true;
+    }
     l=strlen(argv[i]);
     handled=false;
     for(unsigned j=0;j<l;j++) {
@@ -56,6 +65,18 @@ RDCmdSwitch::RDCmdSwitch(int argc,char *argv[],char *modname,char *usage)
       switch_processed.push_back(false);
     }
   }
+
+  //
+  // Initialize Logging
+  //
+#ifndef WIN32
+  if(debug) {
+    openlog(modname,LOG_PERROR,LOG_USER);
+  }
+  else {
+    openlog(modname,0,LOG_USER);
+  }
+#endif  // WIN32
 }
 
 
