@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut_dialog.cpp,v 1.25 2007-12-12 19:20:37 fredg Exp $
+//      $Id: rdcut_dialog.cpp,v 1.25.2.2 2009/08/04 20:56:49 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -377,6 +377,7 @@ void RDCutDialog::addButtonData()
   item->setText(2,cart_title);
   cut_cart_list->setSelected(item,true);
   cut_cart_list->ensureItemVisible(item);
+  cut_ok_button->setEnabled(true);
 
   delete add_cart;
 }
@@ -524,7 +525,7 @@ void RDCutDialog::BuildGroupList()
   }
   else {
     sql=QString().sprintf("select GROUP_NAME from USER_PERMS\
-                           where USER_NAME=\"%s\" order by GROUP_NAME",
+                           where USER_NAME=\"%s\" order by GROUP_NAME desc",
 			  (const char *)cut_username);
   }
   q=new RDSqlQuery(sql);
