@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddatedecode.cpp,v 1.5 2007-02-14 21:48:41 fredg Exp $
+//      $Id: rddatedecode.cpp,v 1.5.6.1 2008/11/06 16:32:29 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,7 @@ QString RDDateDecode(QString str,QDate date)
   QString string;
   int yearnum;
   int dow;
+  bool upper_case=false;
 
   for(unsigned i=0;i<str.length();i++) {
     if(str.at(i)!='%') {
@@ -35,22 +36,46 @@ QString RDDateDecode(QString str,QDate date)
     }
     else {
       i++;
+      if(((const char *)str)[i]=='^') {
+	upper_case=true;
+	i++;
+      }
       switch(((const char *)str)[i]) {
 	  case 'a':   // Abbreviated weekday name
-	    string+=QDate::shortDayName(date.dayOfWeek()).lower();
+	    if(upper_case) {
+	      string+=QDate::shortDayName(date.dayOfWeek()).upper();
+	    }
+	    else {
+	      string+=QDate::shortDayName(date.dayOfWeek()).lower();
+	    }
 	    break;
 
 	  case 'A':   // Full weekday name
-	    string+=QDate::longDayName(date.dayOfWeek()).lower();
+	    if(upper_case) {
+	      string+=QDate::longDayName(date.dayOfWeek()).upper();
+	    }
+	    else {
+	      string+=QDate::longDayName(date.dayOfWeek()).lower();
+	    }
 	    break;
 
 	  case 'b':   // Abbreviated month name
 	  case 'h':
-	    string+=QDate::shortMonthName(date.month()).lower();
+	    if(upper_case) {
+	      string+=QDate::shortMonthName(date.month()).upper();
+	    }
+	    else {
+	      string+=QDate::shortMonthName(date.month()).lower();
+	    }
 	    break;
 
 	  case 'B':   // Full month name
-	    string+=QDate::longMonthName(date.month()).lower();
+	    if(upper_case) {
+	      string+=QDate::longMonthName(date.month()).upper();
+	    }
+	    else {
+	      string+=QDate::longMonthName(date.month()).lower();
+	    }
 	    break;
 
 	  case 'C':   // Century
