@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdevent_line.cpp,v 1.51 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdevent_line.cpp,v 1.54.2.2 2009/02/03 15:35:52 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,12 +20,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <qtextstream.h>
+
 #include <rdconf.h>
 #include <rdcart.h>
 #include <rdevent_line.h>
 #include <schedcartlist.h>
-
-#include <qtextstream.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 
 
 RDEventLine::RDEventLine()
@@ -46,10 +48,12 @@ void RDEventLine::setName(const QString &name)
 {
   event_name=name;
   event_preimport_log->
-    setLogName(QString().sprintf("%s_PRE",(const char *)event_name).
-	       replace(' ',"_"));
+      setLogName(QString().sprintf("%s_PRE",(const char *)
+				   RDEscapeStringSQLColumn(event_name)).
+		 replace(' ',"_"));
   event_postimport_log->
-    setLogName(QString().sprintf("%s_POST",(const char *)event_name).
+    setLogName(QString().sprintf("%s_POST",(const char *)
+				 RDEscapeStringSQLColumn(event_name)).
 	       replace(' ',"_"));
 }
 
@@ -332,7 +336,7 @@ bool RDEventLine::load()
                                  COLOR,AUTOFILL_SLOP,NESTED_EVENT,SCHED_GROUP,TITLE_SEP,HAVE_CODE \
                                  from EVENTS where NAME=\"%s\"",
 				(const char *)event_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     fprintf(stderr,"RDEventLine::load() EVENT NOT FOUND: %s\n",
 	    (const char *)event_name);
@@ -374,7 +378,7 @@ bool RDEventLine::save()
 {
   QString sql=QString().sprintf("select NAME from EVENTS where NAME=\"%s\"",
 				(const char *)event_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString().sprintf("update EVENTS set PROPERTIES=\"%s\",\
                            PREPOSITION=%d,TIME_TYPE=%d,\
@@ -383,9 +387,10 @@ bool RDEventLine::save()
                            IMPORT_SOURCE=%d,START_SLOP=%d,\
                            END_SLOP=%d,FIRST_TRANS_TYPE=%d,\
                            DEFAULT_TRANS_TYPE=%d,COLOR=\"%s\"\
-                           AUTOFILL_SLOP=%d,NESTED_EVENT=\"%s\",SCHED_GROUP=\"%s\",TITLE_SEP=%d,HAVE_CODE=\"%s\" \
+                           AUTOFILL_SLOP=%d,NESTED_EVENT=\"%s\",\
+                           SCHED_GROUP=\"%s\",TITLE_SEP=%d,HAVE_CODE=\"%s\" \
                            where NAME=\"%s\"",
-			  (const char *)event_properties,
+			  (const char *)RDEscapeString(event_properties),
 			  event_preposition,event_time_type,
 			  event_grace_time,
 			  (const char *)RDYesNo(event_post_point),
@@ -396,7 +401,11 @@ bool RDEventLine::save()
 			  event_default_transtype,
 			  (const char *)event_color.name(),
 			  event_autofill_slop,
-			  (const char *)event_nested_event,(const char *)event_sched_group,event_title_sep,(const char*)event_have_code,(const char *)event_name);
+			  (const char *)RDEscapeString(event_nested_event),
+			  (const char *)RDEscapeString(event_sched_group),
+			  event_title_sep,
+			  (const char*)event_have_code,
+			  (const char *)RDEscapeString(event_name));
   }
   else {
     sql=QString().sprintf("insert into EVENTS set NAME=\"%s\",\
@@ -408,8 +417,8 @@ bool RDEventLine::save()
                            END_SLOP=%d,FIRST_TRANS_TYPE=%d,\
                            DEFAULT_TRANS_TYPE=%d,COLOR=\"%s\"\
                            AUTOFILL_SLOP=%d,SCHED_GROUP=\"%s\" where NAME=\"%s\"",
-			  (const char *)event_name,
-			  (const char *)event_properties,
+			  (const char *)RDEscapeString(event_name),
+			  (const char *)RDEscapeString(event_properties),
 			  event_preposition,event_time_type,
 			  event_grace_time,
 			  (const char *)RDYesNo(event_post_point),
@@ -420,11 +429,11 @@ bool RDEventLine::save()
 			  event_default_transtype,
 			  (const char *)event_color.name(),
 			  event_autofill_slop,
-			  (const char *)event_sched_group,
-			  (const char *)event_name);
+			  (const char *)RDEscapeString(event_sched_group),
+			  (const char *)RDEscapeString(event_name));
   }
   delete q;
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(!q->isActive()) {
     delete q;
     return false;
@@ -441,8 +450,8 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			      QString clockname)
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   QTime time=event_start_time;
   QTime end_time=event_start_time.addMSecs(event_length);
   QTime fill_start_time;
@@ -463,7 +472,7 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   //
   sql=QString().sprintf("select COUNT from `%s_LOG` order by COUNT desc",
 			(const char *)logname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     count=q->value(0).toInt()+1;
   }
@@ -472,7 +481,7 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   sql=QString().sprintf("select LINK_ID from `%s_LOG` where LINK_ID>=0 \
                          order by LINK_ID desc",
 			(const char *)logname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     link_id=q->value(0).toInt()+1;
   }
@@ -509,8 +518,9 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			    time_type,
 			    (const char *)RDYesNo(post_point),
 			    logline->transType(),
-			    (const char *)logline->markerComment());
-      q=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(logline->markerComment()));
+      q=new RDSqlQuery(sql);
       delete q;
       count++;
       time=time.addMSecs(GetLength(logline->cartNumber()));
@@ -561,13 +571,13 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			  time_type,
 			  (const char *)RDYesNo(post_point),
 			  trans_type,
-			  (const char *)event_name,
+			  (const char *)RDEscapeString(event_name),
 			  (const char *)event_start_time.toString("hh:mm:ss"),
 			  event_start_time.msecsTo(end_start_time),
 			  link_id,
 			  event_start_slop,
 			  event_end_slop);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     count++;
     time=time.addMSecs(event_length);
@@ -579,236 +589,235 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 
 // Scheduler 
 
-  if(event_import_source == RDEventLine::Scheduler ) 
-    {
-          int titlesep;
-          int stackid;
-          int counter;   		
-          RDLogLine::Source source=RDLogLine::Music;
-              
-          QString svcname_rp = svcname;
-          svcname_rp.replace(" ","_");
- 
-	  time.addMSecs(postimport_length);
-      
-	  sql=QString().sprintf("select NUMBER,ARTIST,SCHED_CODES from CART where GROUP_NAME='%s'",(const char *)SchedGroup()); 
-
-	  q=new QSqlQuery(sql);
-	  if(q->size()>0)
-	  {
-                  if(event_title_sep>=0 && event_title_sep<=50000)
-                          {
-                          titlesep = (int)event_title_sep;
-                          }
-                  else
-                          {
-                          titlesep = 100;
-                          }
-    	  
-		  int querysize=(int)q->size();
-		  SchedCartList *schedCL;
-		  schedCL=new SchedCartList(querysize);
-
-		  for(counter=0;counter<querysize;counter++)
-		  {
-			  q->seek(counter);
-                          schedCL->insertItem(q->value(0).toUInt(),0,0,q->value(1).toString(),q->value(2).toString());
-                  }
-		  delete q;
-
-        	  sql=QString().sprintf("SELECT SCHED_STACK_ID from %s_STACK order by SCHED_STACK_ID",(const char*)svcname_rp);
-	          q=new QSqlQuery(sql);
-	          if (q->last())
-	             { 
-	             stackid=q->value(0).toUInt();
-	             }
-	          else
-	          { 
-	             stackid=0;
-	          }
-	             stackid++;    
-	          delete q;
-	
-
-		  // Add deconflicting rules here		  
-		  // Title separation 
-		  schedCL->save();		  
-                  sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID >= %d",(const char*)svcname_rp,(stackid-titlesep));
-                  q=new QSqlQuery(sql);
-
-                  while (q->next())	
-                  {
-                     for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                     { 
-                          if(q->value(0).toUInt()==schedCL->getItemCartnumber(counter))
-                          {
- 			       schedCL->removeItem(counter);
-			       counter--;
-		          }
-		     }
-                  }          
-                  delete q;
-                  if(schedCL->getNumberOfItems()==0)
-                    *errors+=QString().sprintf("%s Rule broken: Title Separation\n",(const char *)time.toString("hh:mm:ss"));
-                  schedCL->restore();
-
-                  // Artist separation
-		  schedCL->save();		  
-                  sql=QString().sprintf("select ARTIST from %s_STACK \
-			  where SCHED_STACK_ID >= %d",(const char*)svcname_rp,(stackid-artistsep));
-                  q=new QSqlQuery(sql);
-
-                  while (q->next())	
-                  {
-                     for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                     { 
-                          if(q->value(0).toString()==schedCL->getItemArtist(counter))
-                          {
- 			       schedCL->removeItem(counter);
-			       counter--;
-		          }
-		     }
-                  }          
-
-                  delete q;
-                  if(schedCL->getNumberOfItems()==0)
-                      *errors+=QString().sprintf("%s Rule broken: Artist Separation\n",(const char *)time.toString("hh:mm:ss"));
-                  schedCL->restore();
-
-                  // Must have scheduler code
-                  if(event_have_code!="")
-                    {
-		    schedCL->save();		  
-                    for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                      { 
-                      if(!schedCL->itemHasCode(counter,event_have_code))
-                        {
-                        schedCL->removeItem(counter);
-		        counter--;
-                        }
-                      }
-                     if(schedCL->getNumberOfItems()==0)
-                       *errors+=QString().sprintf("%s Rule broken: Must have code %s\n",(const char *)time.toString("hh:mm:ss"),(const char*)event_have_code);
-                     schedCL->restore();
-                     }
-
-		  // Scheduler Codes 
-	          sql=QString().sprintf("select CODE,MAX_ROW,MIN_WAIT,NOT_AFTER, OR_AFTER,OR_AFTER_II from %s_RULES",(const char *)clockname);
-	          q=new QSqlQuery(sql);
-                     while (q->next())
-                       {
-                       // max in a row, min wait
-  		       schedCL->save();	
-                       int range=q->value(1).toInt()+q->value(2).toInt(); 
-                       int allowed=q->value(1).toInt();
-                       QString wstr=q->value(0).toString();
-                       wstr+="          ";
-                       wstr=wstr.left(11);
-                       sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID > %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-range),(const char *)wstr);
-                       q1=new QSqlQuery(sql);
-                       if (q1->size()>=allowed || allowed==0)	
-                         for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                           if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
-                             counter--;
-                       delete q1;
-                       if(schedCL->getNumberOfItems()==0)
-                         *errors+=QString().sprintf("%s Rule broken: Max. in a Row/Min. Wait for %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString());
-                       schedCL->restore();
-                       // do not play after
-                       if (q->value(3).toString()!="")
-                         { 
-  		         schedCL->save();	
-                         QString wstr=q->value(3).toString();
-                         wstr+="          ";
-                         wstr=wstr.left(11);
-                         sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
-                         q1=new QSqlQuery(sql);
-                         if (q1->size()>0)	
-                           for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                             if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
-                               counter--;
-                         delete q1;
-                         if(schedCL->getNumberOfItems()==0)
-                           *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(3).toString());
-                         schedCL->restore();
-                         }
-                       // or after
-                       if (q->value(4).toString()!="")
-                         { 
-  		         schedCL->save();
-                         QString wstr=q->value(4).toString();
-                         wstr+="          ";
-                         wstr=wstr.left(11);
-                         sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
-                         q1=new QSqlQuery(sql);
-                         if (q1->size()>0)	
-                           for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                             if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
-                               counter--;
-                         delete q1;
-                         if(schedCL->getNumberOfItems()==0)
-                           *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(4).toString());
-                         schedCL->restore();
-                         }
-                       // or after II
-                       if (q->value(5).toString()!="")
-                         { 
-  		         schedCL->save();
-                         QString wstr=q->value(5).toString();
-                         wstr+="          ";
-                         wstr=wstr.left(11);
-                         sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
-                         q1=new QSqlQuery(sql);
-                         if (q1->size()>0)	
-                           for(counter=0;counter<schedCL->getNumberOfItems();counter++)
-                             if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
-                               counter--;
-                         delete q1;
-                         if(schedCL->getNumberOfItems()==0)
-                           *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(5).toString());
-                         schedCL->restore();
-                         }
-                       }
-                  delete q;
-
-
-// end of deconflicting rules
-
-		  int schedpos = rand()%schedCL->getNumberOfItems();
-		  sql=QString().sprintf("insert into %s_LOG set ID=%d,COUNT=%d,TYPE=%d,\
-				  SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=-1,\
-				  CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\",\
-				  TRANS_TYPE=%d,EXT_START_TIME=\"%s\"",
-		  (const char *)logname,count,count,
-		  RDLogLine::Cart,source,
-		  (const char *)time.toString("hh:mm:ss"),
-		  schedCL->getItemCartnumber(schedpos),
-		  time_type,
-		  (const char *)RDYesNo(post_point),
-		  trans_type,
-		  (const char *)time.toString("hh:mm:ss"));
-		  q=new QSqlQuery(sql);
-		  delete q;
+  if(event_import_source == RDEventLine::Scheduler ) {
+    int titlesep;
+    int stackid;
+    int counter;   		
+    RDLogLine::Source source=RDLogLine::Music;
     
-		  sql=QString().sprintf("insert into %s_STACK set SCHED_STACK_ID=%u,CART=%u,ARTIST=\"%s\",SCHED_CODES=\"%s\"",(const char*)svcname_rp,
-				  stackid,schedCL->getItemCartnumber(schedpos),
-                                  (const char *)schedCL->getItemArtist(schedpos),(const char *)schedCL->getItemSchedCodes(schedpos));
-		  q=new QSqlQuery(sql);
-		  delete q;
-		  delete schedCL;
-	  }
-	  else
+    QString svcname_rp = svcname;
+    svcname_rp.replace(" ","_");
+    
+    time.addMSecs(postimport_length);
+    
+    sql=QString().sprintf("select NUMBER,ARTIST,SCHED_CODES from CART where GROUP_NAME='%s'",(const char *)SchedGroup()); 
+    
+    q=new RDSqlQuery(sql);
+    if(q->size()>0)
+    {
+      if(event_title_sep>=0 && event_title_sep<=50000)
+      {
+	titlesep = (int)event_title_sep;
+      }
+      else
+      {
+	titlesep = 100;
+      }
+      
+      int querysize=(int)q->size();
+      SchedCartList *schedCL;
+      schedCL=new SchedCartList(querysize);
+      
+      for(counter=0;counter<querysize;counter++)
+      {
+	q->seek(counter);
+	schedCL->insertItem(q->value(0).toUInt(),0,0,q->value(1).toString(),q->value(2).toString());
+      }
+      delete q;
+      
+      sql=QString().sprintf("SELECT SCHED_STACK_ID from %s_STACK order by SCHED_STACK_ID",(const char*)svcname_rp);
+      q=new RDSqlQuery(sql);
+      if (q->last())
+      { 
+	stackid=q->value(0).toUInt();
+      }
+      else
+      { 
+	stackid=0;
+      }
+      stackid++;    
+      delete q;
+      
+      
+      // Add deconflicting rules here		  
+      // Title separation 
+      schedCL->save();		  
+      sql=QString().sprintf("select CART from %s_STACK \
+			  where SCHED_STACK_ID >= %d",(const char*)svcname_rp,(stackid-titlesep));
+      q=new RDSqlQuery(sql);
+      
+      while (q->next())	
+      {
+	for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	{ 
+	  if(q->value(0).toUInt()==schedCL->getItemCartnumber(counter))
 	  {
-		  delete q;
+	    schedCL->removeItem(counter);
+	    counter--;
 	  }
+	}
+      }          
+      delete q;
+      if(schedCL->getNumberOfItems()==0)
+	*errors+=QString().sprintf("%s Rule broken: Title Separation\n",(const char *)time.toString("hh:mm:ss"));
+      schedCL->restore();
+      
+      // Artist separation
+      schedCL->save();		  
+      sql=QString().sprintf("select ARTIST from %s_STACK \
+			  where SCHED_STACK_ID >= %d",(const char*)svcname_rp,(stackid-artistsep));
+      q=new RDSqlQuery(sql);
+      
+      while (q->next())	
+      {
+	for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	{ 
+	  if(q->value(0).toString()==schedCL->getItemArtist(counter))
+	  {
+	    schedCL->removeItem(counter);
+	    counter--;
+	  }
+	}
+      }          
+      
+      delete q;
+      if(schedCL->getNumberOfItems()==0)
+	*errors+=QString().sprintf("%s Rule broken: Artist Separation\n",(const char *)time.toString("hh:mm:ss"));
+      schedCL->restore();
+      
+      // Must have scheduler code
+      if(event_have_code!="")
+      {
+	schedCL->save();		  
+	for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	{ 
+	  if(!schedCL->itemHasCode(counter,event_have_code))
+	  {
+	    schedCL->removeItem(counter);
+	    counter--;
+	  }
+	}
+	if(schedCL->getNumberOfItems()==0)
+	  *errors+=QString().sprintf("%s Rule broken: Must have code %s\n",(const char *)time.toString("hh:mm:ss"),(const char*)event_have_code);
+	schedCL->restore();
+      }
+      
+      // Scheduler Codes 
+      sql=QString().sprintf("select CODE,MAX_ROW,MIN_WAIT,NOT_AFTER, OR_AFTER,OR_AFTER_II from %s_RULES",(const char *)clockname);
+      q=new RDSqlQuery(sql);
+      while (q->next())
+      {
+	// max in a row, min wait
+	schedCL->save();	
+	int range=q->value(1).toInt()+q->value(2).toInt(); 
+	int allowed=q->value(1).toInt();
+	QString wstr=q->value(0).toString();
+	wstr+="          ";
+	wstr=wstr.left(11);
+	sql=QString().sprintf("select CART from %s_STACK \
+			  where SCHED_STACK_ID > %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-range),(const char *)wstr);
+	q1=new RDSqlQuery(sql);
+	if (q1->size()>=allowed || allowed==0)	
+	  for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	    if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
+	      counter--;
+	delete q1;
+	if(schedCL->getNumberOfItems()==0)
+	  *errors+=QString().sprintf("%s Rule broken: Max. in a Row/Min. Wait for %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString());
+	schedCL->restore();
+	// do not play after
+	if (q->value(3).toString()!="")
+	{ 
+	  schedCL->save();	
+	  QString wstr=q->value(3).toString();
+	  wstr+="          ";
+	  wstr=wstr.left(11);
+	  sql=QString().sprintf("select CART from %s_STACK \
+			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  q1=new RDSqlQuery(sql);
+	  if (q1->size()>0)	
+	    for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	      if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
+		counter--;
+	  delete q1;
+	  if(schedCL->getNumberOfItems()==0)
+	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(3).toString());
+	  schedCL->restore();
+	}
+	// or after
+	if (q->value(4).toString()!="")
+	{ 
+	  schedCL->save();
+	  QString wstr=q->value(4).toString();
+	  wstr+="          ";
+	  wstr=wstr.left(11);
+	  sql=QString().sprintf("select CART from %s_STACK \
+			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  q1=new RDSqlQuery(sql);
+	  if (q1->size()>0)	
+	    for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	      if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
+		counter--;
+	  delete q1;
+	  if(schedCL->getNumberOfItems()==0)
+	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(4).toString());
+	  schedCL->restore();
+	}
+	// or after II
+	if (q->value(5).toString()!="")
+	{ 
+	  schedCL->save();
+	  QString wstr=q->value(5).toString();
+	  wstr+="          ";
+	  wstr=wstr.left(11);
+	  sql=QString().sprintf("select CART from %s_STACK \
+			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  q1=new RDSqlQuery(sql);
+	  if (q1->size()>0)	
+	    for(counter=0;counter<schedCL->getNumberOfItems();counter++)
+	      if (                           schedCL->removeIfCode(counter,q->value(0).toString()))
+		counter--;
+	  delete q1;
+	  if(schedCL->getNumberOfItems()==0)
+	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(5).toString());
+	  schedCL->restore();
+	}
+      }
+      delete q;
+      
+      
+// end of deconflicting rules
+      
+      int schedpos = rand()%schedCL->getNumberOfItems();
+      sql=QString().sprintf("insert into %s_LOG set ID=%d,COUNT=%d,TYPE=%d,\
+				  SOURCE=%d,START_TIME=\"%s\",GRACE_TIME=-1, \
+				  CART_NUMBER=%u,TIME_TYPE=%d,POST_POINT=\"%s\", \
+				  TRANS_TYPE=%d,EXT_START_TIME=\"%s\"",
+			    (const char *)logname,count,count,
+			    RDLogLine::Cart,source,
+			    (const char *)time.toString("hh:mm:ss"),
+			    schedCL->getItemCartnumber(schedpos),
+			    time_type,
+			    (const char *)RDYesNo(post_point),
+			    trans_type,
+			    (const char *)time.toString("hh:mm:ss"));
+      q=new RDSqlQuery(sql);
+      delete q;
+      
+      sql=QString().sprintf("insert into %s_STACK set SCHED_STACK_ID=%u,CART=%u,ARTIST=\"%s\",SCHED_CODES=\"%s\"",(const char*)svcname_rp,
+			    stackid,schedCL->getItemCartnumber(schedpos),
+			    (const char *)RDEscapeString(schedCL->getItemArtist(schedpos)),(const char *)schedCL->getItemSchedCodes(schedpos));
+      q=new RDSqlQuery(sql);
+      delete q;
+      delete schedCL;
     }
+    else
+    {
+      delete q;
+    }
+  }
+  
   
-
   //
   // Post-Import Carts
   //
@@ -826,8 +835,9 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 			    time_type,
 			    (const char *)RDYesNo(post_point),
 			    logline->transType(),
-			    (const char *)logline->markerComment());
-      q=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(logline->markerComment()));
+      q=new RDSqlQuery(sql);
       delete q;
       count++;
       time=time.addMSecs(GetLength(logline->cartNumber()));
@@ -848,7 +858,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 			  const QString &import_table,QString *errors)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDLogLine *logline=NULL;
 
   //
@@ -905,7 +915,7 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 			(const char *)import_table,
 			start_start_hour,start_start_secs/1000,
 			end_start_secs/1000);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if((id=e->nextId())>next_id) {
       next_id=id;
@@ -1045,23 +1055,23 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
 			(const char *)import_table,
 			start_start_hour,start_start_secs/1000,
 			end_start_secs/1000);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Autofill
   //
+  QTime end_time=link_logline->startTime(RDLogLine::Logged).
+    addMSecs(link_logline->linkLength());
   if(event_use_autofill&&(event_start_time<=time)) {
     QTime fill_start_time=time;
-    QTime end_time=link_logline->startTime(RDLogLine::Logged).
-      addMSecs(link_logline->linkLength());
     sql=QString().
       sprintf("select AUTOFILLS.CART_NUMBER,CART.FORCED_LENGTH from\
                AUTOFILLS left join CART on AUTOFILLS.CART_NUMBER=CART.NUMBER\
                where (AUTOFILLS.SERVICE=\"%s\")&&(CART.FORCED_LENGTH<=%d)&&\
                (CART.FORCED_LENGTH>0) order by CART.FORCED_LENGTH desc",
 	      (const char *)svcname,time.msecsTo(end_time));
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     bool fit=true;
     while(fit) {
       fit=false;
@@ -1095,30 +1105,33 @@ bool RDEventLine::linkLog(RDLogEvent *e,int next_id,const QString &svcname,
       }
     }
     delete q;
+  }
 
-    if(event_autofill_slop>=0) {
-      int slop=QTime().msecsTo(end_time)-QTime().msecsTo(time);
-      if(abs(slop)>=event_autofill_slop) {
-	if(slop>0) {
-	  *errors+=QString().
-	    sprintf("  %s -- \"%s\" is underscheduled by %s.\n",
-		    (const char *)time.toString("hh:mm:ss"),
-		    (const char *)event_name,
-		    (const char *)QTime().addMSecs(slop).
-		    toString("hh:mm:ss"));
-	}
-	else {
-	  *errors+=QString().
-	    sprintf("  %s -- Autofill event \"%s\" is overscheduled by %s.\n",
-		    (const char *)time.toString("hh:mm:ss"),
-		    (const char *)event_name,
-		    (const char *)QTime().addMSecs(-slop).
-		    toString("hh:mm:ss"));
-	}
+  //
+  // Fill Check
+  //
+  if(event_autofill_slop>=0) {
+    int slop=QTime().msecsTo(end_time)-QTime().msecsTo(time);
+    if(abs(slop)>=event_autofill_slop) {
+      if(slop>0) {
+	*errors+=QString().
+	  sprintf("  %s -- \"%s\" is underscheduled by %s.\n",
+		  (const char *)time.toString("hh:mm:ss"),
+		  (const char *)event_name,
+		  (const char *)QTime().addMSecs(slop).
+		  toString("hh:mm:ss"));
+      }
+      else {
+	*errors+=QString().
+	  sprintf("  %s -- \"%s\" is overscheduled by %s.\n",
+		  (const char *)time.toString("hh:mm:ss"),
+		  (const char *)event_name,
+		  (const char *)QTime().addMSecs(-slop).
+		  toString("hh:mm:ss"));
       }
     }
   }
-
+  
   return false;
 }
 
