@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlivewire.cpp,v 1.3 2008/09/30 18:19:39 fredg Exp $
+//      $Id: rdlivewire.cpp,v 1.3.2.2 2009/02/24 23:40:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,7 @@
 //
 
 #include <stdlib.h>
+#include <syslog.h>
 
 #include <qsignalmapper.h>
 
@@ -190,7 +191,7 @@ void RDLiveWire::gpiSet(int slot,int line,unsigned interval)
       }
     }
   }
-  cmd+="\"\n";
+  cmd+="\"\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpi_states[slot][line]=true;
   if(interval>0) {
@@ -216,7 +217,7 @@ void RDLiveWire::gpiReset(int slot,int line,unsigned interval)
       }
     }
   }
-  cmd+="\"\n";
+  cmd+="\"\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpi_states[slot][line]=false;
   if(interval>0) {
@@ -242,7 +243,7 @@ void RDLiveWire::gpoSet(int slot,int line,unsigned interval)
       }
     }
   }
-  cmd+="\n";
+  cmd+="\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpo_states[slot][line]=true;
   if(interval>0) {
@@ -268,7 +269,7 @@ void RDLiveWire::gpoReset(int slot,int line,unsigned interval)
       }
     }
   }
-  cmd+="\n";
+  cmd+="\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpo_states[slot][line]=false;
   if(interval>0) {
@@ -281,7 +282,7 @@ void RDLiveWire::gpoReset(int slot,int line,unsigned interval)
 void RDLiveWire::setRoute(int src_num,int dest_slot) const
 {
   QString str;
-  str=QString().sprintf("DST %d ADDR:\"239.192.%d.%d\"\n",
+  str=QString().sprintf("DST %d ADDR:\"239.192.%d.%d\"\r\n",
 			dest_slot+1,src_num/256,src_num%256);
   live_socket->writeBlock(str,str.length());
 }
@@ -295,7 +296,7 @@ void RDLiveWire::connectedData()
   }
   str+="\n";
   live_socket->writeBlock(str,str.length());
-  live_socket->writeBlock("VER\n",4);
+  live_socket->writeBlock("VER\r\n",4);
 }
 
 
@@ -422,7 +423,7 @@ void RDLiveWire::gpoTimeoutData(int id)
       }
     }
   }
-  cmd+="\n";
+  cmd+="\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpo_states[chan][line]=!live_gpo_states[chan][line];
 }
@@ -430,7 +431,7 @@ void RDLiveWire::gpoTimeoutData(int id)
 
 void RDLiveWire::watchdogData()
 {
-  live_socket->writeBlock("VER\n",4);
+  live_socket->writeBlock("VER\r\n",4);
 }
 
 
@@ -460,7 +461,6 @@ void RDLiveWire::resetConnectionData()
 
 void RDLiveWire::DespatchCommand(const QString &cmd)
 {
-  printf("DespatchCommand(%s)\n",(const char *)cmd);
   int offset=cmd.find(" ");
   QString opcode=cmd.left(offset);
   QString str;
