@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.cpp,v 1.107 2008-05-12 13:39:45 fredg Exp $
+//      $Id: rdlog_line.cpp,v 1.107.2.3 2009/04/13 16:07:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,34 @@ RDLogLine::RDLogLine()
 }
 
 
+RDLogLine::RDLogLine(unsigned cartnum)
+{
+  QString sql;
+  RDSqlQuery *q;
+
+  clear();
+  log_cart_number=cartnum;
+  sql=QString().sprintf("select GROUP_NAME,TITLE,ARTIST,ALBUM,YEAR,LABEL,\
+                         CLIENT,AGENCY,COMPOSER,PUBLISHER,USER_DEFINED \
+                         from CART where NUMBER=%u",log_cart_number);
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    log_group_name=q->value(0).toString();
+    log_title=q->value(1).toString();
+    log_artist=q->value(2).toString();
+    log_album=q->value(3).toString();
+    log_year=QDate(q->value(4).toInt(),1,1);
+    log_label=q->value(5).toString();
+    log_client=q->value(6).toString();
+    log_agency=q->value(7).toString();
+    log_composer=q->value(8).toString();
+    log_publisher=q->value(9).toString();
+    log_user_defined=q->value(10).toString();
+  }
+  delete q;
+}
+
+
 void RDLogLine::clear()
 {
   log_id=-1;
@@ -1384,7 +1412,7 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 	if(log_cut_name.isEmpty()) {
 	  delete cart;
 #ifndef WIN32
-	  syslog(LOG_USER|LOG_WARNING,"RDLogLine::setEvent(): RDCut::selectCut() failed, CART=%06u",log_cart_number);
+	  // syslog(LOG_USER|LOG_WARNING,"RDLogLine::setEvent(): RDCut::selectCut() failed, CART=%06u",log_cart_number);
 #endif  // WIN32
 	  log_state=RDLogLine::NoCut;
 	  return RDLogLine::NoCut;
@@ -1456,7 +1484,7 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
                                    log_start_point[RDLogLine::LogPointer];
           }
           else {
-	  log_effective_length=q->value(0).toUInt();
+	    log_effective_length=q->value(0).toUInt();
           }
 	  log_segue_start_point[0]=q->value(3).toInt();
 	  log_segue_end_point[0]=q->value(4).toInt();
@@ -1611,7 +1639,6 @@ void RDLogLine::loadCart(int cartnum,RDLogLine::TransType next_type,int mach,
   log_usage_code=(RDCart::UsageCode)q->value(23).toInt();
   log_average_segue_length=q->value(24).toInt();
   log_group_color=QColor(q->value(25).toString());
-  log_play_position_changed=false;
   log_play_source=RDLogLine::UnknownSource;
   if(type!=RDLogLine::NoTrans) {
     log_trans_type=type;
