@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2003-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdplay_deck.cpp,v 1.73 2007/12/29 18:16:10 fredg Exp $
+//      $Id: rdplay_deck.cpp,v 1.81.2.2 2009/04/27 14:40:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -170,22 +170,50 @@ bool RDPlayDeck::setCart(RDLogLine *logline,bool rotate)
     play_audio_point[0]=logline->startPoint();
     play_audio_point[1]=logline->endPoint(RDLogLine::LogPointer);
   }
-  play_audio_length=play_audio_point[1]-play_audio_point[0];
-  if(logline->segueStartPoint(RDLogLine::AutoPointer)<0) {
-    play_point_value[RDPlayDeck::Segue][0]=play_cut->segueStartPoint();
-    play_point_value[RDPlayDeck::Segue][1]=play_cut->segueEndPoint();
+  if(play_timescale_active) {
+    play_timescale_speed=
+      (int)(RD_TIMESCALE_DIVISOR*(double)(play_audio_point[1]-
+					  play_audio_point[0])/
+      (double)play_forced_length);
+    if((((double)play_timescale_speed)<
+	(RD_TIMESCALE_DIVISOR*RD_TIMESCALE_MIN))||
+       (((double)play_timescale_speed)>
+	(RD_TIMESCALE_DIVISOR*RD_TIMESCALE_MAX))) {
+      play_timescale_speed=RD_TIMESCALE_DIVISOR;
+      play_timescale_active=false;
+    }
   }
   else {
-    play_point_value[RDPlayDeck::Segue][0]=logline->
-      segueStartPoint(RDLogLine::AutoPointer);
-    play_point_value[RDPlayDeck::Segue][1]=logline->
-      segueEndPoint(RDLogLine::AutoPointer);
+    play_timescale_speed=RD_TIMESCALE_DIVISOR;
+  }
+  play_audio_length=play_audio_point[1]-play_audio_point[0];
+  if(logline->segueStartPoint(RDLogLine::AutoPointer)<0) {
+    play_point_value[RDPlayDeck::Segue][0]=
+      (int)((double)play_cut->segueStartPoint());
+    play_point_value[RDPlayDeck::Segue][1]=
+      (int)((double)play_cut->segueEndPoint());
+  }
+  else {
+    play_point_value[RDPlayDeck::Segue][0]=
+      (int)((double)logline->segueStartPoint(RDLogLine::AutoPointer));
+    play_point_value[RDPlayDeck::Segue][1]=
+      (int)((double)logline->segueEndPoint(RDLogLine::AutoPointer));
   }
   play_point_gain=logline->segueGain();
-  play_point_value[RDPlayDeck::Hook][0]=play_cut->hookStartPoint();
-  play_point_value[RDPlayDeck::Hook][1]=play_cut->hookEndPoint();
-  play_point_value[RDPlayDeck::Talk][0]=play_cut->talkStartPoint();
-  play_point_value[RDPlayDeck::Talk][1]=play_cut->talkEndPoint();
+  play_point_value[RDPlayDeck::Hook][0]=
+    (int)((double)play_cut->hookStartPoint());
+  play_point_value[RDPlayDeck::Hook][1]=
+    (int)((double)play_cut->hookEndPoint());
+  logline->setHookStartPoint(play_point_value[RDPlayDeck::Hook][0]);
+  logline->setHookEndPoint(play_point_value[RDPlayDeck::Hook][1]);
+  play_point_value[RDPlayDeck::Talk][0]=
+    (int)((double)play_cut->talkStartPoint()*
+	  (RD_TIMESCALE_DIVISOR/(double)play_timescale_speed));
+  play_point_value[RDPlayDeck::Talk][1]=
+    (int)((double)play_cut->talkEndPoint()*
+	  (RD_TIMESCALE_DIVISOR/(double)play_timescale_speed));
+  logline->setTalkStartPoint(play_point_value[RDPlayDeck::Talk][0]);
+  logline->setTalkEndPoint(play_point_value[RDPlayDeck::Talk][1]);
   if(logline->fadeupPoint(RDLogLine::LogPointer)<0) {
     play_fade_point[0]=play_cut->fadeupPoint();
     play_fade_gain[0]=RD_FADE_DEPTH;
@@ -204,13 +232,18 @@ bool RDPlayDeck::setCart(RDLogLine *logline,bool rotate)
   }
   play_duck_gain[0]=logline->duckUpGain();
   play_duck_gain[1]=logline->duckDownGain();
+
+/*
   if(play_timescale_active) {
     play_timescale_speed=
-      1000*(play_audio_point[1]-play_audio_point[0])/play_forced_length;
+      (int)(1000*(double)(play_audio_point[1]-play_audio_point[0])/
+      (double)play_forced_length);
   }
   else {
     play_timescale_speed=1000;
   }
+*/
+
   if(play_state!=RDPlayDeck::Paused) {
     if(!play_cae->loadPlay(play_card,play_cut->cutName(),
 			   &play_stream,&play_handle)) {
@@ -354,7 +387,8 @@ void RDPlayDeck::reset()
 }
 
 
-void RDPlayDeck::play(unsigned pos,int segue_start,int segue_end,int duck_up_end)
+void RDPlayDeck::play(unsigned pos,int segue_start,int segue_end,
+		      int duck_up_end)
 {
   int fadeup;
   play_cut_gain=play_cut->playGain();
@@ -392,10 +426,12 @@ void RDPlayDeck::play(unsigned pos,int segue_start,int segue_end,int duck_up_end
     play_cae->setOutputVolume(play_card,play_stream,i,RD_MUTE_DEPTH);
   }
   if((play_fade_point[0]==-1)||(play_fade_point[0]==play_audio_point[0])||
-     ((fadeup=play_fade_point[0]-play_audio_point[0]-pos)<=0)||(play_state==RDPlayDeck::Paused)) {
+     ((fadeup=play_fade_point[0]-play_audio_point[0]-pos)<=0)||
+     (play_state==RDPlayDeck::Paused)) {
     if((play_fade_point[1]==-1)||((fadeup=pos-play_fade_point[1])<=0)||
        (play_state==RDPlayDeck::Paused)) {
-      play_cae->setOutputVolume(play_card,play_stream,play_port,play_ducked+play_cut_gain+play_duck_level);
+      play_cae->setOutputVolume(play_card,play_stream,play_port,
+				play_ducked+play_cut_gain+play_duck_level);
       play_cae->fadeOutputVolume(play_card,play_stream,play_port,
 				 play_ducked+play_cut_gain+play_duck_level,10);
     }
@@ -403,9 +439,11 @@ void RDPlayDeck::play(unsigned pos,int segue_start,int segue_end,int duck_up_end
       int level=play_fade_gain[1]*((int)pos-play_fade_point[1])/
 			(play_audio_point[1]-play_fade_point[1]);
       play_cae->
-	setOutputVolume(play_card,play_stream,play_port,level+play_cut_gain+play_duck_level);
+	setOutputVolume(play_card,play_stream,play_port,
+			level+play_cut_gain+play_duck_level);
       play_cae->fadeOutputVolume(play_card,play_stream,play_port,
-				 play_fade_gain[1]+play_cut_gain+play_duck_level,
+				 play_fade_gain[1]+play_cut_gain+
+				 play_duck_level,
 				 play_audio_point[1]-(int)pos);
     }
   }
@@ -414,18 +452,24 @@ void RDPlayDeck::play(unsigned pos,int segue_start,int segue_end,int duck_up_end
 		      (play_fade_point[0]-play_audio_point[0]));
     if (level>play_ducked) {
     play_cae->
-      setOutputVolume(play_card,play_stream,play_port,play_ducked+play_cut_gain+play_duck_level);
-    play_cae->fadeOutputVolume(play_card,play_stream,play_port,play_ducked+play_cut_gain+play_duck_level,fadeup);
+      setOutputVolume(play_card,play_stream,play_port,
+		      play_ducked+play_cut_gain+play_duck_level);
+    play_cae->fadeOutputVolume(play_card,play_stream,play_port,
+			       play_ducked+play_cut_gain+play_duck_level,
+			       fadeup);
     }
     else {
     play_cae->
-      setOutputVolume(play_card,play_stream,play_port,level+play_cut_gain+play_duck_level);
-    play_cae->fadeOutputVolume(play_card,play_stream,play_port,play_ducked+play_cut_gain+play_duck_level,fadeup);
+      setOutputVolume(play_card,play_stream,play_port,
+		      level+play_cut_gain+play_duck_level);
+    play_cae->fadeOutputVolume(play_card,play_stream,play_port,
+			       play_ducked+play_cut_gain+play_duck_level,
+			       fadeup);
     }
   }
   play_cae->
     play(play_handle,
-	 (int)(1000.0*(double)(play_audio_point[1]-play_audio_point[0]-pos)/
+	 (int)(100000.0*(double)(play_audio_point[1]-play_audio_point[0]-pos)/
 	 (double)play_timescale_speed),
 	 play_timescale_speed,false);
   play_start_time=QTime::currentTime();
@@ -623,9 +667,6 @@ void RDPlayDeck::positionTimerData()
   if(play_current_position<0) {       // Handle crossing midnight!
     play_current_position+=86400000;
   }
-  if(play_current_position>play_audio_length) {
-    play_current_position=play_audio_length-1;
-  }
   emit position(play_id,play_current_position);
 }
 
@@ -669,18 +710,23 @@ void RDPlayDeck::duckTimerData()
 
 void RDPlayDeck::StartTimers(int offset)
 {
+  int audio_point;
+
   for(int i=0;i<RDPlayDeck::SizeOf;i++) {
     play_point_state[i]=false;
     if(play_point_value[i][0]!=-1) {
-      if((play_point_value[i][0]-play_audio_point[0]-offset)>=0) {
+      audio_point=(int)
+	(RD_TIMESCALE_DIVISOR*(double)play_audio_point[0]/
+	 (double)play_timescale_speed);
+      if((play_point_value[i][0]-audio_point-offset)>=0) {
 	play_point_timer[i]->
-	  start(play_point_value[i][0]-play_audio_point[0]-offset,true);
+	  start(play_point_value[i][0]-audio_point-offset,true);
       }
       else {
-	if((play_point_value[i][1]-play_audio_point[0]-offset)>=0) {
+	if((play_point_value[i][1]-audio_point-offset)>=0) {
 	  play_point_state[i]=true;
 	  play_point_timer[i]->
-	    start(play_point_value[i][1]-play_audio_point[0]-offset,true);
+	    start(play_point_value[i][1]-audio_point-offset,true);
 	}
       }
     }
