@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdreport.cpp,v 1.23.2.2 2009/01/13 19:27:13 cvs Exp $
+//      $Id: rdreport.cpp,v 1.23.2.3 2009/08/08 16:26:05 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -448,6 +448,10 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 	ret=ExportSoundEx(startdate,enddate,mixname);
 	break;
 
+      case RDReport::RadioTraffic:
+	ret=ExportRadioTraffic(startdate,enddate,mixname);
+	break;
+
       default:
 	return false;
 	break;
@@ -479,6 +483,9 @@ QString RDReport::filterText(RDReport::ExportFilter filter)
       case RDReport::SoundExchange:
 	return QT_TR_NOOP("SoundExchange Statutory License Report");
 
+      case RDReport::RadioTraffic:
+	return QT_TR_NOOP("RadioTraffic.com Traffic Reconciliation");
+
       default:
 	break;
   }
@@ -509,19 +516,15 @@ bool RDReport::multipleDaysAllowed(RDReport::ExportFilter filter)
 {
   switch(filter) {
       case RDReport::CbsiDeltaFlex:
-	return false;
-
       case RDReport::TextLog:
+      case RDReport::RadioTraffic:
+      case RDReport::LastFilter:
 	return false;
 
       case RDReport::BmiEmr:
-	return true;
-
       case RDReport::SoundExchange:
+      case RDReport::Technical:
 	return true;
-
-      default:
-	break;
   }
   return true;
 }
@@ -531,16 +534,15 @@ bool RDReport::multipleMonthsAllowed(RDReport::ExportFilter filter)
 {
   switch(filter) {
       case RDReport::CbsiDeltaFlex:
-	return false;
-
       case RDReport::TextLog:
-	return false;
-
       case RDReport::BmiEmr:
+      case RDReport::RadioTraffic:
+      case RDReport::LastFilter:
 	return false;
 
-      default:
-	break;
+      case RDReport::SoundExchange:
+      case RDReport::Technical:
+	return true;
   }
   return true;
 }
