@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdstation.h,v 1.15 2007/12/12 19:20:38 fredg Exp $
+//      $Id: rdstation.h,v 1.17.2.1 2008/11/30 00:32:57 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,10 +30,19 @@ class RDStation
 {
  public:
   enum AudioDriver {None=0,Hpi=1,Jack=2,Alsa=3};
+  /**
+   * Enum to track the state of the broadcast applications security model.
+   * @see setBroadcastSecurity()
+   * @see broadcastSecurity()
+   */
+  enum BroadcastSecurityMode {
+        HostSec=0, /**< HostSec - original host (or no) security. */
+        UserSec=1  /**< UserSec - user based security. */
+      };
   enum Capability {HaveOggenc=0,HaveOgg123=1,HaveFlac=2,
 		   HaveLame=3,HaveMpg321=4};
   enum FilterMode {FilterSynchronous=0,FilterAsynchronous=1};
-  RDStation(QString name,bool create=false);
+  RDStation(const QString &name,bool create=false);
   ~RDStation();
   QString name() const;
   bool exists() const;
@@ -51,6 +60,21 @@ class RDStation
   void setBackupPath(QString path) const;
   int backupLife() const;
   void setBackupLife(int days) const;
+
+  /**
+   * Set the Broadcast applications (rdairplay, rdlogedit, rdlogmanager)
+   * security mode.
+   *
+   * @param mode An enum with the desired mode.
+   */
+  void setBroadcastSecurity(BroadcastSecurityMode mode);
+
+  /**
+   * Get the Broadcast applicaitons security mode.
+   *
+   * @return An enum with the current mode.
+   */
+  BroadcastSecurityMode broadcastSecurity() const;
   unsigned heartbeatCart() const;
   void setHeartbeatCart(unsigned cartnum) const;
   unsigned heartbeatInterval() const;
@@ -61,6 +85,8 @@ class RDStation
   void setEditorPath(const QString &cmd);
   RDStation::FilterMode filterMode() const;
   void setFilterMode(RDStation::FilterMode mode) const;
+  bool systemMaint() const;
+  void setSystemMaint(bool state) const;
   bool scanned() const;
   void setScanned(bool state) const;
   bool haveCapability(Capability cap) const;
@@ -78,10 +104,10 @@ class RDStation
   void setCardOutputs(int cardnum,int outputs) const;
 
  private:
-  void SetRow(QString param,QString value) const;
-  void SetRow(QString param,int value) const;
-  void SetRow(QString param,unsigned value) const;
-  void SetRow(QString param,bool value) const;
+  void SetRow(const QString &param,const QString &value) const;
+  void SetRow(const QString &param,int value) const;
+  void SetRow(const QString &param,unsigned value) const;
+  void SetRow(const QString &param,bool value) const;
   QString station_name;
   int time_offset;
   bool time_offset_valid;
