@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.h,v 1.22 2007/08/31 17:41:12 fredg Exp $
+//      $Id: rdsvc.h,v 1.22.2.2 2008/12/08 19:00:23 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -48,6 +48,10 @@ class RDSvc : public QObject
   void setTrackGroup(const QString &group) const;
   bool autoRefresh() const;
   void setAutoRefresh(bool state);
+  int defaultLogShelflife() const;
+  void setDefaultLogShelflife(int days) const;
+  int elrShelflife() const;
+  void setElrShelflife(int days) const;
   bool chainto() const;
   void setChainto(bool state) const;
   QString breakString() const;
