@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rduser.cpp,v 1.23 2008/08/04 19:05:34 fredg Exp $
+//      $Id: rduser.cpp,v 1.23.2.1 2009/04/07 13:59:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -450,12 +450,13 @@ QStringList RDUser::services() const
 
   if (adminConfig()) {
     sql=QString().sprintf("SELECT NAME FROM SERVICES" );
-  } else {
-    sql=QString().sprintf("SELECT DISTINCT SERVICE_NAME \
-                            FROM USER_PERMS, AUDIO_PERMS \
-                            WHERE USER_PERMS.USER_NAME='%s' \
-                             AND USER_PERMS.GROUP_NAME=AUDIO_PERMS.GROUP_NAME;",
-                          (const char *)user_name );
+  } 
+  else {
+    sql=QString().sprintf("select distinct AUDIO_PERMS.SERVICE_NAME \
+                           from USER_PERMS left join AUDIO_PERMS \
+                           on USER_PERMS.GROUP_NAME=AUDIO_PERMS.GROUP_NAME \
+                           where USER_PERMS.USER_NAME=\"%s\"",
+			  (const char *)RDEscapeString(user_name));
   }
   
   q=new RDSqlQuery(sql);
