@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_report.cpp,v 1.17 2007/02/14 21:51:02 fredg Exp $
+//      $Id: edit_report.cpp,v 1.19 2007/10/04 20:53:29 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,13 +31,9 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
 
+#include <rddb.h>
 #include <rd.h>
-#include <rduser.h>
-#include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
 #include <edit_report.h>
@@ -50,7 +46,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString str;
 
   //
@@ -301,7 +297,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   //
   // Service Selector
   //
-  edit_service_sel=new RListSelector(this,"edit_service_sel");
+  edit_service_sel=new RDListSelector(this,"edit_service_sel");
   edit_service_sel->
     setGeometry((sizeHint().width()-edit_service_sel->sizeHint().width())/2,
 		268,edit_service_sel->sizeHint().width(),
@@ -312,7 +308,7 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   //
   // Station Selector
   //
-  edit_station_sel=new RListSelector(this,"edit_station_sel");
+  edit_station_sel=new RDListSelector(this,"edit_station_sel");
   edit_station_sel->
     setGeometry((sizeHint().width()-edit_station_sel->sizeHint().width())/2,
 		378,edit_station_sel->sizeHint().width(),
@@ -376,14 +372,14 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   sql=QString().sprintf("select SERVICE_NAME from REPORT_SERVICES \
                          where REPORT_NAME=\"%s\"",
 			(const char *)edit_report->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     edit_service_sel->destInsertItem(q->value(0).toString());
   }
   delete q;
 
   sql=QString().sprintf("select NAME from SERVICES");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if(edit_service_sel->destFindItem(q->value(0).toString())==0) {
       edit_service_sel->sourceInsertItem(q->value(0).toString());
@@ -394,14 +390,14 @@ EditReport::EditReport(QString rptname,QWidget *parent,const char *name)
   sql=QString().sprintf("select STATION_NAME from REPORT_STATIONS \
                          where REPORT_NAME=\"%s\"",
 			(const char *)edit_report->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     edit_station_sel->destInsertItem(q->value(0).toString());
   }
   delete q;
 
   sql=QString().sprintf("select NAME from STATIONS");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if(edit_station_sel->destFindItem(q->value(0).toString())==0) {
       edit_station_sel->sourceInsertItem(q->value(0).toString());
@@ -447,7 +443,7 @@ void EditReport::genericEventsToggledData(bool state)
 void EditReport::okData()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   edit_report->setDescription(edit_description_edit->text());
   edit_report->
@@ -482,7 +478,7 @@ void EditReport::okData()
 where REPORT_NAME=\"%s\" && SERVICE_NAME=\"%s\"",
 			  (const char *)edit_report->name(),
 			  (const char *)edit_service_sel->destText(i));
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()==0) {
       delete q;
       sql=QString().
@@ -490,7 +486,7 @@ where REPORT_NAME=\"%s\" && SERVICE_NAME=\"%s\"",
                  values (\"%s\",\"%s\")",
 			    (const char *)edit_report->name(),
 			    (const char *)edit_service_sel->destText(i));
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
     }
     delete q;
   }
@@ -504,7 +500,7 @@ where REPORT_NAME=\"%s\" && SERVICE_NAME=\"%s\"",
     sql+=QString().sprintf(" && SERVICE_NAME<>\"%s\"",
 			   (const char *)edit_service_sel->destText(i));
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
 
@@ -517,7 +513,7 @@ where REPORT_NAME=\"%s\" && SERVICE_NAME=\"%s\"",
 where REPORT_NAME=\"%s\" && STATION_NAME=\"%s\"",
 			  (const char *)edit_report->name(),
 			  (const char *)edit_station_sel->destText(i));
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()==0) {
       delete q;
       sql=QString().
@@ -525,7 +521,7 @@ where REPORT_NAME=\"%s\" && STATION_NAME=\"%s\"",
                  values (\"%s\",\"%s\")",
 			    (const char *)edit_report->name(),
 			    (const char *)edit_station_sel->destText(i));
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
     }
     delete q;
   }
@@ -539,7 +535,7 @@ where REPORT_NAME=\"%s\" && STATION_NAME=\"%s\"",
     sql+=QString().sprintf(" && STATION_NAME<>\"%s\"",
 			   (const char *)edit_station_sel->destText(i));
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
 
