@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_matrices.cpp,v 1.23 2007/10/23 18:21:57 fredg Exp $
+//      $Id: list_matrices.cpp,v 1.25.2.1 2009/08/07 01:14:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -269,6 +269,24 @@ void ListMatrices::DeleteMatrix(int matrix)
 			matrix);
   q=new RDSqlQuery(sql);
   delete q;
+  sql=QString().sprintf("delete from SWITCHER_NODES where \
+                         STATION_NAME=\"%s\" && MATRIX=%d",
+			(const char *)list_station,
+			matrix);
+  q=new RDSqlQuery(sql);
+  delete q;
+  sql=QString().sprintf("delete from GPIS where \
+                         STATION_NAME=\"%s\" && MATRIX=%d",
+			(const char *)list_station,
+			matrix);
+  q=new RDSqlQuery(sql);
+  delete q;
+  sql=QString().sprintf("delete from GPOS where \
+                         STATION_NAME=\"%s\" && MATRIX=%d",
+			(const char *)list_station,
+			matrix);
+  q=new RDSqlQuery(sql);
+  delete q;
 }
 
 
@@ -378,6 +396,12 @@ QString ListMatrices::TypeString(RDMatrix::Type type)
       case RDMatrix::LiveWire:
 	return QString(tr("Axia LiveWire"));
 
+      case RDMatrix::Quartz1:
+	return QString(tr("Quartz Type 1"));
+
+      case RDMatrix::BtSs44:
+	return QString(tr("BroadcastTools SS4.4"));
+
       default:
 	return QString(tr("Unknown"));
   }
