@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdadmin.cpp,v 1.64 2008/08/18 20:26:16 fredg Exp $
+//      $Id: rdadmin.cpp,v 1.64.2.2 2009/04/30 14:54:09 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -54,6 +54,7 @@
 #include <list_reports.h>
 #include <list_feeds.h>
 #include <list_schedcodes.h>
+#include <edit_settings.h>
 #include <rdadmin.h>
 #include <opendb.h>
 #include <info_dialog.h>
@@ -270,13 +271,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(podcasts_button,SIGNAL(clicked()),this,SLOT(podcastsData()));
 
   //
-  // System Info Button
+  // System Wide Settings Button
   //
-  QPushButton *info_button=new QPushButton(this,"info_button");
-  info_button->setGeometry(190,120,80,60);
-  info_button->setFont(font);
-  info_button->setText(tr("System\nInfo"));
-  connect(info_button,SIGNAL(clicked()),this,SLOT(systemInfoData()));
+  QPushButton *system_button=new QPushButton(this,"system_button");
+  system_button->setGeometry(190,120,80,60);
+  system_button->setFont(font);
+  system_button->setText(tr("System\nSettings"));
+  connect(system_button,SIGNAL(clicked()),this,SLOT(systemSettingsData()));
 
   //
   // Manage Scheduler Codes Button
@@ -287,11 +288,20 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   schedcodes_button->setText(tr("Scheduler\nCodes"));
   connect(schedcodes_button,SIGNAL(clicked()),this,SLOT(manageSchedCodes()));
 
+  //
+  // System Info Button
+  //
+  QPushButton *info_button=new QPushButton(this,"info_button");
+  info_button->setGeometry(55,190,80,60);
+  info_button->setFont(font);
+  info_button->setText(tr("System\nInfo"));
+  connect(info_button,SIGNAL(clicked()),this,SLOT(systemInfoData()));
+
   //
   // Backup Database Button
   //
   QPushButton *backup_button=new QPushButton(this,"backup_button");
-  backup_button->setGeometry(100,190,80,60);
+  backup_button->setGeometry(145,190,80,60);
   backup_button->setFont(font);
   backup_button->setText(tr("&Backup\nDatabase"));
   connect(backup_button,SIGNAL(clicked()),this,SLOT(backupData()));
@@ -300,7 +310,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Restore Database Button
   //
   QPushButton *restore_button=new QPushButton(this,"restore_button");
-  restore_button->setGeometry(190,190,80,60);
+  restore_button->setGeometry(235,190,80,60);
   restore_button->setFont(font);
   restore_button->setText(tr("&Restore\nDatabase"));
   connect(restore_button,SIGNAL(clicked()),this,SLOT(restoreData()));
@@ -374,6 +384,14 @@ void MainWidget::manageStationsData()
 }
 
 
+void MainWidget::systemSettingsData()
+{
+  EditSettings *edit_settings=new EditSettings(this,"edit_settings");
+  edit_settings->exec();
+  delete edit_settings;
+}
+
+
 void MainWidget::backupData()
 {
   QString filename;
@@ -513,7 +531,7 @@ int gui_main(int argc,char *argv[])
 
   QTranslator rd(0);
   rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
-	     QTextCodec::locale(),".");
+	  QTextCodec::locale(),".");
   a.installTranslator(&rd);
 
   QTranslator rdhpi(0);
