@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.cpp,v 1.43 2008/04/02 16:47:25 fredg Exp $
+//      $Id: edit_event.cpp,v 1.43.2.1 2009/03/30 19:02:52 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -249,6 +249,26 @@ EditEvent::EditEvent(LogPlay *log,QWidget *parent,const char *name)
   edit_start_button->setText(tr("Start"));
   connect(edit_start_button,SIGNAL(clicked()),this,SLOT(startClickedData()));
 
+  //
+  // End Marker Control
+  //
+  edit_end_button=new RDPushButton(this,"button");
+  edit_end_button->setToggleButton(true);
+  edit_end_button->setGeometry(105,265,66,45);
+  edit_end_button->setFlashColor(backgroundColor());
+  edit_end_button->setFlashPeriod(EVENT_EDITOR_BUTTON_FLASH_PERIOD);
+  edit_end_button->setPalette(QPalette(QColor(EVENT_EDITOR_START_MARKER),
+				       backgroundColor()));
+  edit_end_button->setFont(button_font);
+  edit_end_button->setText(tr("End"));
+  connect(edit_end_button,SIGNAL(clicked()),this,SLOT(endClickedData()));
+
+  //
+  // Audition Stop Timer
+  //
+  edit_audition_timer=new QTimer(this,"edit_audition_timer");
+  connect(edit_audition_timer,SIGNAL(timeout()),this,SLOT(auditionTimerData()));
+
   //
   //  Ok Button
   //
@@ -366,21 +386,23 @@ int EditEvent::exec(int line)
   switch(edit_logline->type()) {
       case RDLogLine::Cart:
 	if((edit_logline->cutNumber()<1)||
-	   (edit_logline->effectiveLength()<=0)) {
+	   (edit_logline->forcedLength()<=0)) {
 	  ShowAudioControls(false);
 	}
 	else {
-	  edit_position_bar->setLength(edit_logline->effectiveLength());
+	  edit_position_bar->setLength(edit_logline->forcedLength());
 	  edit_start_button->setOn(false);
 	  ShowAudioControls(true);
           if(!(edit_logline->status()==RDLogLine::Scheduled) && 
               !(edit_logline->status()==RDLogLine::Paused)) {
               edit_start_button->hide();
+              edit_end_button->hide();
             }
           else {
               edit_start_button->show();
-            }
-	  edit_slider->setRange(0,edit_logline->effectiveLength());
+              edit_end_button->show();
+	  }
+	  edit_slider->setRange(0,edit_logline->forcedLength());
 	  edit_slider->setValue(edit_logline->playPosition());
 	  sliderChangedData(edit_logline->playPosition());
 	  startClickedData();
@@ -389,6 +411,8 @@ int EditEvent::exec(int line)
 	    setMarker(MarkerBar::Play,edit_logline->playPosition());
 	  edit_position_bar->
 	    setMarker(MarkerBar::Start,edit_logline->playPosition());
+	  edit_position_bar->
+	    setMarker(MarkerBar::End,edit_logline->endPoint());
 	  edit_slider->setValue(edit_logline->playPosition());
 	  UpdateCounters();
 	}
@@ -474,7 +498,12 @@ void EditEvent::sliderChangedData(int pos)
     edit_position_bar->setMarker(MarkerBar::Start,pos);
   }
   else {
-    edit_position_bar->setMarker(MarkerBar::Play,pos);
+    if(edit_end_button->isOn()) {
+      edit_position_bar->setMarker(MarkerBar::End,pos);
+    }
+    else {
+      edit_position_bar->setMarker(MarkerBar::Play,pos);
+    }
   }
   UpdateCounters();
 }
@@ -501,6 +530,7 @@ void EditEvent::sliderReleasedData()
 void EditEvent::auditionButtonData()
 {
   int start_pos=edit_slider->value();
+  int play_len=-1;
 
   if(edit_play_deck->state()==RDPlayDeck::Playing) {
     return;
@@ -511,17 +541,37 @@ void EditEvent::auditionButtonData()
     return;
   }
   if(edit_start_button->isOn()) {
+    if(edit_play_deck->state()==RDPlayDeck::Stopped) {
+      start_pos=edit_position_bar->marker(MarkerBar::Start);
+    }
     if(edit_play_deck->state()==RDPlayDeck::Paused) {
       start_pos=edit_play_deck->currentPosition();
     }
+    play_len=edit_position_bar->marker(MarkerBar::End)-start_pos;
   }
   else {
-    if((edit_play_deck->state()==RDPlayDeck::Stopped)&&
-       (!edit_slider_pressed)) {
-      edit_start_pos=edit_slider->value();
+    if(edit_end_button->isOn()) {
+      if(edit_play_deck->state()==RDPlayDeck::Stopped) {
+	play_len=rdairplay_conf->auditionPreroll();
+	if(play_len>(edit_position_bar->marker(MarkerBar::End)-
+		     edit_position_bar->marker(MarkerBar::Start))) {
+	  play_len=edit_position_bar->marker(MarkerBar::End)-
+	    edit_position_bar->marker(MarkerBar::Start);
+	}
+	start_pos=edit_position_bar->marker(MarkerBar::End)-play_len;	  
+      }
+    }
+    else {
+      if((edit_play_deck->state()==RDPlayDeck::Stopped)&&
+	 (!edit_slider_pressed)) {
+	edit_start_pos=edit_slider->value();
+      }
     }
   }
   edit_play_deck->play(start_pos);
+  if(play_len>=0) {
+    edit_audition_timer->start(play_len,true);
+  }
   QString rml=rdairplay_conf->startRml(3);
   if(!rml.isEmpty()) {
     rdevent_player->exec(edit_logline->resolveWildcards(rml));
@@ -585,13 +635,19 @@ void EditEvent::positionData(int id,int msecs)
     return;
   }
   edit_position_bar->setMarker(MarkerBar::Play,msecs);
-  if(!edit_start_button->isOn()) {
+  if((!edit_start_button->isOn())&&(!edit_end_button->isOn())) {
     edit_slider->setValue(msecs);
   }
   UpdateCounters();
 }
 
 
+void EditEvent::auditionTimerData()
+{
+  edit_play_deck->stop();
+}
+
+
 void EditEvent::okData()
 {
   if(edit_play_deck->state()==RDPlayDeck::Playing) {
@@ -645,6 +701,12 @@ void EditEvent::okData()
 	setPlayPosition(edit_position_bar->marker(MarkerBar::Start));
       edit_logline->setPlayPositionChanged(true);
     }
+    if((unsigned)edit_position_bar->marker(MarkerBar::End)!=
+       edit_logline->endPoint()) {
+      edit_logline->setEndPoint(edit_position_bar->marker(MarkerBar::End),
+				RDLogLine::LogPointer);
+      edit_logline->setPlayPositionChanged(true);
+    }
     edit_log->lineModified(edit_line);
   }
   done(0);
@@ -661,8 +723,41 @@ void EditEvent::cancelData()
 
 
 void EditEvent::startClickedData()
+{
+  if(edit_end_button->isOn()) {
+    edit_end_button->toggle();
+    SetEndMode(false);
+  }
+  SetStartMode(edit_start_button->isOn());
+}
+
+
+void EditEvent::endClickedData()
 {
   if(edit_start_button->isOn()) {
+    edit_start_button->toggle();
+    SetStartMode(false);
+  }
+  SetEndMode(edit_end_button->isOn());
+}
+
+
+void EditEvent::closeEvent(QCloseEvent *e)
+{
+  cancelData();
+}
+
+
+void EditEvent::SetStartMode(bool state)
+{
+  if(state) {
+    edit_slider->setRange(0,edit_position_bar->marker(MarkerBar::End));
+    edit_slider->setGeometry(75,140,
+			     (int)(50.0+((double)(sizeHint().width()-200)*
+					 (double)edit_position_bar->
+					 marker(MarkerBar::End)/
+					 (double)edit_logline->
+					 forcedLength())),50);
     edit_slider->setValue(edit_position_bar->marker(MarkerBar::Start));
     edit_slider->setKnobColor(EVENT_EDITOR_START_MARKER);
     edit_audition_button->setAccentColor(EVENT_EDITOR_START_MARKER);
@@ -672,6 +767,8 @@ void EditEvent::startClickedData()
     UpdateCounters();
   }
   else {
+    edit_slider->setRange(0,edit_logline->forcedLength());
+    edit_slider->setGeometry(75,140,sizeHint().width()-150,50);
     edit_slider->setValue(edit_position_bar->marker(MarkerBar::Play));
     edit_slider->setKnobColor(EVENT_EDITOR_PLAY_MARKER); 
     edit_audition_button->setAccentColor(EVENT_EDITOR_PLAY_MARKER);
@@ -683,9 +780,41 @@ void EditEvent::startClickedData()
 }
 
 
-void EditEvent::closeEvent(QCloseEvent *e)
+void EditEvent::SetEndMode(bool state)
 {
-  cancelData();
+  if(state) {
+    edit_slider->setRange(edit_position_bar->marker(MarkerBar::Start),
+			  edit_logline->forcedLength());
+    edit_slider->setGeometry((int)(75.0+(double)(sizeHint().width()-200)*
+				   (double)edit_position_bar->
+				   marker(MarkerBar::Start)/
+				   (double)edit_logline->forcedLength()),
+			     140,(int)(50.0+((double)(sizeHint().width()-200)*
+					     ((double)edit_logline->
+					      forcedLength()-
+					      (double)edit_position_bar->
+					      marker(MarkerBar::Start))/
+					     (double)edit_logline->
+					     forcedLength())),50);
+    edit_slider->setValue(edit_position_bar->marker(MarkerBar::End));
+    edit_slider->setKnobColor(EVENT_EDITOR_START_MARKER);
+    edit_audition_button->setAccentColor(EVENT_EDITOR_START_MARKER);
+    edit_end_button->setFlashingEnabled(true);
+    edit_up_label->setPalette(edit_start_color);
+    edit_down_label->setPalette(edit_start_color);
+    UpdateCounters();
+  }
+  else {
+    edit_slider->setRange(0,edit_logline->forcedLength());
+    edit_slider->setGeometry(75,140,sizeHint().width()-150,50);
+    edit_slider->setValue(edit_position_bar->marker(MarkerBar::Play));
+    edit_slider->setKnobColor(EVENT_EDITOR_PLAY_MARKER); 
+    edit_audition_button->setAccentColor(EVENT_EDITOR_PLAY_MARKER);
+    edit_end_button->setFlashingEnabled(false);
+    edit_up_label->setPalette(palette());
+    edit_down_label->setPalette(palette());
+    UpdateCounters();
+  }
 }
 
 
@@ -762,8 +891,13 @@ void EditEvent::Stopped(int id)
     edit_slider->setValue(edit_position_bar->marker(MarkerBar::Start));
   }
   else {
-    edit_position_bar->setMarker(MarkerBar::Play,edit_start_pos);
-    edit_slider->setValue(edit_start_pos);
+    if(edit_end_button->isOn()) {
+      edit_slider->setValue(edit_position_bar->marker(MarkerBar::End));
+    }
+    else {
+      edit_position_bar->setMarker(MarkerBar::Play,edit_start_pos);
+      edit_slider->setValue(edit_start_pos);
+    }
   }
 }
 
@@ -775,16 +909,28 @@ void EditEvent::UpdateCounters()
      setText(RDGetTimeLength(edit_position_bar->marker(MarkerBar::Start),true));
    edit_down_label->
      setText(RDGetTimeLength(edit_logline->
-			    effectiveLength()-edit_position_bar->
+			    forcedLength()-edit_position_bar->
 			    marker(MarkerBar::Start),true));
   }
   else {
-    edit_up_label->
-      setText(RDGetTimeLength(edit_position_bar->marker(MarkerBar::Play),true));
-    edit_down_label->
-      setText(RDGetTimeLength(edit_logline->
-			     effectiveLength()-edit_position_bar->
-			     marker(MarkerBar::Play),true));
+    if(edit_end_button->isOn()) {
+      edit_up_label->
+	setText(RDGetTimeLength(edit_position_bar->marker(MarkerBar::End),
+				true));
+      edit_down_label->
+	setText(RDGetTimeLength(edit_logline->
+				forcedLength()-edit_position_bar->
+				marker(MarkerBar::End),true));
+    }
+    else {
+      edit_up_label->
+	setText(RDGetTimeLength(edit_position_bar->marker(MarkerBar::Play),
+				true));
+      edit_down_label->
+	setText(RDGetTimeLength(edit_logline->
+				forcedLength()-edit_position_bar->
+				marker(MarkerBar::Play),true));
+    }
   }
 }
 
@@ -832,11 +978,11 @@ void EditEvent::mousePressEvent(QMouseEvent *e)
 
       case QMouseEvent::MidButton:
         if(edit_audition_button->isShown()) {
-          if(edit_logline->effectiveLength()>10000) {
+          if(edit_logline->forcedLength()>10000) {
             if(edit_play_deck->state()==RDPlayDeck::Playing) {
               edit_play_deck->pause();
               }
-            edit_slider->setValue((edit_logline->effectiveLength())-10000);
+            edit_slider->setValue((edit_logline->forcedLength())-10000);
             sliderChangedData(edit_slider->value());
             }
           auditionButtonData();
