@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_log.cpp,v 1.98 2007/10/04 20:53:32 dmills Exp $
+//      $Id: list_log.cpp,v 1.100.2.3 2009/03/26 20:27:57 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,12 +60,16 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_scroll=true;
   list_pause_allowed=allow_pause;
   list_playbutton_mode=ListLog::ButtonDisabled;
+  list_audition_head_playing=false;
+  list_audition_tail_playing=false;
 
   //
   // Create Fonts
   //
   QFont list_font=QFont("Helvetica",12,QFont::Normal);
   list_font.setPixelSize(12);
+  QFont label_font=QFont("Helvetica",12,QFont::Bold);
+  label_font.setPixelSize(12);
   QFont font=QFont("Helvetica",14,QFont::Bold);
   font.setPixelSize(14);
   QFont name_font=QFont("Helvetica",18,QFont::Bold);
@@ -131,9 +135,14 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
 
   list_log_list=new RDListView(this,"list_log_list");
   list_log_list->setFont(list_font);
-  list_log_list->setGeometry(0,0,sizeHint().width(),sizeHint().height()-60);
+  if(rdairplay_conf->showCounters()) {
+    list_log_list->setGeometry(0,0,sizeHint().width(),sizeHint().height()-120);
+  }
+  else {
+    list_log_list->setGeometry(0,0,sizeHint().width(),sizeHint().height()-60);
+  }
   list_log_list->setAllColumnsShowFocus(true);
-  list_log_list->setSelectionMode(QListView::Single);
+  list_log_list->setSelectionMode(QListView::Extended);
   list_log_list->setItemMargin(5);
   list_log_list->addColumn("");
   list_log_list->setColumnAlignment(0,Qt::AlignHCenter);
@@ -175,6 +184,48 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
 	  this,
 	  SLOT(doubleclickedData(QListViewItem *,const QPoint &,int)));
 
+  //
+  // Time Counter Section
+  //
+  QLabel *label=new QLabel(tr("Run Length"),this);
+  label->setGeometry(370,sizeHint().height()-120,75,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignCenter);  
+  label->setBackgroundColor(QColor(lightGray));
+  if(!rdairplay_conf->showCounters()) {
+    label->hide();
+  }
+
+  //
+  // Stop Time Counter
+  //
+  list_stoptime_edit=new QLineEdit(this,"list_stoptime_edit");
+  list_stoptime_edit->setGeometry(410,sizeHint().height()-100,60,18);
+  list_stoptime_label=new QLabel(list_stoptime_edit,tr("Next Stop:"),this);
+  list_stoptime_label->setGeometry(340,sizeHint().height()-100,65,18);
+  list_stoptime_label->setFont(label_font);
+  list_stoptime_label->setAlignment(AlignRight|AlignVCenter);  
+  list_stoptime_label->setBackgroundColor(QColor(lightGray));
+  if(!rdairplay_conf->showCounters()) {
+    list_stoptime_edit->hide();
+    list_stoptime_label->hide();
+  }
+
+  //
+  // End Time Counter
+  //
+  list_endtime_edit=new QLineEdit(this,"list_endtime_edit");
+  list_endtime_edit->setGeometry(410,sizeHint().height()-80,60,18);
+  label=new QLabel(list_endtime_edit,tr("Log End:"),this);
+  label->setGeometry(340,sizeHint().height()-80,65,18);
+  label->setFont(label_font);
+  label->setAlignment(AlignRight|AlignVCenter);  
+  label->setBackgroundColor(QColor(lightGray));
+  if(!rdairplay_conf->showCounters()) {
+    list_endtime_edit->hide();
+    label->hide();
+  }
+
   //
   // Select Button
   //
@@ -183,10 +234,38 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_take_button->setFont(font);
   list_take_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
   list_take_button->setText(tr("Select"));
- list_take_button->setFocusPolicy(QWidget::NoFocus);
+  list_take_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_take_button,SIGNAL(clicked()),this,SLOT(takeButtonData()));
   list_take_button->hide();
 
+  //
+  // Audition Head Button
+  //
+  list_head_button=new QPushButton(this,"list_head_button");
+  list_head_button->setGeometry(10,sizeHint().height()-113,80,50);
+  list_head_button->setFont(font);
+  list_head_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_head_button->setText(tr("Audition\nHead"));
+  list_head_button->setFocusPolicy(QWidget::NoFocus);
+  connect(list_head_button,SIGNAL(clicked()),this,SLOT(headButtonData()));
+  if(!rdairplay_conf->showCounters()) {
+    list_head_button->hide();
+  }
+
+  //
+  // Audition Tail Button
+  //
+  list_tail_button=new QPushButton(this,"list_tail_button");
+  list_tail_button->setGeometry(90,sizeHint().height()-113,80,50);
+  list_tail_button->setFont(font);
+  list_tail_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_tail_button->setText(tr("Audition\nTail"));
+  list_tail_button->setFocusPolicy(QWidget::NoFocus);
+  connect(list_tail_button,SIGNAL(clicked()),this,SLOT(tailButtonData()));
+  if(!rdairplay_conf->showCounters()) {
+    list_tail_button->hide();
+  }
+
   //
   // Play Button
   //
@@ -194,9 +273,9 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_play_button->setGeometry(10,sizeHint().height()-55,80,50);
   list_play_button->setFont(font);
   list_play_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
-  list_play_button->setText(tr("Play"));
+  list_play_button->setText(tr("Start"));
   list_play_button->setDisabled(true);
- list_play_button->setFocusPolicy(QWidget::NoFocus);
+  list_play_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_play_button,SIGNAL(clicked()),this,SLOT(playButtonData()));
 
   //
@@ -209,7 +288,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
 					  QColor(lightGray)));
   list_next_button->setText(tr("Make\nNext"));
   list_next_button->setDisabled(true);
- list_next_button->setFocusPolicy(QWidget::NoFocus);
+  list_next_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_next_button,SIGNAL(clicked()),this,SLOT(nextButtonData()));
 
   //
@@ -222,7 +301,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
 					  QColor(lightGray)));
   list_modify_button->setText(tr("Modify"));
   list_modify_button->setDisabled(true);
- list_modify_button->setFocusPolicy(QWidget::NoFocus);
+  list_modify_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_modify_button,SIGNAL(clicked()),this,SLOT(modifyButtonData()));
 
   //
@@ -234,7 +313,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_scroll_button->setPalette(QPalette(backgroundColor(),
 					  QColor(lightGray)));
   list_scroll_button->setText(tr("Scroll"));
- list_scroll_button->setFocusPolicy(QWidget::NoFocus);
+  list_scroll_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_scroll_button,SIGNAL(clicked()),this,SLOT(scrollButtonData()));
   list_scroll_button->setPalette(list_scroll_color[0]);
 
@@ -261,7 +340,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_load_button->setFont(font);
   list_load_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
   list_load_button->setText(tr("Select\nLog"));
- list_load_button->setFocusPolicy(QWidget::NoFocus);
+  list_load_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_load_button,SIGNAL(clicked()),this,SLOT(loadButtonData()));
 
   //
@@ -284,6 +363,12 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   connect(list_log,SIGNAL(modified(int)),this,SLOT(modifiedData(int)));
   connect(list_log,SIGNAL(refreshabilityChanged(bool)),
 	  this,SLOT(refreshabilityChangedData(bool)));
+  connect(list_log,SIGNAL(auditionHeadPlayed(int)),
+	  this,SLOT(auditionHeadData(int)));
+  connect(list_log,SIGNAL(auditionTailPlayed(int)),
+	  this,SLOT(auditionTailData(int)));
+  connect(list_log,SIGNAL(auditionStopped(int)),
+	  this,SLOT(auditionStoppedData(int)));
 
   setBackgroundColor(QColor(lightGray));
 
@@ -353,6 +438,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
   }
   switch(mode) {
       case RDAirPlayConf::Normal:
+	list_log_list->setSelectionMode(QListView::Extended);
 	list_log_list->setPalette(palette());
 	list_take_button->hide();
 	list_play_button->show();
@@ -364,6 +450,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::AddTo:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_to_color);
 	list_take_button->setText(ADD_TO_MODE_TITLE);
 	list_take_button->setPalette(list_to_color);
@@ -377,6 +464,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::DeleteFrom:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_from_color);
 	list_take_button->setText(DELETE_FROM_MODE_TITLE);
 	list_take_button->setPalette(list_from_color);
@@ -390,6 +478,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::MoveFrom:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_from_color);
 	list_take_button->setText(MOVE_FROM_MODE_TITLE);
 	list_take_button->setPalette(list_from_color);
@@ -403,6 +492,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::MoveTo:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_to_color);
 	list_take_button->setText(MOVE_TO_MODE_TITLE);
 	list_take_button->setPalette(list_to_color);
@@ -416,6 +506,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::CopyFrom:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_from_color);
 	list_take_button->setText(COPY_FROM_MODE_TITLE);
 	list_take_button->setPalette(list_from_color);
@@ -429,6 +520,7 @@ void ListLog::setActionMode(RDAirPlayConf::ActionMode mode,int *cartnum)
 	break;
 
       case RDAirPlayConf::CopyTo:
+	list_log_list->setSelectionMode(QListView::Single);
 	list_log_list->setPalette(list_list_to_color);
 	list_take_button->setText(COPY_TO_MODE_TITLE);
 	list_take_button->setPalette(list_to_color);
@@ -552,6 +644,10 @@ void ListLog::takeButtonData()
 	      
 	    default:
 	      line=list_log_list->currentItem()->text(13).toInt();
+              // Don't try delete "end of log" or other invalid log entries.
+              if (line<0) {
+                return;
+              }
 	      break;
 	}
 	break;
@@ -563,6 +659,55 @@ void ListLog::takeButtonData()
 }
 
 
+void ListLog::headButtonData()
+{
+  if(list_audition_head_playing) {
+    list_log->auditionStop();
+  }
+  else {
+    if(!list_audition_tail_playing) {
+      list_log->auditionHead(CurrentLine());
+    }
+  }
+}
+
+
+void ListLog::tailButtonData()
+{
+  if(list_audition_tail_playing) {
+    list_log->auditionStop();
+  }
+  else {
+    if(!list_audition_head_playing) {
+      list_log->auditionTail(CurrentLine());
+    }
+  }
+}
+
+
+void ListLog::auditionHeadData(int line)
+{
+  list_head_button->setPalette(list_scroll_color[0]);
+  list_audition_head_playing=true;
+}
+
+
+void ListLog::auditionTailData(int line)
+{
+  list_tail_button->setPalette(list_scroll_color[0]);
+  list_audition_tail_playing=true;
+}
+
+
+void ListLog::auditionStoppedData(int line)
+{
+  list_head_button->setPalette(list_scroll_color[1]);
+  list_tail_button->setPalette(list_scroll_color[1]);
+  list_audition_head_playing=false;
+  list_audition_tail_playing=false;
+}
+
+
 void ListLog::playButtonData()
 {
   int line=CurrentLine();
@@ -795,10 +940,35 @@ void ListLog::logRemovedData(int line,int num,bool moving)
 
 void ListLog::selectionChangedData()
 {
-  if(list_log_list->selectedItem()==NULL) {
+  int count=0;
+  RDListViewItem *item=NULL;
+  RDListViewItem *next=(RDListViewItem *)list_log_list->firstChild();
+  int start_line=-1;
+  int end_line=-1;
+
+  while(next!=NULL) {
+    if(list_log_list->isSelected(next)) {
+      item=next;
+      if((start_line<0)&&(next->text(12).toInt()!=END_MARKER_ID)) {
+	start_line=next->text(13).toInt();
+      }
+      if(next->text(12).toInt()!=END_MARKER_ID) {
+	end_line=next->text(13).toInt();
+      }
+      count++;
+    }
+    next=(RDListViewItem *)next->nextSibling();
+  }
+  if(count!=1) {
+    list_endtime_edit->setText("");
+    list_stoptime_label->setText(tr("Selected:"));
     SetPlaybuttonMode(ListLog::ButtonDisabled);
     list_modify_button->setDisabled(true);
     list_next_button->setDisabled(true);
+    if(start_line>=0) {
+      list_stoptime_edit->setText(RDGetTimeLength(list_log->
+		      length(start_line,end_line+1),true,false));
+    }
     return;
   }  
   switch(CurrentStatus()) {
@@ -825,6 +995,22 @@ void ListLog::selectionChangedData()
       default:
 	break;
   }
+  if(item->text(13).toInt()>=0) {
+    list_endtime_edit->setText(RDGetTimeLength(list_log->
+      length(item->text(13).toInt(),list_log->size()),true,false));
+    list_stoptime_label->setText(tr("Next Stop:"));
+    int stoplen=list_log->lengthToStop(item->text(13).toInt());
+    if(stoplen>=0) {
+      list_stoptime_edit->setText(RDGetTimeLength(stoplen,true,false));
+    }
+    else {
+      list_stoptime_edit->setText("");
+    }
+  }
+  else {
+    list_endtime_edit->setText("");
+    list_stoptime_edit->setText("");
+  }
 }
 
 
@@ -861,6 +1047,29 @@ void ListLog::refreshabilityChangedData(bool state)
 }
 
 
+void ListLog::paintEvent(QPaintEvent *e)
+{
+  if(!rdairplay_conf->showCounters()) {
+    return;
+  }
+  int x=339;
+  int y=sizeHint().height()-111;
+
+  QPainter *p=new QPainter(this);
+  p->setPen(black);
+  p->setBrush(black);
+  p->moveTo(x,y);
+  p->lineTo(x+136,y);
+  p->lineTo(x+136,y+53);
+  p->lineTo(x,y+53);
+  p->lineTo(x,y);
+
+  p->end();
+  delete p;
+  
+}
+
+
 void ListLog::RefreshList()
 {
   RDListViewItem *l;
@@ -950,20 +1159,6 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
 	  }
 	}
 	break;
-      case RDLogLine::Overlap:
-	l->setText(3,tr("OVERLAP"));
-	if(log_line->hasCustomTransition()) {
-	  l->setTextColor(3,RD_CUSTOM_TRANSITION_COLOR,QFont::Bold);
-	}
-	else {
-	  if(log_line->timeType()==RDLogLine::Hard) {
-	    l->setTextColor(3,l->textColor(2),QFont::Bold);
-	  }
-	  else {
-	    l->setTextColor(3,l->textColor(2),QFont::Normal);
-	  }
-	}
-	break;
 
       default:
 	break;
@@ -1284,7 +1479,7 @@ void ListLog::SetPlaybuttonMode(ListLog::PlayButtonMode mode)
   switch(mode) {
       case ListLog::ButtonPlay:
 	list_play_button->setEnabled(true);
-	list_play_button->setText(tr("Play"));
+	list_play_button->setText(tr("Start"));
 	break;
 
       case ListLog::ButtonStop:
@@ -1299,7 +1494,7 @@ void ListLog::SetPlaybuttonMode(ListLog::PlayButtonMode mode)
 
       case ListLog::ButtonDisabled:
 	list_play_button->setDisabled(true);
-	list_play_button->setText(tr("Play"));
+	list_play_button->setText(tr("Start"));
 	break;
   }
   list_playbutton_mode=mode;
