@@ -2,9 +2,9 @@
 //
 // Rivendell Log Playout Machine
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2009 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.cpp,v 1.188.2.14 2009/03/17 13:11:50 cvs Exp $
+//      $Id: log_play.cpp,v 1.188.2.20 2009/08/19 12:49:36 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -62,6 +62,7 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_timescaling_available=false;
   play_rescan_pos=0;
   play_refreshable=false;
+  play_audition_preroll=rdairplay_conf->auditionPreroll();
   for(int i=0;i<LOGPLAY_MAX_PLAYS;i++) {
     play_slot_id[i]=i;
   }
@@ -83,6 +84,7 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_next_cartnum=0;
   play_prevnow_cartnum=0;
   play_prevnext_cartnum=0;
+  play_op_mode=RDAirPlayConf::Auto;
 
   //
   // Macro Cart Decks
@@ -105,6 +107,26 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   connect(rdripc,SIGNAL(onairFlagChanged(bool)),
 	  this,SLOT(onairFlagChangedData(bool)));
 
+  //
+  // Audition Player
+  //
+  play_audition_line=-1;
+  if((rdairplay_conf->card(3)>=0)&&(rdairplay_conf->port(3)>=0)) {
+    play_audition_player=new RDSimplePlayer(rdcae,rdripc,
+					    rdairplay_conf->card(3),
+					    rdairplay_conf->port(3),
+					    0,0);
+    play_audition_player->playButton()->hide();
+    play_audition_player->stopButton()->hide();
+    connect(play_audition_player,SIGNAL(played()),
+	    this,SLOT(auditionStartedData()));
+    connect(play_audition_player,SIGNAL(stopped()),
+	    this,SLOT(auditionStoppedData()));
+  }
+  else {
+    play_audition_player=NULL;
+  }
+
   //
   // Transition Timers
   //
@@ -221,6 +243,59 @@ void LogPlay::setNextCart(unsigned cartnum)
 }
 
 
+void LogPlay::auditionHead(int line)
+{
+  RDLogLine *logline=logLine(line);
+  if((play_audition_player==NULL)||(logline==NULL)) {
+    return;
+  }
+  if(logline->cartType()!=RDCart::Audio) {
+    return;
+  }
+  if(play_audition_line>=0) {
+    play_audition_player->stop();
+  }
+  play_audition_line=line;
+  play_audition_head_played=true;
+  play_audition_player->setCart(logline->cartNumber());
+  play_audition_player->play();
+}
+
+
+void LogPlay::auditionTail(int line)
+{
+  RDLogLine *logline=logLine(line);
+  if((play_audition_player==NULL)||(logline==NULL)) {
+    return;
+  }
+  if(logline->cartType()!=RDCart::Audio) {
+    return;
+  }
+  if(play_audition_line>=0) {
+    play_audition_player->stop();
+  }
+  play_audition_line=line;
+  play_audition_head_played=false;
+  play_audition_player->setCart(logline->cartNumber());
+  int start_pos=logline->endPoint()-play_audition_preroll;
+  if(start_pos<0) {
+    start_pos=0;
+  }
+  play_audition_player->play(start_pos);
+}
+
+
+void LogPlay::auditionStop()
+{
+  if(play_audition_player==NULL) {
+    return;
+  }
+  if(play_audition_line>=0) {
+    play_audition_player->stop();
+  }
+}
+
+
 bool LogPlay::play(int line,RDLogLine::StartSource src,
 		   int mport,bool skip_meta)
 {
@@ -382,6 +457,8 @@ void LogPlay::makeNext(int line,bool refresh_status)
     RefreshEvents(line,LOGPLAY_LOOKAHEAD_EVENTS);
   }
   SendNowNext();
+  SetTransTimer();
+  UpdatePostPoint();
   emit nextEventChanged(line);
   emit transportChanged();
 }
@@ -431,9 +508,9 @@ void LogPlay::load()
   play_next_line=0;
   UpdateStartTimes(0);
   emit reloaded();
-  UpdatePostPoint(0);
-  emit transportChanged();
   SetTransTimer();
+  emit transportChanged();
+  UpdatePostPoint();
   if((running>0)&&(size()>running)) {
     makeNext(running);
   }
@@ -456,7 +533,7 @@ void LogPlay::load()
 
 bool LogPlay::refresh()            
 {                                  
-  RDLogLine *s;                    
+  RDLogLine *s;
   RDLogLine *d;
   int prev_line;
   int prev_id;
@@ -578,7 +655,7 @@ bool LogPlay::refresh()
   }
   RefreshEvents(0,size());
   UpdateStartTimes(next_line);
-  UpdatePostPoint(play_line_counter);
+  UpdatePostPoint();
   SetTransTimer();
   emit transportChanged();
   emit reloaded();
@@ -624,6 +701,8 @@ void LogPlay::clear()
     delete play_log;
     play_log=NULL;
   }
+  SetTransTimer();
+  UpdatePostPoint();
   if(play_refreshable) {
     play_refreshable=false;
     emit refreshabilityChanged(play_refreshable);
@@ -677,12 +756,13 @@ void LogPlay::insert(int line,int cartnum,RDLogLine::TransType next_type,
     setTimescalingActive(play_timescaling_available&&logline->enforceLength());
   UpdateStartTimes(line);
   emit inserted(line);
-  UpdatePostPoint(play_line_counter);
+  UpdatePostPoint();
   if(mod_line>=0) {
     emit modified(mod_line);
   }
   emit transportChanged();
   SetTransTimer();
+  UpdatePostPoint();
 }
 
 
@@ -730,13 +810,14 @@ void LogPlay::insert(int line,RDLogLine *l,bool update,bool preserv_custom_trans
   if(update) {
     UpdateStartTimes(line);
     emit inserted(line);
-    UpdatePostPoint(play_line_counter);
+    UpdatePostPoint();
     if(mod_line>=0) {
       emit modified(mod_line);
     }
     emit transportChanged();
     SetTransTimer();
-    }
+    UpdatePostPoint();
+  }
 }
 
 
@@ -1113,8 +1194,22 @@ int LogPlay::runningEvents(int *lines, bool include_paused)
 
 void LogPlay::lineModified(int line)
 {
+  RDLogLine *logline;
+  RDLogLine *next_logline;
+
   SetTransTimer();
   UpdateStartTimes(line);
+
+  if((logline=logLine(line))!=NULL) {
+    if((next_logline=logLine(line+1))==NULL) {
+      logline->loadCart(logline->cartNumber(),RDLogLine::Play,
+			play_id,logline->timescalingActive());
+    }
+    else {
+      logline->loadCart(logline->cartNumber(),next_logline->transType(),
+			play_id,logline->timescalingActive());
+    }
+  }
   emit modified(line);
   int lines[TRANSPORT_QUANTITY] = {-1};
   int count;
@@ -1122,7 +1217,7 @@ void LogPlay::lineModified(int line)
   if (count > 0){
     line=lines[count-1];
   }
-  UpdatePostPoint(line);
+  UpdatePostPoint();
   emit transportChanged();
 }
 
@@ -1187,6 +1282,7 @@ void LogPlay::transTimerData()
   int lines[TRANSPORT_QUANTITY];
   RDLogLine *logline=NULL;
   int grace=0;
+  int trans_line=play_trans_line;
 
   if(play_grace_timer->isActive()) {
     play_grace_timer->stop();
@@ -1203,7 +1299,7 @@ void LogPlay::transTimerData()
     if((runningEvents(lines)==0)) {
       makeNext(play_trans_line);
       if(logline->transType()!=RDLogLine::Stop || grace>=0) {
-        StartEvent(play_trans_line,RDLogLine::Play,0,RDLogLine::StartTime);
+        StartEvent(trans_line,RDLogLine::Play,0,RDLogLine::StartTime);
       } 
     }
     else {
@@ -1216,11 +1312,10 @@ void LogPlay::transTimerData()
 	  case 0:
 	    makeNext(play_trans_line);
 	    if(play_trans_length==0) {
-	      StartEvent(play_trans_line,RDLogLine::Play,0,
-			 RDLogLine::StartTime);
+	      StartEvent(trans_line,RDLogLine::Play,0,RDLogLine::StartTime);
 	    }
 	    else {
-	      StartEvent(play_trans_line,RDLogLine::Segue,play_trans_length,
+	      StartEvent(trans_line,RDLogLine::Segue,play_trans_length,
 			 RDLogLine::StartTime);
 	    }
 	    break;
@@ -1249,12 +1344,16 @@ void LogPlay::transTimerData()
 void LogPlay::graceTimerData()
 {
   int lines[TRANSPORT_QUANTITY];
+  int line=play_grace_line;
 
   if(play_op_mode==RDAirPlayConf::Auto) {
-    if(!GetNextPlayable(&play_grace_line,false)) {
+    if(!GetNextPlayable(&line,false)) {
       SetTransTimer();
       return;
     }
+    if(line!=play_grace_line) {
+      return;
+    }
     if((runningEvents(lines)==0)) {
       makeNext(play_grace_line);
       StartEvent(play_grace_line,RDLogLine::Play,0,RDLogLine::StartTime);
@@ -1413,7 +1512,7 @@ void LogPlay::macroStartedData()
 		 QTime::currentTime().addMSecs(rdstation_conf->timeOffset()));
   UpdateStartTimes(line);
   emit played(line);
-  UpdatePostPoint(line);
+  UpdatePostPoint();
   emit transportChanged();
 }
 
@@ -1434,7 +1533,7 @@ void LogPlay::macroFinishedData()
 	       play_onair_flag);
   }
   play_macro_running=false;
-  UpdatePostPoint(line+1);
+  UpdatePostPoint();
   if(play_refresh_pending) {
     refresh();
     play_refresh_pending=false;
@@ -1457,7 +1556,7 @@ void LogPlay::macroStoppedData()
 	       (RDLogLine::PlaySource)(play_id+1),RDAirPlayConf::TrafficMacro,
 	       play_onair_flag);
   }
-  UpdatePostPoint(line+1);
+  UpdatePostPoint();
   emit transportChanged();
 }
 
@@ -1495,6 +1594,25 @@ void LogPlay::rescanEventsData()
 }
 
 
+void LogPlay::auditionStartedData()
+{
+  if(play_audition_head_played) {
+    emit auditionHeadPlayed(play_audition_line);
+  }
+  else {
+    emit auditionTailPlayed(play_audition_line);
+  }
+}
+
+
+void LogPlay::auditionStoppedData()
+{
+  int line=play_audition_line;
+  play_audition_line=-1;
+  emit auditionStopped(line);
+}
+
+
 bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 			 int trans_length,RDLogLine::StartSource src,int mport,int duck_length)
 {
@@ -1509,16 +1627,12 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
   bool was_paused=false;
 
   if((logline=logLine(line))==NULL) {
-//    SetTransTimer();
     return false;
   }
   if(logline->id()<0) {
-//    SetTransTimer();
     return false;
   }
 
-//  rdairplay_conf->setLogCurrentLine(play_id,line);
-
   //
   // Transition running events
   //
@@ -1800,14 +1914,12 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
     if((logline->state()==RDLogLine::Ok)||
        (logline->state()==RDLogLine::NoCart)||
        (logline->state()==RDLogLine::NoCut)) {
-//      SetTransTimer();
       rdairplay_conf->setLogCurrentLine(play_id,nextLine());
       return true;
     }
     play_next_line++;
   }
   play_next_line=-1;
-//  SetTransTimer();
   rdairplay_conf->setLogCurrentLine(play_id,nextLine());
   return true;
 }
@@ -1892,7 +2004,7 @@ void LogPlay::CleanupEvent(int id)
   logline->setStatus(RDLogLine::Finished);
   FreePlayDeck(playdeck);
   logline->setPlayDeck(NULL);
-  UpdatePostPoint(line);
+  UpdatePostPoint();
   if(top_changed) {
     emit topEventChanged(play_line_counter);
   }
@@ -1995,6 +2107,7 @@ void LogPlay::UpdateStartTimes(int line)
 
 void LogPlay::FinishEvent(int line)
 {
+  int prev_next_line=play_next_line;
   if(GetNextPlayable(&play_next_line,false)) {
     if(play_next_line>=0) {
       RDLogLine *logline;
@@ -2006,11 +2119,11 @@ void LogPlay::FinishEvent(int line)
 	if(play_next_line>=0) {
 	  if(logline->transType()==RDLogLine::Play) {
 	    StartEvent(play_next_line,RDLogLine::Play,0,RDLogLine::StartPlay);
-  	    SetTransTimer(QTime(),false);
+  	    SetTransTimer(QTime(),prev_next_line==play_trans_line);
 	  }
 	  if(logline->transType()==RDLogLine::Segue) {
 	    StartEvent(play_next_line,RDLogLine::Segue,0,RDLogLine::StartPlay);
-  	    SetTransTimer(QTime(),false);
+  	    SetTransTimer(QTime(),prev_next_line==play_trans_line);
 	  }
 	}
       }
@@ -2139,7 +2252,10 @@ void LogPlay::UpdatePostPoint()
   int count = runningEvents(lines,false);
   if (count > 0){
     UpdatePostPoint(lines[count -1]);
+    return;
   }
+  transportEvents(lines);
+  UpdatePostPoint(lines[0]);
 }
 
 void LogPlay::UpdatePostPoint(int line)
@@ -2148,10 +2264,17 @@ void LogPlay::UpdatePostPoint(int line)
   QTime post_time;
   int offset=0;
 
-  if((line<size())&&(play_trans_line>=0)&&(play_trans_line<size())) {
-    post_line=play_trans_line;
-    post_time=logLine(post_line)->startTime(RDLogLine::Logged);
-    offset=length(line,post_line)-QTime::currentTime().msecsTo(post_time);
+  if((line<0)||(play_trans_line<0)) {
+    post_line=-1;
+    post_time=QTime();
+    offset=0;
+  }
+  else {
+    if((line<size())&&(play_trans_line>=0)&&(play_trans_line<size())) {
+      post_line=play_trans_line;
+      post_time=logLine(post_line)->startTime(RDLogLine::Logged);
+      offset=length(line,post_line)-QTime::currentTime().msecsTo(post_time);
+    }
   }
   if((post_time!=play_post_time)||(offset!=play_post_offset)) {
     play_post_time=post_time;
@@ -2465,7 +2588,7 @@ void LogPlay::Playing(int id)
   UpdateStartTimes(line);
   emit played(line);
   AdvanceActiveEvent();
-  UpdatePostPoint(line);
+  UpdatePostPoint();
   // TEST
   RefreshEvents(line,LOGPLAY_LOOKAHEAD_EVENTS);
   //
@@ -2485,7 +2608,7 @@ void LogPlay::Paused(int id)
   }
   UpdateStartTimes(line);
   emit paused(line);
-  UpdatePostPoint(line+1);
+  UpdatePostPoint();
   LogTraffic(serviceName(),logName().left(logName().length()-4),logLine(line),
 	     (RDLogLine::PlaySource)(play_id+1),RDAirPlayConf::TrafficPause,
 	     play_onair_flag);
@@ -2506,7 +2629,7 @@ void LogPlay::Stopped(int id)
   UpdateStartTimes(line);
   emit stopped(line);
   AdvanceActiveEvent();
-  UpdatePostPoint(line+1);
+  UpdatePostPoint();
   if(runningEvents(lines)==0) {
     next_channel=0;
   }
@@ -2537,7 +2660,7 @@ void LogPlay::Finished(int id)
       default:
 	break;
   }
-  UpdatePostPoint(line+1);
+  UpdatePostPoint();
   if(runningEvents(lines)==0) {
     next_channel=0;
   }
