@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_casts.cpp,v 1.13 2008-09-26 17:52:23 fredg Exp $
+//      $Id: list_casts.cpp,v 1.13.2.4 2009/05/21 17:32:17 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,7 +36,6 @@
 #include <qbuttongroup.h>
 #include <qdatetime.h>
 #include <qfile.h>
-#include <qprogressdialog.h>
 #include <qapplication.h>
 #include <qfiledialog.h>
 
@@ -47,11 +46,11 @@
 #include <rdconf.h>
 #include <rdcut.h>
 #include <rdwavefile.h>
-#include <rdfeed.h>
 #include <rdescape_string.h>
 #include <rdurl.h>
 #include <rdfeedlog.h>
 #include <rdsettings.h>
+#include <rdcastsearch.h>
 
 #include <list_casts.h>
 #include <edit_cast.h>
@@ -89,6 +88,91 @@ ListCasts::ListCasts(unsigned feed_id,QWidget *parent,const char *name)
   QFont small_font=QFont("Helvetica",10,QFont::Normal);
   small_font.setPixelSize(10);
 
+  //
+  // Create Icons
+  //
+  list_greenball_map=new QPixmap(greenball_xpm);
+  list_redball_map=new QPixmap(redball_xpm);
+  list_whiteball_map=new QPixmap(whiteball_xpm);
+
+  //
+  // The Feed
+  //
+  list_feed=new RDFeed(feed_id,this);
+
+  //
+  // Progress Dialog
+  //
+  list_progress_dialog=
+    new QProgressDialog(tr("Uploading Audio..."),"Cancel",4,this);
+  list_progress_dialog->setCaption(tr("Progress"));
+  list_progress_dialog->setMinimumDuration(0);
+  list_progress_dialog->setTotalSteps(list_feed->totalPostSteps());
+  connect(list_feed,SIGNAL(postProgressChanged(int)),
+	  this,SLOT(postProgressChangedData(int)));
+
+  //
+  // Filter
+  //
+  list_filter_edit=new QLineEdit(this,"list_filter_edit");
+  list_filter_label=
+    new QLabel(list_filter_edit,tr("Filter:"),this,"list_filter_label");
+  list_filter_label->setFont(font);
+  list_filter_label->setAlignment(AlignRight|AlignVCenter);
+  connect(list_filter_edit,SIGNAL(textChanged(const QString &)),
+	  this,SLOT(filterChangedData(const QString &)));
+
+  //
+  // Unexpired Check Box
+  //
+  list_unexpired_check=new QCheckBox(this,"list_unexpired_check");
+  list_unexpired_label=
+    new QLabel(list_unexpired_check,tr("Only Show Unexpired Casts"),this,
+	       "list_unexpired_label");
+  list_unexpired_label->setFont(font);
+  list_unexpired_label->setAlignment(AlignLeft|AlignVCenter);
+  connect(list_unexpired_check,SIGNAL(toggled(bool)),
+	  this,SLOT(notexpiredToggledData(bool)));
+
+  //
+  // Active Check Box
+  //
+  list_active_check=new QCheckBox(this,"list_active_check");
+  list_active_label=
+    new QLabel(list_active_check,tr("Only Show Active Casts"),this,
+	       "list_active_label");
+  list_active_label->setFont(font);
+  list_active_label->setAlignment(AlignLeft|AlignVCenter);
+  connect(list_active_check,SIGNAL(toggled(bool)),
+	  this,SLOT(activeToggledData(bool)));
+
+  //
+  // Group List
+  //
+  list_casts_view=new RDListView(this,"list_casts_view");
+  list_casts_view->setAllColumnsShowFocus(true);
+  list_casts_view->setItemMargin(5);
+  list_casts_view->addColumn(tr(" "));
+  list_casts_view->setColumnAlignment(0,AlignCenter);
+  list_casts_view->addColumn(tr("Title"));
+  list_casts_view->setColumnAlignment(1,AlignLeft);
+  list_casts_view->addColumn(tr("Origin"));
+  list_casts_view->setColumnAlignment(2,AlignLeft);
+  list_casts_view->addColumn(tr("Expires"));
+  list_casts_view->setColumnAlignment(3,AlignCenter);
+  list_casts_view->addColumn(tr("Length"));
+  list_casts_view->setColumnAlignment(4,AlignRight);
+  list_casts_view->addColumn(tr("Description"));
+  list_casts_view->setColumnAlignment(5,AlignLeft);
+  list_casts_view->addColumn(tr("Category"));
+  list_casts_view->setColumnAlignment(6,AlignCenter);
+  list_casts_view->addColumn(tr("Link"));
+  list_casts_view->setColumnAlignment(7,AlignCenter);
+  connect(list_casts_view,
+	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  this,
+	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+
   //
   //  Post Cart Button
   //
@@ -138,43 +222,6 @@ ListCasts::ListCasts(unsigned feed_id,QWidget *parent,const char *name)
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
-  //
-  // Create Icons
-  //
-  list_greenball_map=new QPixmap(greenball_xpm);
-  list_redball_map=new QPixmap(redball_xpm);
-  list_whiteball_map=new QPixmap(whiteball_xpm);
-
-  //
-  // Group List
-  //
-  list_casts_view=new RDListView(this,"list_casts_view");
-  list_casts_view->setAllColumnsShowFocus(true);
-  list_casts_view->setItemMargin(5);
-  list_casts_view->addColumn(tr(" "));
-  list_casts_view->setColumnAlignment(0,AlignCenter);
-  list_casts_view->addColumn(tr("Title"));
-  list_casts_view->setColumnAlignment(1,AlignLeft);
-  list_casts_view->addColumn(tr("Origin"));
-  list_casts_view->setColumnAlignment(2,AlignLeft);
-  list_casts_view->addColumn(tr("Expires"));
-  list_casts_view->setColumnAlignment(3,AlignCenter);
-  list_casts_view->addColumn(tr("Length"));
-  list_casts_view->setColumnAlignment(4,AlignRight);
-  list_casts_view->addColumn(tr("Description"));
-  list_casts_view->setColumnAlignment(5,AlignLeft);
-  list_casts_view->addColumn(tr("Category"));
-  list_casts_view->setColumnAlignment(6,AlignCenter);
-  list_casts_view->addColumn(tr("Link"));
-  list_casts_view->setColumnAlignment(7,AlignCenter);
-  QLabel *list_box_label=new QLabel(list_casts_view,tr("&Casts:"),
-				    this,"list_box_label");
-  list_box_label->setGeometry(14,11,85,19);
-  connect(list_casts_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
-
   RefreshList();
   GetEncoderId();
   connect(cast_ripc,SIGNAL(userChanged()),this,SLOT(userChangedData()));
@@ -184,6 +231,8 @@ ListCasts::ListCasts(unsigned feed_id,QWidget *parent,const char *name)
 
 ListCasts::~ListCasts()
 {
+  delete list_progress_dialog;
+  delete list_feed;
 }
 
 
@@ -202,151 +251,42 @@ QSizePolicy ListCasts::sizePolicy() const
 void ListCasts::addCartData()
 {
   QString cutname;
-  QString tmpfile;
-  QString destfile;
-  QString sql;
-  RDSqlQuery *q;
-  RDPodcast *cast=NULL;
-
   RDCutDialog *cd=new RDCutDialog(&cutname,rdstation_conf,&cast_filter,
 				  &cast_group,cast_ripc->user());
-  if(cd->exec()==0) {
-    QProgressDialog *pd=
-      new QProgressDialog(tr("Uploading Audio..."),"Cancel",2,this);
-    pd->setCaption(tr("Progress"));
-    pd->setMinimumDuration(0);
-    pd->setProgress(0);
-    qApp->processEvents();
-    sleep(1);
-    qApp->processEvents();
-    QString cut_filename=RDCut::pathName(cutname); 
-    QString cmd=GetExportCommand(cut_filename,&tmpfile);
-    // printf("CMD: %s\n",(const char *)cmd);
-    if(system(cmd)!=0) {
-      pd->reset();
-      QMessageBox::warning(this,tr("Format Error"),
-			   tr("Unable to convert audio file!"));
-      delete pd;
-      delete cd;
-      return;
-    }
-    if(pd->wasCanceled()) {
-      delete pd;
-      delete cd;
-      return;
-    }
-    pd->setProgress(1);
-    qApp->processEvents();
-    QFile file(tmpfile);
-    int length=file.size();
-    RDCut *cut=new RDCut(cutname);
-    unsigned cast_id=CreateCast(&destfile,length,cut->length());
-    delete cut;
-    cast=new RDPodcast(cast_id);
-    cmd=cast->audioUploadCommand(tmpfile);
-    if(system(cmd)!=0) {
-      pd->reset();
-      QMessageBox::warning(this,tr("Upload Error"),
-			   tr("Unable to upload audio file!"));
-      sql=QString().sprintf("delete from PODCASTS where ID=%u",cast_id);
-      q=new RDSqlQuery(sql);
-      delete q;
-      delete cast;
-      delete pd;
-      delete cd;
-      return;
-    }
-    pd->setProgress(2);
-    pd->reset();
-    delete pd;
-    EditCast *edit_cast=new EditCast(cast_id,this);
-    edit_cast->exec();
-    RDListViewItem *item=new RDListViewItem(list_casts_view);
-    item->setId(cast_id);
-    RefreshItem(item);
-    list_casts_view->setSelected(item,true);
-    list_casts_view->ensureItemVisible(item);
-    delete edit_cast;
+  if(cd->exec()!=0) {
+    delete cd;
+    return;
   }
-  delete cast;
   delete cd;
-  unlink(tmpfile);
+  RDFeed::Error err;
+  unsigned cast_id=list_feed->postCut(cutname,&err);
+  if(err!=RDFeed::ErrorOk) {
+    QMessageBox::warning(this,tr("Posting Error"),RDFeed::errorString(err));
+    return;
+  }
+  EditCast *edit_cast=new EditCast(cast_id,this);
+  edit_cast->exec();
+  RDListViewItem *item=new RDListViewItem(list_casts_view);
+  item->setId(cast_id);
+  RefreshItem(item);
+  list_casts_view->setSelected(item,true);
+  list_casts_view->ensureItemVisible(item);
+  delete edit_cast;
 }
 
 
 void ListCasts::addFileData()
 {
-  QString sql;
-  RDSqlQuery *q;
-  QString cmd;
-  QString tmpfile;
-  QString tmpfile2;
-  QString destfile;
-  int time_length;
   QString srcfile=QFileDialog::getOpenFileName("",RD_AUDIO_FILE_FILTER,this);
   if(srcfile.isNull()) {
+    return;
+  }
+  RDFeed::Error err;
+  unsigned cast_id=list_feed->postFile(srcfile,&err);
+  if(err!=RDFeed::ErrorOk) {
+    QMessageBox::warning(this,tr("Posting Error"),RDFeed::errorString(err));
     return;
   }
-  QProgressDialog *pd=
-    new QProgressDialog(tr("Uploading Audio..."),"Cancel",4,this);
-  pd->setCaption(tr("Progress"));
-  pd->setMinimumDuration(0);
-  pd->setProgress(0);
-  qApp->processEvents();
-  sleep(1);
-  pd->setProgress(1);
-  qApp->processEvents();
-  RDWaveFile *wave=new RDWaveFile(srcfile);
-  if(!wave->openWave()) {
-    pd->reset();
-    QMessageBox::warning(this,tr("Format Error"),
-			 tr("Unable to convert audio file!"));
-    delete pd;
-    delete wave;
-    return;
-  }
-  time_length=wave->getExtTimeLength();
-  delete wave;
-
-
-  cmd=GetImportCommand(srcfile,&tmpfile);
-  if(system(cmd)!=0) {
-    pd->reset();
-    QMessageBox::warning(this,tr("Format Error"),
-			 tr("Unable to convert audio file!"));
-    delete pd;
-    return;
-  }
-  pd->setProgress(2);
-  qApp->processEvents();
-  cmd=GetExportCommand(tmpfile,&tmpfile2);
-  if(system(cmd)!=0) {
-    pd->reset();
-    QMessageBox::warning(this,tr("Format Error"),
-			 tr("Unable to convert audio file!"));
-    delete pd;
-    return;
-  }
-  pd->setProgress(3);
-  qApp->processEvents();  
-  QFile file(tmpfile2);
-  int length=file.size();
-  unsigned cast_id=CreateCast(&destfile,length,time_length);
-  RDPodcast *cast=new RDPodcast(cast_id);
-  cmd=cast->audioUploadCommand(tmpfile2);
-  if(system(cmd)!=0) {
-    pd->reset();
-    QMessageBox::warning(this,tr("Upload Error"),
-			 tr("Unable to upload audio file!"));
-    sql=QString().sprintf("delete from PODCASTS where ID=%u",cast_id);
-    q=new RDSqlQuery(sql);
-    delete q;
-    delete cast;
-    delete pd;
-    return;
-  }
-  pd->reset();
-  delete pd;
   EditCast *edit_cast=new EditCast(cast_id,this);
   edit_cast->exec();
   RDListViewItem *item=new RDListViewItem(list_casts_view);
@@ -355,9 +295,6 @@ void ListCasts::addFileData()
   list_casts_view->setSelected(item,true);
   list_casts_view->ensureItemVisible(item);
   delete edit_cast;
-  delete cast;
-  unlink(QString().sprintf("%s.wav",(const char *)tmpfile));
-  unlink(tmpfile2);
 }
 
 
@@ -464,6 +401,34 @@ void ListCasts::userChangedData()
 }
 
 
+void ListCasts::filterChangedData(const QString &str)
+{
+  RefreshList();
+}
+
+
+void ListCasts::notexpiredToggledData(bool state)
+{
+  RefreshList();
+}
+
+
+void ListCasts::activeToggledData(bool state)
+{
+  RefreshList();
+}
+
+
+void ListCasts::postProgressChangedData(int step)
+{
+  list_progress_dialog->setProgress(step);
+  if(step==list_progress_dialog->totalSteps()) {
+    list_progress_dialog->reset();
+  }
+  qApp->processEvents();
+}
+
+
 void ListCasts::closeData()
 {
   done(0);
@@ -472,13 +437,19 @@ void ListCasts::closeData()
 
 void ListCasts::resizeEvent(QResizeEvent *e)
 {
+  list_filter_label->setGeometry(10,10,40,20);
+  list_filter_edit->setGeometry(55,10,size().width()-65,20);
+  list_unexpired_check->setGeometry(55,35,15,15);
+  list_unexpired_label->setGeometry(75,33,200,20);
+  list_active_check->setGeometry(300,35,15,15);
+  list_active_label->setGeometry(320,33,200,20);
+  list_casts_view->setGeometry(10,54,size().width()-20,size().height()-124);
   list_cart_button->setGeometry(10,size().height()-60,80,50);
   list_file_button->setGeometry(100,size().height()-60,80,50);
   list_edit_button->setGeometry(190,size().height()-60,80,50);
   list_delete_button->setGeometry(280,size().height()-60,80,50);
   list_report_button->setGeometry(415,size().height()-60,80,50);
   list_close_button->setGeometry(size().width()-90,size().height()-60,80,50);
-  list_casts_view->setGeometry(10,30,size().width()-20,size().height()-100);
 }
 
 
@@ -489,8 +460,11 @@ void ListCasts::RefreshList()
   RDListViewItem *item;
 
   list_casts_view->clear();
-  sql=QString().sprintf("select ID from PODCASTS where FEED_ID=%d \
-                         order by ORIGIN_DATETIME",list_feed_id);
+  sql=QString().sprintf("select ID from PODCASTS %s \
+                         order by ORIGIN_DATETIME",
+       (const char *)RDCastSearch(list_feed_id,list_filter_edit->text(),
+				  list_unexpired_check->isChecked(),
+				  list_active_check->isChecked()));
   q=new RDSqlQuery(sql);
   while (q->next()) {
     item=new RDListViewItem(list_casts_view);
@@ -542,271 +516,6 @@ void ListCasts::RefreshItem(RDListViewItem *item)
 }
 
 
-unsigned ListCasts::CreateCast(QString *filename,int bytes,int msecs)
-{
-  QString sql;
-  RDSqlQuery *q;
-  RDSqlQuery *q1;
-  unsigned cast_id=0;
-  QDateTime current_datetime=
-    QDateTime(QDate::currentDate(),QTime::currentTime());
-
-  sql=QString().sprintf("select CHANNEL_TITLE,CHANNEL_DESCRIPTION,\
-                         CHANNEL_CATEGORY,CHANNEL_LINK,MAX_SHELF_LIFE,\
-                         UPLOAD_FORMAT,UPLOAD_EXTENSION from FEEDS \
-                         where ID=%u",list_feed_id);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    return 0;
-  }
-
-  //
-  // Create Entry
-  //
-  sql=QString().sprintf("insert into PODCASTS set \
-                         FEED_ID=%u,\
-                         ITEM_TITLE=\"%s\",\
-                         ITEM_DESCRIPTION=\"%s\",\
-                         ITEM_CATEGORY=\"%s\",\
-                         ITEM_LINK=\"%s\",\
-                         SHELF_LIFE=%d,\
-                         ORIGIN_DATETIME=\"%s\"",
-			list_feed_id,
-			(const char *)RDEscapeString(q->value(0).toString()),
-			(const char *)RDEscapeString(q->value(1).toString()),
-			(const char *)RDEscapeString(q->value(2).toString()),
-			(const char *)RDEscapeString(q->value(3).toString()),
-			q->value(4).toInt(),
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:ss"));
-  q1=new RDSqlQuery(sql);
-  delete q1;
-
-  //
-  // Get the ID
-  //
-  sql=QString().sprintf("select ID from PODCASTS \
-                         where (FEED_ID=%u)&&(ORIGIN_DATETIME=\"%s\")",
-			list_feed_id,
-			(const char *)current_datetime.
-			toString("yyyy-MM-dd hh:mm:ss"));
-  q1=new RDSqlQuery(sql);
-  if(q1->first()) {
-    cast_id=q1->value(0).toUInt();
-  }
-  delete q1;
-
-  //
-  // Generate the Filename
-  //
-  *filename=QString().
-    sprintf("%s.%s",
-	    (const char *)QString().sprintf("%06u_%06u",list_feed_id,cast_id),
-	    (const char *)q->value(6).toString());
-  sql=QString().sprintf("update PODCASTS set AUDIO_FILENAME=\"%s\",\
-                         AUDIO_LENGTH=%d,\
-                         AUDIO_TIME=%d where ID=%u",
-			(const char *)(*filename),
-			bytes,msecs,cast_id);
-  q1=new RDSqlQuery(sql);
-  delete q1;
-  delete q;
-  return cast_id;
-}
-
-
-QString ListCasts::GetImportCommand(const QString &srcfile,QString *destfile)
-{
-  int format_in=0;
-  int temp_length;
-  int finished_length;
-  QString cmd;
-
-  if(!QFile::exists(srcfile)) {
-    QMessageBox::warning(this,tr("File Error"),tr("File does not exist!"));
-    return QString();
-  }
-  RDWaveFile *wave=new RDWaveFile(srcfile);
-  if(!wave->openWave()) {
-    QMessageBox::warning(this,tr("File Error"),tr("Cannot open file!"));
-    delete wave;
-    return QString();
-  }
-  if(wave->type()==RDWaveFile::Unknown) {
-    QMessageBox::warning(this,tr("File Error"),tr("Unsupported file type!"));
-    wave->closeWave();
-    delete wave;
-    return QString();
-  }
-  int samplerate=wave->getSamplesPerSec();
-  switch(wave->getFormatTag()) {
-      case WAVE_FORMAT_PCM:
-	format_in=0;
-	temp_length=wave->getSampleLength()*
-	  wave->getChannels()*(wave->getBitsPerSample()/8);
-	break;
-
-      case WAVE_FORMAT_MPEG:
-	format_in=wave->getHeadLayer();
-	temp_length=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-
-      case WAVE_FORMAT_FLAC:
-	format_in=0;
-	temp_length=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-  }
-  delete wave;
-
-  RDFeed *feed=new RDFeed(list_feed_id);
-
-  int lib_fmt=0;
-  finished_length=
-    (int)(((double)temp_length/2.0)*
-	  (double)feed->uploadChannels()*
-	  ((double)feed->uploadSampleRate())/44100.0);
-  lib_fmt=0;
-  *destfile=GetTempFilename();
-  QString tempwav_name=*destfile+".wav";
-  QString tempdat_name=*destfile+".dat";
-
-  float normal=0.0;
-  normal=pow(10.0,(double)(-1.0/20.0));
-  cmd=QString().
-    sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s",
-	    normal,
-	    format_in,
-	    samplerate,
-	    (const char *)RDEscapeString(srcfile.utf8()),  
-	    lib_fmt,
-	    feed->uploadChannels(),
-	    feed->uploadSampleRate(),
-	    (feed->uploadChannels())*feed->uploadBitRate()/1000,
-	    (const char *)(*destfile),
-	    (const char *)tempdat_name,
-	    (const char *)tempwav_name);
-  // printf("CMD: %s\n",(const char *)cmd);
-
-  delete feed;
-
-  return cmd;
-}
-
-
-QString ListCasts::GetExportCommand(const QString &srcfile,QString *destfile)
-{
-  int format_in=0;
-  int len;
-  RDSettings settings;
-  QString custom_cmd;
-
-  RDFeed *feed=new RDFeed(list_feed_id);
-  *destfile=GetTempFilename();
-  QFile file(srcfile);
-  if(!file.exists()) {
-    return QString();
-  }
-  RDWaveFile *wave=new RDWaveFile(srcfile);
-  if(!wave->openWave()) {
-    delete wave;
-    return QString();
-  }
-  int samplerate=wave->getSamplesPerSec();
-  switch(wave->getFormatTag()) {
-      case WAVE_FORMAT_PCM:
-	format_in=0;
-	len=wave->getSampleLength()*wave->getChannels()*
-	  (wave->getBitsPerSample()/8);
-	break;
-
-      case WAVE_FORMAT_MPEG:
-	format_in=wave->getHeadLayer();
-	len=wave->getSampleLength()*wave->getChannels()*2;
-	break;
-  }
-  wave->closeWave();
-  delete wave;
-
-  QString cmd;
-  float normal=0.0;
-  if(feed->normalizeLevel()<=0) {
-    normal=pow(10.0,(double)(feed->normalizeLevel()/20000.0));
-    cmd=QString().
-      sprintf("rd_export_file %6.4f %d %d %s %d %d %d %d %d %s %s.dat %s.%s",
-	      normal,
-	      format_in,
-	      samplerate,
-	      (const char *)srcfile,
-	      feed->uploadFormat(),
-	      feed->uploadChannels(),
-	      feed->uploadSampleRate(),
-	      feed->uploadBitRate()/1000,
-	      feed->uploadQuality(),
-	      (const char *)RDEscapeString(*destfile),
-	      (const char *)(*destfile),
-	      (const char *)(*destfile),
-	      RDConfiguration()->audioExtension().ascii());
-  }
-  else {
-    cmd=QString().
-      sprintf("rd_export_file 0 %d %d %s %d %d %d %d %d %s %s.dat %s.%s",
-	      format_in,
-	      samplerate,
-	      (const char *)srcfile,
-	      feed->uploadFormat(),
-	      feed->uploadChannels(),
-	      feed->uploadSampleRate(),
-	      feed->uploadBitRate()/1000,
-	      feed->uploadQuality(),
-	      (const char *)RDEscapeString(*destfile),
-	      (const char *)(*destfile),
-	      (const char *)(*destfile),
-	      RDConfiguration()->audioExtension().ascii());
-  }
-
-  switch(feed->uploadFormat()) {  // Custom format?
-    case RDSettings::Pcm16:
-    case RDSettings::MpegL1:
-    case RDSettings::MpegL2:
-    case RDSettings::MpegL3:
-    case RDSettings::Flac:
-    case RDSettings::OggVorbis:
-      break;
-
-    default:
-      settings.setFormat(feed->uploadFormat());
-      settings.setChannels(feed->uploadChannels());
-      settings.setSampleRate(feed->uploadSampleRate());
-      settings.setBitRate(feed->uploadBitRate());
-      custom_cmd=settings.resolvedCustomCommandLine(*destfile);
-      if(custom_cmd.isEmpty()) {
-	return QString();
-      }
-      cmd+=" \""+custom_cmd+"\"";
-      break;
-  }
-  delete feed;
-
-  // printf("CMD: %s",(const char *)cmd);
-
-  return cmd;
-}
-
-
-QString ListCasts::GetTempFilename()
-{
-  char tempname[PATH_MAX];
-
-  sprintf(tempname,"%s/podcastXXXXXX",(const char *)RDTempDir());
-  if(mkstemp(tempname)<0) {
-    return QString();
-  }
-
-  return QString(tempname);
-}
-
-
 void ListCasts::GetEncoderId()
 {
   QString sql;
