@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.130.2.6 2009/04/14 15:58:09 cvs Exp $
+//      $Id: rdcatchd.cpp,v 1.130.2.7 2009/08/03 20:47:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -2852,7 +2852,7 @@ QString MainObject::GetImportCmd(int event,QString *tempname)
 	      (const char *)*tempname,
 	      RDConfiguration()->audioExtension().ascii());
   }
-  // LogLine(QString().sprintf("CMD: %s",(const char *)cmd));
+  //LogLine(RDConfig::LogErr,QString().sprintf("CMD: %s",(const char *)cmd));
   return cmd;
 }
 
@@ -3219,7 +3219,7 @@ void MainObject::StartRmlRecording(int chan,int cartnum,int cutnum,int maxlen)
   catch_events.back().setChannels(deck->defaultChannels());
   catch_events.back().setSampleRate(deck->defaultSamprate());
   catch_events.back().setBitrate(deck->defaultBitrate());
-  catch_events.back().setNormalizeLevel(deck->defaultThreshold());
+  catch_events.back().setNormalizeLevel(0);
   StartRecording(catch_events.size()-1);
   delete cut;
   delete deck;
