@@ -2,9 +2,9 @@
 //
 // CD Ripper Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2003, 2009 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cdripper.cpp,v 1.36 2008/08/18 15:57:42 fredg Exp $
+//      $Id: cdripper.cpp,v 1.36.2.3 2009/08/04 20:56:49 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -151,6 +151,8 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_track_list->setAllColumnsShowFocus(true);
   rip_track_list->setItemMargin(5);
   rip_track_list->setSorting(-1);
+  connect(rip_track_list,SIGNAL(selectionChanged()),
+	  this,SLOT(trackSelectionChangedData()));
   label=new QLabel(rip_track_list,tr("Tracks"),this,"name_label");
   label->setGeometry(10,140,100,14);
   label->setFont(label_font);
@@ -209,6 +211,7 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_rip_button=new QPushButton(tr("&Rip\nTrack"),this,"rip_track_button");
   rip_rip_button->setGeometry(sizeHint().width()-90,380,80,50);
   rip_rip_button->setFont(button_font);
+  rip_rip_button->setDisabled(true);
   connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
 
   //
@@ -329,6 +332,12 @@ QSizePolicy CdRipper::sizePolicy() const
 }
 
 
+void CdRipper::trackSelectionChangedData()
+{
+  rip_rip_button->setDisabled(rip_track_list->selectedItem()==NULL);
+}
+
+
 void CdRipper::ejectButtonData()
 {
   rip_cdrom->eject();
@@ -442,7 +451,6 @@ void CdRipper::ripTrackButtonData()
 	  RIPPER_TEMP_PEAK,
 	  RIPPER_TEMP_DIR,
 	  RIPPER_TEMP_WAV);
-     rip_multipass=true;
     }
     else {
      cmd=QString().sprintf("rd_rip_cd %d %s %d 0 %d %d %d %d %s %s/%s %s/%s",
@@ -458,7 +466,6 @@ void CdRipper::ripTrackButtonData()
 	  RIPPER_TEMP_PEAK,
 	  RIPPER_TEMP_DIR,
 	  RIPPER_TEMP_WAV);
-     rip_multipass=false;
     }
     ripper_running=true;
     bar_temp_file=new QFile(QString(RIPPER_TEMP_DIR)+QString("/")+
@@ -589,17 +596,10 @@ void CdRipper::autotrimCheckData(bool state)
 void CdRipper::barTimerData()
 {
   if(ripper_running) {
-    if(rip_multipass) {
-      rip_bar->
-	setProgress((int)(50.0*((double)bar_temp_file->
-				size()/(double)rip_temp_length+
-				(double)bar_file->size()/
-				(double)rip_finished_length)));
-    }
-    else {
-      rip_bar->setProgress((int)(100.0*(double)bar_file->size()/
-				 (double)rip_finished_length));
-    }
+    rip_bar->setProgress((int)(50.0*((double)bar_temp_file->
+				     size()/(double)rip_temp_length+
+				     (double)bar_file->size()/
+				     (double)rip_finished_length)));
     rip_bar_timer->start(RIPPER_BAR_INTERVAL,true);
   }
   else {
@@ -610,6 +610,7 @@ void CdRipper::barTimerData()
     rip_stop_button->setEnabled(true);
     rip_rip_button->setEnabled(true);
     rip_close_button->setEnabled(true);
+    rip_cdrom->unlock();
     if(bar_file->exists()) {
       rip_done=true;
       QMessageBox::information(this,tr("Rip Complete"),
