@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_cart.cpp,v 1.69 2008/08/04 19:05:35 fredg Exp $
+//      $Id: edit_cart.cpp,v 1.69.2.1 2009/03/24 12:11:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,8 @@
 #include <rd.h>
 #include <rdconf.h>
 #include <rdaudio_exists.h>
+#include <rdsystem.h>
+#include <rdescape_string.h>
 
 #include <cdripper.h>
 #include <edit_cart.h>
@@ -730,88 +732,108 @@ void EditCart::okData()
   int year;
   QListViewItemIterator *it;
   RDCart *rdcart_cart_medit;
+  RDSystem *system;
+  QString sql;
+  RDSqlQuery *q;
 
   if(lib_cart_list_edit==NULL) { // Single Edit
-  if(rdcart_controls.title_edit->text().isEmpty()) {
-    QMessageBox::warning(this,tr("Missing Title"),
-			 tr("You must provide at least a Cart Title!"));
-    return;
-  }
-  if(rdcart_controls.enforce_length_box->isChecked()) {
-    if(!ValidateLengths()) {
-      switch(QMessageBox::warning(this,tr("Length Mismatch"),
-				  tr("One or more cut lengths exceed the timescaling\nlimits of the system!  Do you still want to save?"),QMessageBox::Yes,QMessageBox::No)) {
+    if(rdcart_controls.title_edit->text().isEmpty()) {
+      QMessageBox::warning(this,tr("Missing Title"),
+			   tr("You must provide at least a Cart Title!"));
+      return;
+    }
+    system=new RDSystem();
+    if(!system->allowDuplicateCartTitles()) {
+      sql=QString().sprintf("select NUMBER from CART \
+                             where (TITLE=\"%s\")&&(NUMBER!=%u)",
+	  (const char *)RDEscapeString(rdcart_controls.title_edit->text()),
+	  rdcart_cart->number());
+      q=new RDSqlQuery(sql);
+      if(q->first()) {
+	QMessageBox::warning(this,tr("Duplicate Title"),
+			     tr("The cart title must be unique!"));
+	delete q;
+	delete system;
+	return;
+      }
+      delete q;
+    }
+    delete system;
+    if(rdcart_controls.enforce_length_box->isChecked()) {
+      if(!ValidateLengths()) {
+	switch(QMessageBox::warning(this,tr("Length Mismatch"),
+				    tr("One or more cut lengths exceed the timescaling\nlimits of the system!  Do you still want to save?"),QMessageBox::Yes,QMessageBox::No)) {
 	  case QMessageBox::No:
 	  case QMessageBox::NoButton:
 	    return;
-
+	    
 	  default:
 	    break;
+	}
       }
     }
-  }
-  rdcart_cart->setGroupName(rdcart_group_box->currentText());
-  rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
-  rdcart_cart->setLengthDeviation(rdcart_length_deviation);
-  rdcart_cart->updateLength(rdcart_controls.enforce_length_box->isChecked(),
-			    QTime().msecsTo(rdcart_controls.
-					    forced_length_edit->time()));
-  rdcart_cart->
-    setAverageLength(RDSetTimeLength(rdcart_average_length_edit->text()));
-  if(rdcart_controls.enforce_length_box->isChecked()) {
+    rdcart_cart->setGroupName(rdcart_group_box->currentText());
+    rdcart_cart->calculateAverageLength(&rdcart_length_deviation);
+    rdcart_cart->setLengthDeviation(rdcart_length_deviation);
+    rdcart_cart->updateLength(rdcart_controls.enforce_length_box->isChecked(),
+			      QTime().msecsTo(rdcart_controls.
+					      forced_length_edit->time()));
     rdcart_cart->
-      setForcedLength(QTime().msecsTo(rdcart_controls.forced_length_edit->time()));
-    rdcart_cart->setEnforceLength(true);
-  }
-  else {
-    rdcart_cart->
-      setForcedLength(RDSetTimeLength(rdcart_average_length_edit->text()));
-    rdcart_cart->setEnforceLength(false);
-  }
-  rdcart_cart->setPreservePitch(rdcart_preserve_pitch_button->isChecked());
-  rdcart_cart->setTitle(rdcart_controls.title_edit->text());
-  if(sscanf((const char *)rdcart_controls.year_edit->text(),
-	    "%d",&year)==1) {
-    rdcart_cart->setYear(QDate(year,1,1));
-  }
-  else {
-    rdcart_cart->setYear();
-  }
+      setAverageLength(RDSetTimeLength(rdcart_average_length_edit->text()));
+    if(rdcart_controls.enforce_length_box->isChecked()) {
+      rdcart_cart->
+	setForcedLength(QTime().msecsTo(rdcart_controls.forced_length_edit->time()));
+      rdcart_cart->setEnforceLength(true);
+    }
+    else {
+      rdcart_cart->
+	setForcedLength(RDSetTimeLength(rdcart_average_length_edit->text()));
+      rdcart_cart->setEnforceLength(false);
+    }
+    rdcart_cart->setPreservePitch(rdcart_preserve_pitch_button->isChecked());
+    rdcart_cart->setTitle(rdcart_controls.title_edit->text());
+    if(sscanf((const char *)rdcart_controls.year_edit->text(),
+	      "%d",&year)==1) {
+      rdcart_cart->setYear(QDate(year,1,1));
+    }
+    else {
+      rdcart_cart->setYear();
+    }
     rdcart_cart->setSchedCodes(sched_codes);
-  rdcart_cart->setArtist(rdcart_controls.artist_edit->text());
-  rdcart_cart->setAlbum(rdcart_controls.album_edit->text());
-  rdcart_cart->setLabel(rdcart_controls.label_edit->text());
-  rdcart_cart->setClient(rdcart_controls.client_edit->text());
-  rdcart_cart->setAgency(rdcart_controls.agency_edit->text());
-  rdcart_cart->setPublisher(rdcart_controls.publisher_edit->text());
-  rdcart_cart->setComposer(rdcart_controls.composer_edit->text());
-  rdcart_cart->setUserDefined(rdcart_controls.user_defined_edit->text());
-  rdcart_cart->
-    setUsageCode((RDCart::UsageCode)rdcart_usage_box->currentItem());
-  rdcart_cart->
-    setPlayOrder((RDCart::PlayOrder)rdcart_cut_sched_box->currentItem());
-
-  if(rdcart_cart->type()==RDCart::Macro) {
-    rdcart_macro_cart->save();
-    rdcart_cart->setAsyncronous(rdcart_syncronous_box->isChecked());
-  }
+    rdcart_cart->setArtist(rdcart_controls.artist_edit->text());
+    rdcart_cart->setAlbum(rdcart_controls.album_edit->text());
+    rdcart_cart->setLabel(rdcart_controls.label_edit->text());
+    rdcart_cart->setClient(rdcart_controls.client_edit->text());
+    rdcart_cart->setAgency(rdcart_controls.agency_edit->text());
+    rdcart_cart->setPublisher(rdcart_controls.publisher_edit->text());
+    rdcart_cart->setComposer(rdcart_controls.composer_edit->text());
+    rdcart_cart->setUserDefined(rdcart_controls.user_defined_edit->text());
+    rdcart_cart->
+      setUsageCode((RDCart::UsageCode)rdcart_usage_box->currentItem());
+    rdcart_cart->
+      setPlayOrder((RDCart::PlayOrder)rdcart_cut_sched_box->currentItem());
+    
+    if(rdcart_cart->type()==RDCart::Macro) {
+      rdcart_macro_cart->save();
+      rdcart_cart->setAsyncronous(rdcart_syncronous_box->isChecked());
+    }
   }
   else {  // Multi Edit
-  	it=new QListViewItemIterator(lib_cart_list_edit);
+    it=new QListViewItemIterator(lib_cart_list_edit);
     while(it->current()) {
       if (it->current()->isSelected()) {  
         RDListViewItem *item=(RDListViewItem *)it->current();
         if(item->text(17).isEmpty()) {
-        
+	  
           rdcart_cart_medit=new RDCart(item->text(1).toUInt());
-        
+	  
           if(!rdcart_group_box->currentText().stripWhiteSpace().isEmpty())
-   	        rdcart_cart_medit->setGroupName(rdcart_group_box->currentText());
+	    rdcart_cart_medit->setGroupName(rdcart_group_box->currentText());
           if(!rdcart_controls.title_edit->text().stripWhiteSpace().isEmpty())
             rdcart_cart_medit->setTitle(rdcart_controls.title_edit->text());
           if(!rdcart_controls.year_edit->text().stripWhiteSpace().isEmpty())
             if(sscanf((const char *)rdcart_controls.year_edit->text(),
-	             "%d",&year)==1) {
+		      "%d",&year)==1) {
               rdcart_cart_medit->setYear(QDate(year,1,1));
             }
             else {
@@ -835,20 +857,20 @@ void EditCart::okData()
             rdcart_cart_medit->setUserDefined(rdcart_controls.user_defined_edit->text());
           if(!rdcart_usage_box->currentText().stripWhiteSpace().isEmpty())          
             rdcart_cart_medit->
-               setUsageCode((RDCart::UsageCode)(rdcart_usage_box->currentItem()-1));
+	      setUsageCode((RDCart::UsageCode)(rdcart_usage_box->currentItem()-1));
           if(!rdcart_cut_sched_box->currentText().stripWhiteSpace().isEmpty())          
             rdcart_cart_medit->
-               setPlayOrder((RDCart::PlayOrder)(rdcart_cut_sched_box->currentItem()-1));
+	      setPlayOrder((RDCart::PlayOrder)(rdcart_cut_sched_box->currentItem()-1));
           rdcart_cart_medit->updateSchedCodes(add_codes,remove_codes);
-
-   	      delete rdcart_cart_medit; 
+	  
+	  delete rdcart_cart_medit; 
         }
       }
       ++(*it);
     }
     delete it;
   }
-
+  
   done(0);
 }
 
