@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_reports.cpp,v 1.4 2007-09-14 14:06:56 fredg Exp $
+//      $Id: list_reports.cpp,v 1.4.2.1 2009/02/12 14:21:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,6 +28,7 @@
 
 #include <rdconf.h>
 #include <rdtextfile.h>
+#include <rddatedialog.h>
 
 #include <globals.h>
 #include <list_reports.h>
@@ -63,6 +64,8 @@ ListReports::ListReports(const QString &logname,const QString &description,
   //
   QFont font=QFont("Helvetica",12,QFont::Bold);
   font.setPixelSize(12);
+  QFont select_font=QFont("Helvetica",12,QFont::Normal);
+  select_font.setPixelSize(12);
 
   //
   // Reports List
@@ -78,26 +81,42 @@ ListReports::ListReports(const QString &logname,const QString &description,
   list_reports_label->setFont(font);
   list_reports_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Effective Date
+  //
+  list_date_edit=new QDateEdit(this,"list_date_edit");
+  list_date_edit->setGeometry(110,34,100,19);
+  QLabel *list_date_label=
+    new QLabel(list_date_edit,tr("Effective Date:"),
+	       this,"list_date_label");
+  list_date_label->setGeometry(10,34,95,19);
+  list_date_label->setFont(font);
+  list_date_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  QPushButton *button=new QPushButton(this,"select_button");
+  button->setGeometry(215,32,60,24);
+  button->setFont(select_font);
+  button->setText(tr("&Select"));
+  connect(button,SIGNAL(clicked()),this,SLOT(selectDateData()));
+  list_date_edit->setDate(QDate::currentDate());
+
   //
   //  Generate Button
   //
-  QPushButton *generate_button=new QPushButton(this,"generate_button");
-  generate_button->
-    setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
-  generate_button->setDefault(true);
-  generate_button->setFont(font);
-  generate_button->setText(tr("&Generate"));
-  connect(generate_button,SIGNAL(clicked()),this,SLOT(generateData()));
+  button=new QPushButton(this,"generate_button");
+  button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
+  button->setDefault(true);
+  button->setFont(font);
+  button->setText(tr("&Generate"));
+  connect(button,SIGNAL(clicked()),this,SLOT(generateData()));
 
   //
   //  Close Button
   //
-  QPushButton *close_button=new QPushButton(this,"close_button");
-  close_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  close_button->setFont(font);
-  close_button->setText(tr("&Close"));
-  connect(close_button,SIGNAL(clicked()),this,SLOT(closeData()));
+  button=new QPushButton(this,"close_button");
+  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
+  button->setFont(font);
+  button->setText(tr("&Close"));
+  connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
 }
 
 
@@ -108,7 +127,7 @@ ListReports::~ListReports()
 
 QSize ListReports::sizeHint() const
 {
-  return QSize(350,110);
+  return QSize(350,132);
 } 
 
 
@@ -118,6 +137,18 @@ QSizePolicy ListReports::sizePolicy() const
 }
 
 
+void ListReports::selectDateData()
+{
+  QDate today=QDate::currentDate();
+  QDate date=list_date_edit->date();
+  RDDateDialog *d=new RDDateDialog(today.year()-1,today.year()+1,this);
+  if(d->exec(&date)==0) {
+    list_date_edit->setDate(date);
+  }
+  delete d;
+}
+
+
 void ListReports::generateData()
 {
   QString report;
@@ -128,7 +159,7 @@ void ListReports::generateData()
 	break;
 
       case 1:  // XLoad Report
-	GenerateExceptionReport(&report);
+	GenerateExceptionReport(&report,list_date_edit->date());
 	break;
 
       default:
@@ -297,9 +328,9 @@ void ListReports::GenerateLogReport(QString *report)
 }
 
 
-void ListReports::GenerateExceptionReport(QString *report)
+void ListReports::GenerateExceptionReport(QString *report,const QDate &date)
 {
-  int errs=list_events->validate(report);
+  int errs=list_events->validate(report,date);
   if(errs==0) {
     QMessageBox::information(this,tr("Log Check"),tr("No exceptions found."));
     *report="";
