@@ -3,789 +3,819 @@
     <name>AddMeta</name>
     <message>
         <source>Insert a:</source>
-        <translation type="unfinished"></translation>
+        <translation>Füge ein:</translation>
     </message>
     <message>
         <source>&amp;Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Marker</translation>
     </message>
     <message>
         <source>Voice &amp;Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice &amp;Track</translation>
     </message>
     <message>
         <source>Log C&amp;hain</source>
-        <translation type="unfinished"></translation>
+        <translation>Log C&amp;hain</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
 </context>
 <context>
     <name>EditChain</name>
     <message>
         <source>Edit Log Chain</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Chain editieren</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stop</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergangstyp:</translation>
     </message>
     <message>
         <source>Log Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Logname</translation>
     </message>
     <message>
         <source>Select</source>
-        <translation type="unfinished"></translation>
+        <translation>Auswählen</translation>
     </message>
     <message>
         <source>Log Description</source>
-        <translation type="unfinished"></translation>
+        <translation>Logbeschreibung</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
 </context>
 <context>
     <name>EditLog</name>
     <message>
         <source>Edit Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log editieren</translation>
     </message>
     <message>
         <source>Log Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Logname</translation>
     </message>
     <message>
         <source>Tracks:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tracks:</translation>
     </message>
     <message>
         <source>Origin:</source>
-        <translation type="unfinished"></translation>
+        <translation>Herkunft:</translation>
     </message>
     <message>
         <source>Description:</source>
-        <translation type="unfinished"></translation>
+        <translation>Beschreibung:</translation>
     </message>
     <message>
         <source>Service:</source>
-        <translation type="unfinished"></translation>
+        <translation>Service:</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Ja</translation>
     </message>
     <message>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Nein</translation>
     </message>
     <message>
         <source>Enable AutoRefresh:</source>
-        <translation type="unfinished"></translation>
+        <translation>AutoRefresh einschalten:</translation>
     </message>
     <message>
         <source>Start Date:</source>
-        <translation type="unfinished"></translation>
+        <translation>Startdatum:</translation>
     </message>
     <message>
         <source>End Date:</source>
-        <translation type="unfinished"></translation>
+        <translation>Enddatum:</translation>
     </message>
     <message>
         <source>Start Date Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Start Datum ein</translation>
     </message>
     <message>
         <source>End Date Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Enddatum an</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeit</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation type="unfinished"></translation>
+        <translation>ÜBERGANG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation type="unfinished"></translation>
+        <translation>CART</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation type="unfinished"></translation>
+        <translation>GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation type="unfinished"></translation>
+        <translation>LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation type="unfinished"></translation>
+        <translation>TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation type="unfinished"></translation>
+        <translation>KÜNSTLER</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation type="unfinished"></translation>
+        <translation>KUNDE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation type="unfinished"></translation>
+        <translation>AGENTUR</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation type="unfinished"></translation>
+        <translation>LABEL</translation>
     </message>
     <message>
         <source>SOURCE</source>
-        <translation type="unfinished"></translation>
+        <translation>QUELLE</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation type="unfinished"></translation>
+        <translation>LINE ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation type="unfinished"></translation>
+        <translation>ZÄHLER</translation>
     </message>
     <message>
         <source>Insert
 Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cart
+einfügen</translation>
     </message>
     <message>
         <source>Insert
 Meta</source>
-        <translation type="unfinished"></translation>
+        <translation>Meta
+einfügen</translation>
     </message>
     <message>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>editieren</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>löschen</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation type="unfinished"></translation>
+        <translation>Cut</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopieren</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation type="unfinished"></translation>
+        <translation>Einfügen</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Speichern</translation>
     </message>
     <message>
         <source>Save
 &amp;As</source>
-        <translation type="unfinished"></translation>
+        <translation>Speichern
+&amp;Als</translation>
     </message>
     <message>
         <source>&amp;Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Reporte</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Invalid Carts</source>
-        <translation type="unfinished"></translation>
+        <translation>Ungültige Carts</translation>
     </message>
     <message>
         <source>This log contains one or more carts
 that are invalid for the selected service!</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieses Log enthält einen oder mehrere Carts,
+die für den gewählten Service ungültig sind!</translation>
     </message>
     <message>
         <source>Voice Track</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Track</translation>
     </message>
     <message>
         <source>The log contains carts that are disabled
 for the selected service!
 
 Do you still want to save?</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieses Log enthält Carts die für den
+ausgewählten Service nicht verfügbar sind!
+
+Wollen Sie trotzdem speichern?</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Hinzufügen</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>Log existiert</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>Log existiert bereits!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLogEdit</translation>
     </message>
     <message>
         <source>The log has been modified.
 Do you want to save your changes?</source>
-        <translation type="unfinished"></translation>
+        <translation>Das Log modifiziert.
+Wollen Sie ihre Änderungen speichern?</translation>
     </message>
     <message>
         <source>The log contains carts that are disabled
 for the selected service!</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieses Log enthält einen oder mehrere Carts,
+die für den gewählten Service ungültig sind!</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="unfinished"></translation>
+        <translation>PLAY</translation>
     </message>
     <message>
         <source>STOP</source>
-        <translation type="unfinished"></translation>
+        <translation>STOP</translation>
     </message>
     <message>
         <source>SEGUE</source>
-        <translation type="unfinished"></translation>
+        <translation>ÜBERGANG</translation>
     </message>
     <message>
         <source>[cart not found]</source>
-        <translation type="unfinished"></translation>
+        <translation>[cart nicht gefunden]</translation>
     </message>
     <message>
         <source>MARKER</source>
-        <translation type="unfinished"></translation>
+        <translation>MARKER</translation>
     </message>
     <message>
         <source>TRACK</source>
-        <translation type="unfinished"></translation>
+        <translation>TRACK</translation>
     </message>
     <message>
         <source>LOG CHAIN</source>
-        <translation type="unfinished"></translation>
+        <translation>LOG CHAIN</translation>
     </message>
     <message>
         <source>LINK</source>
-        <translation type="unfinished"></translation>
+        <translation>LINK</translation>
     </message>
     <message>
         <source>[music import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[musikimport]</translation>
     </message>
     <message>
         <source>[traffic import]</source>
-        <translation type="unfinished"></translation>
+        <translation>[trafficimport]</translation>
     </message>
     <message>
         <source>Manual</source>
-        <translation type="unfinished"></translation>
+        <translation>Manuell</translation>
     </message>
     <message>
         <source>Traffic</source>
-        <translation type="unfinished"></translation>
+        <translation>Traffic</translation>
     </message>
     <message>
         <source>Music</source>
-        <translation type="unfinished"></translation>
+        <translation>Musik</translation>
     </message>
     <message>
         <source>RDLogManager</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLogManager</translation>
     </message>
     <message>
         <source>Voice Tracker</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Tracker</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
-        <translation type="unfinished"></translation>
+        <translation>--- ende des logs ---</translation>
     </message>
     <message>
         <source>[INVALID CART]</source>
-        <translation type="unfinished"></translation>
+        <translation>[UNGÜLTIGER CART]</translation>
     </message>
     <message>
         <source>Next Stop:</source>
-        <translation type="unfinished"></translation>
+        <translation>Nächste Stop:</translation>
     </message>
     <message>
         <source>Log End:</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Ende:</translation>
     </message>
     <message>
         <source>Run Length</source>
-        <translation type="unfinished"></translation>
+        <translation>Laufzeit</translation>
     </message>
     <message>
         <source>Selected:</source>
-        <translation type="unfinished"></translation>
+        <translation>Ausgewählt:</translation>
+    </message>
+    <message>
+        <source>Delete on</source>
+        <translation>Lösche am</translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation>Auswählen</translation>
     </message>
 </context>
 <context>
     <name>EditLogLine</name>
     <message>
         <source>Edit Log Entry</source>
-        <translation type="unfinished"></translation>
+        <translation>Logeintrag editieren</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stop</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergangstyp:</translation>
     </message>
     <message>
         <source>Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cart</translation>
     </message>
     <message>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation>Titel</translation>
     </message>
     <message>
         <source>Artist</source>
-        <translation type="unfinished"></translation>
+        <translation>Künstler</translation>
     </message>
     <message>
         <source>Select
 Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cart
+auswählen</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Missing Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehlender Cart</translation>
     </message>
     <message>
         <source>You must supply a cart number!</source>
-        <translation type="unfinished"></translation>
+        <translation>Sie müssen eine Cartnummer angeben!</translation>
     </message>
     <message>
         <source>Disabled Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Abgeschalteter Cart</translation>
     </message>
     <message>
         <source>This cart belongs to a disabled
 group for the specified service!</source>
-        <translation type="unfinished"></translation>
+        <translation>Dieser Cart gehört einer abgeschalteten
+Gruppe des ausgewählten Service!</translation>
     </message>
     <message>
         <source>No Fade on Segue Out</source>
-        <translation type="unfinished"></translation>
+        <translation>Kein Faden beim Segue Out</translation>
     </message>
 </context>
 <context>
     <name>EditMarker</name>
     <message>
         <source>Edit Log Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Marker editieren</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stop</translation>
     </message>
     <message>
         <source>Comment</source>
-        <translation type="unfinished"></translation>
+        <translation>Kommentar</translation>
     </message>
     <message>
         <source>Label</source>
-        <translation type="unfinished"></translation>
+        <translation>Label</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergangstyp:</translation>
     </message>
 </context>
 <context>
     <name>EditTrack</name>
     <message>
         <source>Edit Voice Track Marker</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Track Marker editieren</translation>
     </message>
     <message>
         <source>Start at:</source>
-        <translation type="unfinished"></translation>
+        <translation>Starte um:</translation>
     </message>
     <message>
         <source>Action If Previous Event Still Playing</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktion wenn vorheriges Event noch läuft</translation>
     </message>
     <message>
         <source>Start Immediately</source>
-        <translation type="unfinished"></translation>
+        <translation>Sofort starten</translation>
     </message>
     <message>
         <source>Make Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Als Nächstes</translation>
     </message>
     <message>
         <source>Wait up to</source>
-        <translation type="unfinished"></translation>
+        <translation>Warte bis zu</translation>
     </message>
     <message>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Abspielen</translation>
     </message>
     <message>
         <source>Segue</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation>Stop</translation>
     </message>
     <message>
         <source>Comment</source>
-        <translation type="unfinished"></translation>
+        <translation>Kommentar</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergang wenn der vorheriger Cart eher aufhört</translation>
     </message>
     <message>
         <source>Transition Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Übergangstyp:</translation>
     </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Ein Log auswählen</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation type="unfinished"></translation>
+        <translation>NAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
+        <translation>BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation>SERVICE</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbre&amp;chen</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLibrary Reports</translation>
     </message>
     <message>
         <source>Log Listing</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Liste</translation>
     </message>
     <message>
         <source>Log Exception Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Fehlerbericht</translation>
     </message>
     <message>
         <source>Type:</source>
-        <translation type="unfinished"></translation>
+        <translation>Typ:</translation>
     </message>
     <message>
         <source>&amp;Generate</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Generieren</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Schliessen</translation>
     </message>
     <message>
         <source>[none]</source>
-        <translation type="unfinished"></translation>
+        <translation>[keine]</translation>
     </message>
     <message>
         <source>Log Check</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Überprüfung</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation type="unfinished"></translation>
+        <translation>Keine Fehler gefunden.</translation>
+    </message>
+    <message>
+        <source>Effective Date:</source>
+        <translation>Effektives Datum:</translation>
+    </message>
+    <message>
+        <source>&amp;Select</source>
+        <translation>Au&amp;swählen</translation>
     </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>RDLogEdit - Host</source>
-        <translation type="unfinished"></translation>
+        <translation>RDLogEdit - Host</translation>
     </message>
     <message>
         <source>User: [Unknown]</source>
-        <translation type="unfinished"></translation>
+        <translation>Benutzer: [Unbekannt]</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
+        <translation>Kann nicht verbinden</translation>
     </message>
     <message>
         <source>LOG NAME</source>
-        <translation type="unfinished"></translation>
+        <translation>LOGNAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
+        <translation>BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation>SERVICE</translation>
     </message>
     <message>
         <source>MUSIC</source>
-        <translation type="unfinished"></translation>
+        <translation>MUSIK</translation>
     </message>
     <message>
         <source>TRAFFIC</source>
-        <translation type="unfinished"></translation>
+        <translation>TRAFFIC</translation>
     </message>
     <message>
         <source>TRACKS</source>
-        <translation type="unfinished"></translation>
+        <translation>TRACKS</translation>
     </message>
     <message>
         <source>VALID FROM</source>
-        <translation type="unfinished"></translation>
+        <translation>GÜLTIG VON</translation>
     </message>
     <message>
         <source>VALID TO</source>
-        <translation type="unfinished"></translation>
+        <translation>GÜLTIG BIS</translation>
     </message>
     <message>
         <source>AUTO REFRESH</source>
-        <translation type="unfinished"></translation>
+        <translation>AUTO REFRESH</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation type="unfinished"></translation>
+        <translation>HERKUNFT</translation>
     </message>
     <message>
         <source>LAST LINKED</source>
-        <translation type="unfinished"></translation>
+        <translation>ZULETZT GELINKT</translation>
     </message>
     <message>
         <source>LAST MODIFIED</source>
-        <translation type="unfinished"></translation>
+        <translation>ZULETZT GEÄNDERT</translation>
     </message>
     <message>
         <source>&amp;Add</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Hinzufügen</translation>
     </message>
     <message>
         <source>&amp;Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Editieren</translation>
     </message>
     <message>
         <source>&amp;Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Löschen</translation>
     </message>
     <message>
         <source>Voice
 &amp;Tracker</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice
+&amp;Tracker</translation>
     </message>
     <message>
         <source>Log
 Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Log
+Report</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Schliessen</translation>
     </message>
     <message>
         <source>User</source>
-        <translation type="unfinished"></translation>
+        <translation>Benutzer</translation>
     </message>
     <message>
         <source>Add Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Hinzufügen</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>Log existiert</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation type="unfinished"></translation>
+        <translation>Log existiert bereits!</translation>
     </message>
     <message>
         <source>Delete Log</source>
-        <translation type="unfinished"></translation>
+        <translation>Log Löschen</translation>
     </message>
     <message>
         <source>This will also delete the</source>
-        <translation type="unfinished"></translation>
+        <translation>Dies löscht ebenfalls die</translation>
     </message>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Tracks die mit diesem Log verbunden sind.
+Fortfahren?</translation>
     </message>
     <message>
         <source>Tracks Exist</source>
-        <translation type="unfinished"></translation>
+        <translation>Track existiert</translation>
     </message>
     <message>
         <source>Always</source>
-        <translation type="unfinished"></translation>
+        <translation>Immer</translation>
     </message>
     <message>
         <source>TFN</source>
-        <translation type="unfinished"></translation>
+        <translation>TFN</translation>
     </message>
 </context>
 </TS>
