@@ -2,9 +2,9 @@
 //
 // Edit a Rivendell Log Event
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2004,2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.cpp,v 1.37 2007/07/11 14:58:10 stgabriel Exp $
+//      $Id: edit_event.cpp,v 1.44.2.7 2009/06/29 13:15:37 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,15 +25,14 @@
 #include <qcombobox.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 #include <qcolordialog.h>
-#include <rconf.h>
-#include <math.h>
 
+#include <rddb.h>
 #include <rd.h>
+#include <rdconf.h>
 #include <rdcart.h>
 #include <rdcart_search_text.h>
-#include <rdtextvalidator.h>
+#include <rdescape_string.h>
 
 #include <globals.h>
 #include <add_event.h>
@@ -86,11 +85,6 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_playout_map=new QPixmap(play_xpm);
   event_macro_map=new QPixmap(rml5_xpm);
 
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
-
   //
   // Library Section
   //
@@ -98,7 +92,6 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   event_lib_filter_edit=new QLineEdit(this,"event_lib_filter_edit");
   event_lib_filter_edit->setGeometry(55,10,CENTER_LINE-70,14);
-  event_lib_filter_edit->setValidator(validator);
   connect(event_lib_filter_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
   QLabel *label=new QLabel(event_lib_filter_edit,tr("Filter:"),
@@ -157,7 +150,11 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   // Cart List
   //
   event_lib_list=new LibListView(this,"event_lib_list");
-  event_lib_list->setGeometry(10,80,CENTER_LINE-20,sizeHint().height()-150);
+#ifdef WIN32
+  event_lib_list->setGeometry(10,80,CENTER_LINE-20,sizeHint().height()-250);
+#else
+  event_lib_list->setGeometry(10,80,CENTER_LINE-20,sizeHint().height()-300);
+#endif  // WIN32
   event_lib_list->setAllColumnsShowFocus(true);
   event_lib_list->setItemMargin(5);
   event_lib_list->addColumn("");
@@ -177,31 +174,45 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   // Cart Player
   //
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
+  event_player = NULL;
 #ifndef WIN32
   sql=QString().sprintf("select OUTPUT_CARD,OUTPUT_PORT,START_CART,END_CART \
                        from RDLOGEDIT where STATION=\"%s\"",
 			(const char *)rdstation_conf->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     event_player=
       new RDSimplePlayer(rdcae,rdripc,q->value(0).toInt(),q->value(1).toInt(),
 			 q->value(2).toUInt(),q->value(3).toUInt(),
 			 this,"event_player");
-    event_player->playButton()->setGeometry(10,sizeHint().height()-60,80,50);
+    event_player->playButton()->
+      setGeometry(CENTER_LINE-180,sizeHint().height()-210,80,50);
     event_player->stopButton()->
       setPalette(QPalette(backgroundColor(),QColor(lightGray)));
-    event_player->stopButton()->setGeometry(100,sizeHint().height()-60,80,50);
+    event_player->stopButton()->setGeometry(CENTER_LINE-90,sizeHint().height()-210,80,50);
     event_player->stopButton()->setOnColor(red);
   }
   delete q;
 #endif  // WIN32  
 
+  //
+  // Remarks
+  //
+  event_remarks_edit=new QTextEdit(this,"event_remarks_edit");
+  event_remarks_edit->
+    setGeometry(10,sizeHint().height()-150,CENTER_LINE-20,140);
+  event_remarks_edit->setTextFormat(QTextEdit::PlainText);
+  label=new QLabel(event_remarks_edit,tr("REMARKS"),this,"event_remarks_label");
+  label->setFont(bold_font);
+  label->setGeometry(15,sizeHint().height()-165,100,15);
+  label->setAlignment(AlignVCenter|AlignLeft);
+
   //
   // Load Group List
   //
   sql="select NAME from GROUPS order by NAME";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   event_group_box->insertItem(tr("ALL"));
   while(q->next()) {
     event_group_box->insertItem(q->value(0).toString());
@@ -333,8 +344,6 @@ EditEvent::EditEvent(QString eventname,bool new_event,
 
   event_autofill_box=new QCheckBox(this,"event_autofill_box");
   event_autofill_box->setGeometry(CENTER_LINE+100,182,15,15);
-  connect(event_autofill_box,SIGNAL(toggled(bool)),
-	  this,SLOT(autofillToggledData(bool)));
   label=new QLabel(event_autofill_box,tr("Use AutoFill"),
 		   this,"event_autofill_label");
   label->setFont(bold_font);
@@ -382,6 +391,16 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   // Pre-Import Carts List
   //
+  event_preimport_length_edit=new QLineEdit(this,"event_preimport_length_edit");
+  event_preimport_length_edit->setGeometry(sizeHint().width()-140,208,80,20);
+  event_preimport_length_edit->setReadOnly(true);
+  label=new QLabel(event_preimport_length_edit,tr("Len:"),
+		   this,"event_preimport_length_label");
+  label->setFont(bold_font);
+  label->setGeometry(sizeHint().width()-330,210,185,16);
+  label->setAlignment(AlignVCenter|AlignRight);
+
+
   event_preimport_list=new ImportListView(this,"event_preimport_list");
   event_preimport_list->setGeometry(CENTER_LINE+15,227,
 				    sizeHint().width()-CENTER_LINE-75,125);
@@ -403,14 +422,16 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_preimport_list->addColumn(tr("COUNT"));
   connect(event_preimport_list,SIGNAL(clicked(QListViewItem *)),
 	  this,SLOT(cartClickedData(QListViewItem *)));
+  connect(event_preimport_list,SIGNAL(lengthChanged(int)),
+	  this,SLOT(preimportLengthChangedData(int)));
   event_preimport_up_button=
-    new RTransportButton(RTransportButton::Up,this,
+    new RDTransportButton(RDTransportButton::Up,this,
 			 "event_preimport_up_button");
   event_preimport_up_button->setGeometry(sizeHint().width()-50,237,40,40);
   connect(event_preimport_up_button,SIGNAL(clicked()),
 	  this,SLOT(preimportUpData()));
   event_preimport_down_button=
-    new RTransportButton(RTransportButton::Down,this,
+    new RDTransportButton(RDTransportButton::Down,this,
 			 "event_preimport_down_button");
   event_preimport_down_button->setGeometry(sizeHint().width()-50,302,40,40);
   connect(event_preimport_down_button,SIGNAL(clicked()),
@@ -469,7 +490,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_sched_group_box=new QComboBox(this,"event_sched_group_box");
   event_sched_group_box->setGeometry(CENTER_LINE+510,359,100,20);
   QString sql2="select NAME from GROUPS order by NAME";
-  QSqlQuery *q2=new QSqlQuery(sql2);
+  RDSqlQuery *q2=new RDSqlQuery(sql2);
   while(q2->next()) {
     event_sched_group_box->insertItem(q2->value(0).toString());
   }
@@ -500,7 +521,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_have_code_box->setGeometry(CENTER_LINE+510,404,100,20);
   event_have_code_box->insertItem("");
   sql2="select CODE from SCHED_CODES order by CODE";
-  q2=new QSqlQuery(sql2);
+  q2=new RDSqlQuery(sql2);
   while(q2->next()) {
     event_have_code_box->insertItem(q2->value(0).toString());
   }
@@ -574,6 +595,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_defaulttrans_box->setGeometry(CENTER_LINE+163,451,90,22);
   event_defaulttrans_box->insertItem(tr("Play"));
   event_defaulttrans_box->insertItem(tr("Segue"));
+  event_defaulttrans_box->insertItem(tr("Stop"));
   event_defaulttrans_unit=new QLabel(tr("transition."),
 				     this,"default_cart_unit");
   event_defaulttrans_unit->setFont(bold_font);
@@ -608,6 +630,15 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   // Post-Import Carts List
   //
+  event_postimport_length_edit=new QLineEdit(this,"event_postimport_length_edit");
+  event_postimport_length_edit->setGeometry(sizeHint().width()-140,503,80,20);
+  event_postimport_length_edit->setReadOnly(true);
+  label=new QLabel(event_postimport_length_edit,tr("Len:"),
+		   this,"event_postimport_length_label");
+  label->setFont(bold_font);
+  label->setGeometry(sizeHint().width()-330,505,185,16);
+  label->setAlignment(AlignVCenter|AlignRight);
+
   event_postimport_list=new ImportListView(this,"event_postimport_list");
   event_postimport_list->setGeometry(CENTER_LINE+15,522,
 				     sizeHint().width()-CENTER_LINE-75,125);
@@ -628,14 +659,16 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   event_postimport_list->addColumn(tr("COUNT"));
   connect(event_postimport_list,SIGNAL(clicked(QListViewItem *)),
 	  this,SLOT(cartClickedData(QListViewItem *)));
+  connect(event_postimport_list,SIGNAL(lengthChanged(int)),
+	  this,SLOT(postimportLengthChangedData(int)));
   event_postimport_up_button=
-    new RTransportButton(RTransportButton::Up,this,
+    new RDTransportButton(RDTransportButton::Up,this,
 			 "event_postimport_up_button");
   event_postimport_up_button->setGeometry(sizeHint().width()-50,532,40,40);
   connect(event_postimport_up_button,SIGNAL(clicked()),
 	  this,SLOT(postimportUpData()));
   event_postimport_down_button=
-    new RTransportButton(RTransportButton::Down,this,
+    new RDTransportButton(RDTransportButton::Down,this,
 			 "event_postimport_down_button");
   event_postimport_down_button->setGeometry(sizeHint().width()-50,597,40,40);
   connect(event_postimport_down_button,SIGNAL(clicked()),
@@ -702,6 +735,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   //
   // Load Event
   //
+  event_remarks_edit->setText(event_event->remarks());
   int pos=event_event->preposition();
   if(pos<0) {
     event_position_box->setChecked(false);
@@ -744,16 +778,14 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   }
   
   event_autofill_box->setChecked(event_event->useAutofill());
-  if(event_autofill_box->isChecked()) {
-    int autofill_slop=event_event->autofillSlop();
-    if(autofill_slop>=0) {
-      event_autofill_slop_box->setChecked(true);
-      event_autofill_slop_edit->setTime(QTime().addMSecs(autofill_slop));
-    }
+  int autofill_slop=event_event->autofillSlop();
+  if(autofill_slop>=0) {
+    event_autofill_slop_box->setChecked(true);
+    event_autofill_slop_edit->setTime(QTime().addMSecs(autofill_slop));
   }
-  autofillToggledData(event_autofill_box->isChecked());
+  autofillWarnToggledData(event_autofill_slop_box->isChecked());
   event_timescale_box->setChecked(event_event->useTimescale());
-  
+
   event_source_group->setButton(event_event->importSource());
   event_startslop_edit->setTime(QTime().addMSecs(event_event->startSlop()));
   event_endslop_edit->setTime(QTime().addMSecs(event_event->endSlop()));
@@ -772,7 +804,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   sql=QString().sprintf("select NAME from EVENTS where NAME!=\"%s\"\
                          order by NAME",
 			(const char *)eventname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     event_nestevent_box->insertItem(q->value(0).toString());
     if(q->value(0).toString()==str) {
@@ -781,10 +813,12 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   }
   delete q;
 
-  event_preimport_list->logEvent()->load();
-  event_preimport_list->refreshList();
-  event_postimport_list->logEvent()->load();
-  event_postimport_list->refreshList();
+  if(!new_event) {
+    event_preimport_list->logEvent()->load();
+    event_preimport_list->refreshList();
+    event_postimport_list->logEvent()->load();
+    event_postimport_list->refreshList();
+  }
 
   prepositionToggledData(event_position_box->isChecked());
   timeToggledData(event_timetype_box->isChecked());
@@ -835,6 +869,7 @@ void EditEvent::filterClickedData(int id)
 void EditEvent::cartClickedData(QListViewItem *item)
 {
 #ifndef WIN32
+  if (!event_player) return;
   if(item==NULL) {
     event_player->setCart(0);
     return;
@@ -987,14 +1022,6 @@ void EditEvent::timeTransitionData(int id)
 }
 
 
-void EditEvent::autofillToggledData(bool state)
-{
-  event_autofill_slop_box->setEnabled(state);
-  event_autofill_slop_label1->setEnabled(state);
-  autofillWarnToggledData(state&&event_autofill_slop_box->isChecked());
-}
-
-
 void EditEvent::autofillWarnToggledData(bool state)
 {
   event_autofill_slop_edit->setEnabled(state);
@@ -1061,6 +1088,12 @@ void EditEvent::preimportChangedData(int size)
 }
 
 
+void EditEvent::preimportLengthChangedData(int msecs)
+{
+  event_preimport_length_edit->setText(RDGetTimeLength(msecs,true,false));
+}
+
+
 void EditEvent::preimportUpData()
 {
   int line;
@@ -1134,6 +1167,12 @@ void EditEvent::postimportDownData()
 }
 
 
+void EditEvent::postimportLengthChangedData(int msecs)
+{
+  event_postimport_length_edit->setText(RDGetTimeLength(msecs,true,false));
+}
+
+
 void EditEvent::saveData()
 {
   Save();
@@ -1154,8 +1193,8 @@ void EditEvent::saveAsData()
   }
   delete add_dialog;
   QString sql=QString().sprintf("select NAME from EVENTS where NAME=\"%s\"",
-				(const char *)event_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+				(const char *)RDEscapeString(event_name));
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete event_event;
     event_event=new RDEvent(event_name,true);
@@ -1178,8 +1217,8 @@ void EditEvent::saveAsData()
     Save();
     event_new_events->push_back(event_name);
     sql=QString().sprintf("delete from EVENT_PERMS where EVENT_NAME=\"%s\"",
-			  (const char *)event_name);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(event_name));
+    q=new RDSqlQuery(sql);
     delete q;
     CopyEventPerms(old_name,event_name);
     if(event_new_event) {
@@ -1216,7 +1255,9 @@ void EditEvent::okData()
 {
   Save();
 #ifndef WIN32
-  event_player->stop();
+  if (event_player){
+    event_player->stop();
+  }
 #endif  // WIN32
   done(0);
 }
@@ -1225,7 +1266,9 @@ void EditEvent::okData()
 void EditEvent::cancelData()
 {
 #ifndef WIN32
-  event_player->stop();
+  if (event_player){
+    event_player->stop();
+  }
 #endif  // WIN32
   if(event_saved) {
     done(-1);
@@ -1236,6 +1279,12 @@ void EditEvent::cancelData()
 }
 
 
+void EditEvent::closeEvent(QCloseEvent *e)
+{
+  cancelData();
+}
+
+
 void EditEvent::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
@@ -1274,10 +1323,10 @@ void EditEvent::RefreshLibrary()
   }
   sql+=QString().
     sprintf(" where %s && %s",
-	    (const char *)RDCartSearchText(event_lib_filter_edit->
-					   text(),group).utf8(),
+	    (const char *)
+	    RDCartSearchText(event_lib_filter_edit->text(),group).utf8(),
 	    (const char *)type_filter);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item;
   event_lib_list->clear();
   while(q->next()) {
@@ -1298,7 +1347,7 @@ void EditEvent::RefreshLibrary()
     }
     item->setText(1,QString().sprintf("%06u",q->value(1).toInt()));
     item->setText(2,q->value(2).toString());
-    item->setText(3,RGetTimeLength(q->value(3).toInt(),false,false));
+    item->setText(3,RDGetTimeLength(q->value(3).toInt(),false,false));
     item->setText(4,q->value(4).toString());
     item->setText(5,q->value(5).toString());
     if(!q->value(6).toDateTime().isNull()) {
@@ -1357,6 +1406,7 @@ void EditEvent::Save()
   QString properties;
   QString listname;
 
+  event_event->setRemarks(event_remarks_edit->text());
   if(event_position_box->isChecked()) {
     event_event->setPreposition(QTime().msecsTo(event_position_edit->time()));
   }
@@ -1403,14 +1453,12 @@ void EditEvent::Save()
   }
 
   event_event->setUseAutofill(event_autofill_box->isChecked());
-  if(event_autofill_box->isChecked()) {
-    if(event_autofill_slop_box->isChecked()) {
-      event_event->
-	setAutofillSlop(QTime().msecsTo(event_autofill_slop_edit->time()));
-    }
-    else {
-      event_event->setAutofillSlop(-1);
-    }
+  if(event_autofill_slop_box->isChecked()) {
+    event_event->
+      setAutofillSlop(QTime().msecsTo(event_autofill_slop_edit->time()));
+  }
+  else {
+    event_event->setAutofillSlop(-1);
   }
   event_event->setUseTimescale(event_timescale_box->isChecked());
 
@@ -1467,10 +1515,10 @@ void EditEvent::Save()
   listname.replace(" ","_");
   event_preimport_list->logEvent()->
     setLogName(QString().sprintf("%s_PRE",(const char *)listname));
-  event_preimport_list->logEvent()->save();
+  event_preimport_list->logEvent()->save(false);
   event_postimport_list->logEvent()->
     setLogName(QString().sprintf("%s_POST",(const char *)listname));
-  event_postimport_list->logEvent()->save();
+  event_postimport_list->logEvent()->save(false);
   event_saved=true;
 }
 
@@ -1582,18 +1630,20 @@ QString EditEvent::GetProperties()
 void EditEvent::CopyEventPerms(QString old_name,QString new_name)
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
 
   sql=QString().sprintf("select SERVICE_NAME from EVENT_PERMS where\
-                         EVENT_NAME=\"%s\"",(const char *)old_name);
-  q=new QSqlQuery(sql);
+                         EVENT_NAME=\"%s\"",
+			(const char *)RDEscapeString(old_name));
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     sql=QString().sprintf("insert into EVENT_PERMS set\
                           EVENT_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			  (const char *)new_name,
-			  (const char *)q->value(0).toString());
-    q1=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(new_name),
+			  (const char *)
+			  RDEscapeString(q->value(0).toString()));
+    q1=new RDSqlQuery(sql);
     delete q1;
   }
   delete q;
@@ -1606,19 +1656,20 @@ void EditEvent::AbandonEvent(QString name)
     return;
   }
   QString sql=QString().sprintf("delete from EVENTS where NAME=\"%s\"",
-				(const char *)name);
-  QSqlQuery *q=new QSqlQuery(sql);
+				(const char *)RDEscapeString(name));
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from EVENT_PERMS where EVENT_NAME=\"%s\"",
-			(const char *)name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(name));
+  q=new RDSqlQuery(sql);
   delete q;
   name.replace(" ","_");
-  sql=QString().sprintf("drop table %s_PRE",(const char *)name);
-  q=new QSqlQuery(sql);
+  sql=QString().sprintf("drop table %s_PRE",
+			(const char *)RDEscapeStringSQLColumn(name));
+  q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("drop table %s_POST",(const char *)name);
-  q=new QSqlQuery(sql);
+  sql=QString().sprintf("drop table %s_POST",
+			(const char *)RDEscapeStringSQLColumn(name));
+  q=new RDSqlQuery(sql);
   delete q;
 }
-
