@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_eventline.cpp,v 1.12 2007/09/14 14:06:58 fredg Exp $
+//      $Id: edit_eventline.cpp,v 1.14 2007/11/13 00:23:29 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +27,7 @@
 #include <qmessagebox.h>
 #include <qpushbutton.h>
 
+#include <rddb.h>
 #include <rd.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
@@ -205,13 +206,14 @@ void EditEventLine::okData()
   }
   QString sql=QString().sprintf("select NAME from EVENTS where NAME=\"%s\"",
 				(const char *)edit_eventname_edit->text());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     QMessageBox::information(this,tr("No Such Event"),
 			     tr("There is no such event."));
     delete q;
     return;
   }
+  edit_eventname_edit->setText(q->value(0).toString());
   delete q;
   if(!edit_clock->validate(edit_starttime_edit->time(),
 			   edit_starttime_edit->time().
