@@ -1,10 +1,10 @@
-// edlogmanager.cpp
+// rdlogmanager.cpp
 //
 // The Log Editor Utility for Rivendell.
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogmanager.cpp,v 1.31 2007/03/12 11:57:05 fredg Exp $
+//      $Id: rdlogmanager.cpp,v 1.37 2008/07/26 00:01:39 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,6 +21,7 @@
 //
 
 #ifndef WIN32
+#include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
 #include <sys/types.h>
@@ -35,22 +36,21 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qsettings.h>
-#include <rd.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rconf.h>
 #include <qlabel.h>
 #include <qlistview.h>
 #include <qtextcodec.h>
 #include <qtranslator.h>
 
-#include <rdlogmanager.h>
+#include <rd.h>
+#include <rduser.h>
+#include <rdripc.h>
 #include <rdstation.h>
 #include <rdcheck_daemons.h>
 #include <rdcreate_log.h>
 #include <rdcmd_switch.h>
 #include <rddbheartbeat.h>
 
+#include <rdlogmanager.h>
 #include <globals.h>
 #include <list_events.h>
 #include <list_clocks.h>
@@ -157,26 +157,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   log_config=new RDConfig();
   log_config->load();
-  setCaption("");
+  setCaption(tr("RDLogManager"));
 
   //
   // Open Database
   //
-  log_db=QSqlDatabase::addDatabase(log_config->mysqlDriver());
+  QString err;
+  log_db=RDInitDb(&err);
   if(!log_db) {
-    QMessageBox::warning(this,
-			 tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    exit(0);
-  }
-  log_db->setDatabaseName(log_config->mysqlDbname());
-  log_db->setUserName(log_config->mysqlUsername());
-  log_db->setPassword(log_config->mysqlPassword());
-  log_db->setHostName(log_config->mysqlHostname());
-  if(!log_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    log_db->removeDatabase(log_config->mysqlDbname());
+    QMessageBox::warning(this,tr("Can't Connect"),err);
     exit(0);
   }
   new RDDbHeartbeat(log_config->mysqlHeartbeatInterval(),this);
@@ -337,6 +326,10 @@ QSizePolicy MainWidget::sizePolicy() const
 
 void MainWidget::userData()
 {
+  QString str1=tr("RDLogManager - User: ");
+  setCaption(QString().sprintf("%s%s",(const char *)str1,
+			       (const char *)rdripc->user()));
+
   if(rduser!=NULL) {
     delete rduser;
   }
@@ -427,13 +420,17 @@ int main(int argc,char *argv[])
   qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(tr_path+QString("libradio_")+QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
+  QTranslator rd(0);
+  rd.load(tr_path+QString("librd_")+QTextCodec::locale(),".");
+  a.installTranslator(&rd);
 
-  QTranslator tests(0);
-  tests.load(tr_path+QString("rdlogmanager_")+QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  QTranslator rdhpi(0);
+  rdhpi.load(tr_path+QString("librdhpi_")+QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(tr_path+QString("rdlogmanager_")+QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
