@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: svc_rec.cpp,v 1.5 2007/09/14 14:06:58 fredg Exp $
+//      $Id: svc_rec.cpp,v 1.6 2007/10/04 20:53:39 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,8 +25,7 @@
 #include <qstring.h>
 #include <qlabel.h>
 #include <qpalette.h>
-#include <qsqldatabase.h>
-
+#include <rddb.h>
 #include <svc_rec.h>
 
 //
@@ -37,7 +36,7 @@ SvcRec::SvcRec(const QString &svcname,
   :QWidget(parent,name)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   pick_service_name=svcname;
 
   //
@@ -59,7 +58,7 @@ SvcRec::SvcRec(const QString &svcname,
   sql=QString().sprintf("select EVENT_DATETIME from `%s_SRT`\
                          order by EVENT_DATETIME",
 			(const char *)pick_tablename);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     pick_low_year=q->value(0).toDate().year();
   }
@@ -217,7 +216,7 @@ bool SvcRec::dayActive(int day) const
 void SvcRec::deleteDay()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   QString tablename=pick_service_name;
   tablename.replace(" ","_");
@@ -227,7 +226,7 @@ void SvcRec::deleteDay()
 			(const char *)tablename,
 			(const char *)date().toString("yyyy-MM-dd 00:00:00"),
 			(const char *)date().toString("yyyy-MM-dd 23:59:59"));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   GetActiveDays(pick_date);
   PrintDays();
@@ -406,7 +405,7 @@ void SvcRec::SelectDay(int day,int dow_offset,bool state)
 void SvcRec::GetActiveDays(const QDate &date)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   for(int i=0;i<=31;i++) {
     sql=QString().sprintf("select ID from `%s_SRT` where \
@@ -415,7 +414,7 @@ void SvcRec::GetActiveDays(const QDate &date)
 			  (const char *)pick_tablename,
 			  (const char *)date.toString("yyyy-MM"),i+1,
 			  (const char *)date.toString("yyyy-MM"),i+1);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     pick_active_days[i]=q->first();
     delete q;
   }
