@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.49.2.4 2008/12/11 20:13:09 fredg Exp $
+//      $Id: local_macros.cpp,v 1.49.2.10 2009/08/07 01:14:08 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@
 #include <rduser.h>
 #include <rddb.h>
 #include <ripcd.h>
-
+#include <rdescape_string.h>
 
 void MainObject::gpiChangedData(int matrix,int line,bool state)
 {
@@ -435,6 +435,23 @@ void MainObject::LoadLocalMacros()
 		  this,SLOT(sendRml(RDMacro *)));
 	  break;
 
+	case RDMatrix::BtSs44:
+	  ripcd_btss44[q->value(0).toInt()]=new BtSs44(matrix,this);
+	  ripcd_switcher_tty[matrix->matrix()][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix->matrix()][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btss44[q->value(0).toInt()],
+		  SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btss44[q->value(0).toInt()],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss44[q->value(0).toInt()],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+
 	default:
 	  break;
     }
@@ -485,6 +502,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
   int gpi;
   int tty_port;
   int tty_port2;
+  int severity=0;
   QString str;
   QString sql;
   QString cmd;
@@ -712,6 +730,58 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       delete rduser;
       break;
       
+    case RDMacro::MB:
+      if(rml->argQuantity()<3) {
+	if(rml->echoRequested()) {
+	  rml->acknowledge(false);
+	  sendRml(rml);
+	}
+	return;
+      }
+      severity=rml->arg(1).toInt();
+      if((severity<1)||(severity>3)) {
+	if(rml->echoRequested()) {
+	  rml->acknowledge(false);
+	  sendRml(rml);
+	}
+	return;
+      }
+      if(fork()==0) {
+	if(getuid()==0) {
+	  if(setegid(ripcd_config->gid())<0) {
+	    LogLine(RDConfig::LogWarning,QString().
+		    sprintf("unable to set group id %d for RDPopup",
+				      ripcd_config->gid()));
+	    if(rml->echoRequested()) {
+	      rml->acknowledge(false);
+	      sendRml(rml);
+	    }
+	  }
+	  if(seteuid(ripcd_config->uid())<0) {
+	    LogLine(RDConfig::LogWarning,QString().
+		    sprintf("unable to set user id %d for RDPopup",
+				      ripcd_config->uid()));
+	    if(rml->echoRequested()) {
+	      rml->acknowledge(false);
+	      sendRml(rml);
+	    }
+	  }
+	}
+	if(system(QString().
+		  sprintf("rdpopup -display %s %s %s",
+			(const char *)rml->arg(0).toString(),
+			(const char *)rml->arg(1).toString(),
+			(const char *)RDEscapeString(rml->rollupArgs(2))))<0) {
+	  LogLine(RDConfig::LogWarning,"RDPopup returned an error");
+	}
+	exit(0);
+      }
+      if(rml->echoRequested()) {
+	rml->acknowledge(true);
+	sendRml(rml);
+      }
+      break;
+
     case RDMacro::MT:
       if(rml->argQuantity()!=3) {
 	if(rml->echoRequested()) {
@@ -1007,6 +1077,10 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_quartz1[rml->arg(0).toInt()]->processCommand(rml);
 	  break;
 	  
+	case RDMatrix::BtSs44:
+	  ripcd_btss44[rml->arg(0).toInt()]->processCommand(rml);
+	  break;
+	  
 	default:
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(false);
@@ -1209,6 +1283,12 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
 	  break;
 	  
+	case RDMatrix::BtSs44:
+	  delete ripcd_btss44[matrix_num];
+	  ripcd_btss44[matrix_num]=NULL;
+	  ripcd_matrix_type[matrix_num]=RDMatrix::None;
+	  break;
+	  
 	default:
 	  break;
       }
@@ -1509,6 +1589,23 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 		  this,SLOT(sendRml(RDMacro *)));
 	  break;
 	  
+	case RDMatrix::BtSs44:
+	  ripcd_btss44[matrix_num]=new BtSs44(matrix);
+	  ripcd_matrix_type[matrix_num]=RDMatrix::BtSs44;
+	  ripcd_switcher_tty[matrix_num][0]=
+	    matrix->port(RDMatrix::Primary);
+	  ripcd_switcher_tty[matrix_num][1]=-1;
+	  ripcd_tty_inuse[matrix->port(RDMatrix::Primary)]=true;
+	  connect(ripcd_btss44[matrix_num],SIGNAL(rmlEcho(RDMacro *)),
+		  this,SLOT(sendRml(RDMacro *)));
+	  connect(ripcd_btss44[matrix_num],
+		  SIGNAL(gpiChanged(int,int,bool)),
+		  this,SLOT(gpiChangedData(int,int,bool)));
+	  connect(ripcd_btss44[matrix_num],
+		  SIGNAL(gpoChanged(int,int,bool)),
+		  this,SLOT(gpoChangedData(int,int,bool)));
+	  break;
+	  
 	default:
 	  break;
       }
