@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: unity4000.h,v 1.3 2007/02/14 21:57:04 fredg Exp $
+//      $Id: unity4000.h,v 1.4 2007/09/14 14:07:00 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,7 +49,7 @@ class Unity4000 : public QObject
   void rmlEcho(RDMacro *cmd);
 
  private:
-  RTTYDevice *unity_device;
+  RDTTYDevice *unity_device;
   vector<UnityFeed> unity_feed;
   int unity_inputs;
   int unity_outputs;
