@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: vguest.cpp,v 1.30 2008/10/01 14:43:59 fredg Exp $
+//      $Id: vguest.cpp,v 1.30.2.1 2009/02/10 16:19:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -53,6 +53,10 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   vguest_username[1]=PadString(matrix->username(RDMatrix::Backup),16);
   vguest_password[0]=PadString(matrix->password(RDMatrix::Primary),16);
   vguest_password[1]=PadString(matrix->password(RDMatrix::Backup),16);
+  vguest_start_cart[0]=matrix->startCart(RDMatrix::Primary);
+  vguest_start_cart[1]=matrix->startCart(RDMatrix::Backup);
+  vguest_stop_cart[0]=matrix->stopCart(RDMatrix::Primary);
+  vguest_stop_cart[1]=matrix->stopCart(RDMatrix::Backup);
   vguest_ipport[0]=matrix->ipPort(RDMatrix::Primary);
   vguest_ipport[1]=matrix->ipPort(RDMatrix::Backup);
   vguest_inputs=matrix->inputs();
@@ -374,6 +378,9 @@ void VGuest::connectionClosedData(int id)
 	  sprintf("Connection to vGuest device at %s:%d closed, attempting reconnect, holdoff = %d mS",
 			    (const char *)vguest_ipaddress[id].toString(),
 			    vguest_ipport[id],interval));
+  if(vguest_stop_cart[id]>0) {
+    ExecuteMacroCart(vguest_stop_cart[id]);
+  }
   vguest_reconnect_timer[id]->start(interval,true);
 }
 
@@ -505,6 +512,9 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
 			"connection to vGuest device at %s:%d established",
 			(const char *)vguest_ipaddress[id].toString(),
 			vguest_ipport[id]));
+	      if(vguest_start_cart[id]>0) {
+		ExecuteMacroCart(vguest_start_cart[id]);
+	      }
 	      break;
 
 	    case 0x0B:  // Invalid Username
@@ -642,3 +652,16 @@ int VGuest::GetHoldoff()
 	       (VGUEST_RECONNECT_MAX_INTERVAL-VGUEST_RECONNECT_MIN_INTERVAL)*
 	       (double)random()/(double)RAND_MAX);
 }
+
+
+void VGuest::ExecuteMacroCart(unsigned cartnum)
+{
+  RDMacro rml;
+  rml.setRole(RDMacro::Cmd);
+  rml.setCommand(RDMacro::EX);
+  rml.setAddress(rdstation->address());
+  rml.setEchoRequested(false);
+  rml.setArgQuantity(1);
+  rml.setArg(0,cartnum);
+  emit rmlEcho(&rml);
+}
