@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.23.2.2 2008/11/30 00:33:04 fredg Exp $
+//      $Id: rdimport.cpp,v 1.23.2.4 2009/08/04 23:18:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -789,26 +789,26 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
     }
     cut->setMetadata(wavedata);
   }
-  if(wavedata->title().length()==0 || ( (wavedata->title().length()>0) && (wavedata->title()[0] == '\0')) ) {
+  if((wavedata->title().length()==0)||
+     ((wavedata->title().length()>0)&&(wavedata->title()[0] == '\0'))) {
     QString title=effective_group->defaultTitle();
     QString basename=RDGetBasePart(filename);
     int ptr=basename.findRev(".");
     title.replace("%p",RDGetPathPart(filename));
     title.replace("%f",basename.left(ptr));
     title.replace("%e",basename.right(basename.length()-ptr-1));
+    cut->setDescription(title.utf8());
     if(cart_created) {
       cart->setTitle(title.utf8());
     }
-    cut->setDescription(title.utf8());
   }
-
-  if(import_title_from_cartchunk_cutid) {
-    if(! (wavedata->cutId().length()==0 || ( (wavedata->cutId().length()>0) && (wavedata->cutId()[0] == '\0')) ) ) {
+  if(import_title_from_cartchunk_cutid) {    
+    if((wavedata->cutId().length()>0)&&(wavedata->cutId()[0]!='\0')) {
+      if(cut->description().isEmpty()) {
+	cut->setDescription(wavedata->cutId());
+      }
       cart->setTitle(wavedata->cutId());
     }
-    if(cut->description().isEmpty()) {
-      cut->setDescription(wavedata->cutId());
-    }
   }
   cart->updateLength();
   cart->resetRotation();
